@@ -41,7 +41,7 @@ call init1
 ! allocate array for storing the eigenvalues
 allocate(e(nstsv,nkpt))
 ! maximum angular momentum for band character
-lmax=min(3,lmaxvr)
+lmax=min(3,lmaxo)
 lmmax=(lmax+1)**2
 if (task.eq.21) then
   allocate(bc(0:lmax,natmtot,nstsv,nkpt))
