@@ -7,44 +7,43 @@ subroutine dbxcplot
 use modmain
 implicit none
 ! local variables
-integer idm,is,ias,ir
+integer idm,is,ias,np
 ! allocatable arrays
-real(8), allocatable :: rvfmt(:,:,:,:),rvfir(:,:)
-real(8), allocatable :: rfmt(:,:,:),rfir(:)
-real(8), allocatable :: grfmt(:,:,:,:),grfir(:,:)
+real(8), allocatable :: rvfmt(:,:,:),rvfir(:,:)
+real(8), allocatable :: rfmt(:,:),rfir(:)
+real(8), allocatable :: grfmt(:,:,:),grfir(:,:)
+! initialise universal variables
+call init0
 if (.not.spinpol) then
   write(*,*)
-  write(*,'("Error(dbxcplot): spin-unpolarised field is zero")')
+  write(*,'("Error(dbxcplot): spin-unpolarised magnetic field is zero")')
   write(*,*)
   stop
 end if
-! initialise universal variables
-call init0
 ! read magnetisation from file
 call readstate
-allocate(rvfmt(lmmaxvr,nrmtmax,natmtot,3),rvfir(ngtot,3))
-allocate(rfmt(lmmaxvr,nrmtmax,natmtot),rfir(ngtot))
-allocate(grfmt(lmmaxvr,nrmtmax,natmtot,3),grfir(ngtot,3))
+allocate(rvfmt(npmtmax,natmtot,3),rvfir(ngtot,3))
+allocate(rfmt(npmtmax,natmtot),rfir(ngtot))
+allocate(grfmt(npmtmax,natmtot,3),grfir(ngtot,3))
 if (ncmag) then
 ! non-collinear
-  rvfmt(:,:,:,:)=bxcmt(:,:,:,:)
+  rvfmt(:,:,:)=bxcmt(:,:,:)
   rvfir(:,:)=bxcir(:,:)
 else
 ! collinear
-  rvfmt(:,:,:,1:2)=0.d0
+  rvfmt(:,:,1:2)=0.d0
   rvfir(:,1:2)=0.d0
-  rvfmt(:,:,:,3)=bxcmt(:,:,:,1)
+  rvfmt(:,:,3)=bxcmt(:,:,1)
   rvfir(:,3)=bxcir(:,1)
 end if
-rfmt(:,:,:)=0.d0
+rfmt(:,:)=0.d0
 rfir(:)=0.d0
 do idm=1,3
-  call gradrf(rvfmt(:,:,:,idm),rvfir(:,idm),grfmt,grfir)
+  call gradrf(rvfmt(:,:,idm),rvfir(:,idm),grfmt,grfir)
   do ias=1,natmtot
     is=idxis(ias)
-    do ir=1,nrmt(is)
-      rfmt(:,ir,ias)=rfmt(:,ir,ias)+grfmt(:,ir,ias,idm)
-    end do
+    np=npmt(is)
+    rfmt(1:np,ias)=rfmt(1:np,ias)+grfmt(1:np,ias,idm)
   end do
   rfir(:)=rfir(:)+grfir(:,idm)
 end do
