@@ -18,18 +18,18 @@ integer l1,l2,l3,m1,m2,m3
 integer lm1,lm2,lm3,i,j
 complex(8) zsum
 is=idxis(ias)
-do ilo=1,nlorb(is)
-  l1=lorbl(ilo,is)
-  do m1=-l1,l1
-    lm1=idxlm(l1,m1)
-    i=ngpq+idxlo(lm1,ilo,ias)
-    do jlo=1,nlorb(is)
-      l3=lorbl(jlo,is)
-      do m3=-l3,l3
-        lm3=idxlm(l3,m3)
-        j=ngp+idxlo(lm3,jlo,ias)
+do jlo=1,nlorb(is)
+  l3=lorbl(jlo,is)
+  do m3=-l3,l3
+    lm3=idxlm(l3,m3)
+    j=ngp+idxlo(lm3,jlo,ias)
+    do ilo=1,nlorb(is)
+      l1=lorbl(ilo,is)
+      do m1=-l1,l1
+        lm1=idxlm(l1,m1)
+        i=ngpq+idxlo(lm1,ilo,ias)
         zsum=0.d0
-        do l2=0,lmaxvr
+        do l2=0,lmaxo
           if (mod(l1+l2+l3,2).eq.0) then
             do m2=-l2,l2
               lm2=idxlm(l2,m2)
