@@ -8,21 +8,39 @@ use modmain
 use modphonon
 implicit none
 ! local variables
-integer is,ias,nr,ir
+integer is,ias,nr,nri,np
 ! allocatable arrays
-complex(8), allocatable :: zfmt(:,:)
-! compute the exchange-correlation potential derivative
-! (at this stage the density derivative is in spherical coordinates)
-call dpotxc
-! convert density derivative to spherical harmonics
-!$OMP PARALLEL DEFAULT(SHARED) PRIVATE(zfmt,is,nr)
+complex(8), allocatable :: zfmt(:)
+! convert density derivative to spherical coordinates
+!$OMP PARALLEL DEFAULT(SHARED) &
+!$OMP PRIVATE(zfmt,is,nr,nri,np)
 !$OMP DO
 do ias=1,natmtot
-  allocate(zfmt(lmmaxvr,nrmtmax))
+  allocate(zfmt(npmtmax))
   is=idxis(ias)
   nr=nrmt(is)
-  call zcopy(lmmaxvr*nr,drhomt(:,:,ias),1,zfmt,1)
-  call zfsht(nr,nrmtinr(is),zfmt,drhomt(:,:,ias))
+  nri=nrmti(is)
+  np=npmt(is)
+  zfmt(1:np)=drhomt(1:np,ias)
+  call zbsht(nr,nri,zfmt,drhomt(:,ias))
+  deallocate(zfmt)
+end do
+!$OMP END DO
+!$OMP END PARALLEL
+! compute the exchange-correlation potential derivative
+call dpotxc
+! convert density derivative to spherical harmonics
+!$OMP PARALLEL DEFAULT(SHARED) &
+!$OMP PRIVATE(zfmt,is,nr,nri,np)
+!$OMP DO
+do ias=1,natmtot
+  allocate(zfmt(npmtmax))
+  is=idxis(ias)
+  nr=nrmt(is)
+  nri=nrmti(is)
+  np=npmt(is)
+  zfmt(1:np)=drhomt(1:np,ias)
+  call zfsht(nr,nri,zfmt,drhomt(:,ias))
   deallocate(zfmt)
 end do
 !$OMP END DO
@@ -32,18 +50,13 @@ call dpotcoul
 ! add to the Kohn-Sham potential derivative
 do ias=1,natmtot
   is=idxis(ias)
-  call zfmtadd(nrmt(is),nrmtinr(is),zone,dvclmt(:,:,ias),dvsmt(:,:,ias))
+  np=npmt(is)
+  dvsmt(1:np,ias)=dvsmt(1:np,ias)+dvclmt(1:np,ias)
 end do
 call zaxpy(ngtot,zone,dvclir,1,dvsir,1)
 ! remove the gradient part of the potential derivative for displaced muffin-tin
-call zfmtadd(nrmt(isph),nrmtinr(isph),zone,gvsmt,dvsmt(:,:,iasph))
-! zero high (l,m) components on inner part of muffin-tin
-do ias=1,natmtot
-  is=idxis(ias)
-  do ir=1,nrmtinr(is)
-    dvsmt(lmmaxinr+1:lmmaxvr,ir,ias)=0.d0
-  end do
-end do
+np=npmt(isph)
+dvsmt(1:np,iasph)=dvsmt(1:np,iasph)+gvsmt(1:np)
 return
 end subroutine
 
