@@ -63,13 +63,13 @@ use modtest
 !BOC
 implicit none
 ! local variables
-integer ik,ist,idm,jdm,n2,i
-integer is,ia,ias,nrc,nrci
+integer ik,ist,idm,jdm
+integer is,ia,ias,n2,i
 real(8) cb,vn,sum,f
 complex(8) z1
 ! allocatable arrays
-real(8), allocatable :: rfmt(:,:,:)
-complex(8), allocatable :: evecsv(:,:),c(:,:)
+real(8), allocatable :: rfmt(:,:)
+complex(8), allocatable :: evecsv(:,:),kmat(:,:),c(:,:)
 ! external functions
 real(8) rfinp
 complex(8) zdotc
@@ -79,14 +79,13 @@ cb=gfacte/(4.d0*solsc)
 !-----------------------------------------------!
 !     exchange-correlation potential energy     !
 !-----------------------------------------------!
-engyvxc=rfinp(1,rhomt,vxcmt,rhoir,vxcir)
+engyvxc=rfinp(rhomt,rhoir,vxcmt,vxcir)
 !-----------------------------------------------------!
 !     exchange-correlation effective field energy     !
 !-----------------------------------------------------!
 engybxc=0.d0
 do idm=1,ndmag
-  engybxc=engybxc+rfinp(1,magmt(:,:,:,idm),bxcmt(:,:,:,idm),magir(:,idm), &
-   bxcir(:,idm))
+  engybxc=engybxc+rfinp(magmt(:,:,idm),magir(:,idm),bxcmt(:,:,idm),bxcir(:,idm))
 end do
 !------------------------------------------!
 !     external magnetic field energies     !
@@ -104,17 +103,17 @@ end do
 !----------------------------------!
 !     Coulomb potential energy     !
 !----------------------------------!
-engyvcl=rfinp(1,rhomt,vclmt,rhoir,vclir)
+engyvcl=rfinp(rhomt,rhoir,vclmt,vclir)
 !-----------------------!
 !     Madelung term     !
 !-----------------------!
 engymad=0.d0
 do is=1,nspecies
 ! compute the bare nucleus potential at the origin
-  call potnucl(ptnucl,1,spr(:,is),spzn(is),vn)
+  call potnucl(ptnucl,1,rsp(:,is),spzn(is),vn)
   do ia=1,natoms(is)
     ias=idxas(ia,is)
-    engymad=engymad+0.5d0*spzn(is)*(vclmt(1,1,ias)*y00-vn)
+    engymad=engymad+0.5d0*spzn(is)*(vclmt(1,ias)*y00-vn)
   end do
 end do
 !---------------------------------------------!
@@ -139,14 +138,14 @@ if ((xctype(1).lt.0).or.(task.eq.5)) then
 ! mix exact and DFT exchange energies for hybrid functionals
     if (hybrid) then
       engyx=engyx*hybridc
-      engyx=engyx+rfinp(1,rhomt,exmt,rhoir,exir)
+      engyx=engyx+rfinp(rhomt,rhoir,exmt,exir)
     end if
   else
     engyx=0.d0
   end if
 else
 ! exchange energy from the density
-  engyx=rfinp(1,rhomt,exmt,rhoir,exir)
+  engyx=rfinp(rhomt,rhoir,exmt,exir)
 end if
 !----------------------------!
 !     correlation energy     !
@@ -154,14 +153,14 @@ end if
 if (task.eq.5) then
   if (hybrid) then
 ! fraction of DFT correlation energy for hybrid functionals
-    engyc=rfinp(1,rhomt,ecmt,rhoir,ecir)
+    engyc=rfinp(rhomt,rhoir,ecmt,ecir)
   else
 ! zero correlation energy for pure Hartree-Fock
     engyc=0.d0
   end if
 else
 ! correlation energy from the density
-  engyc=rfinp(1,rhomt,ecmt,rhoir,ecir)
+  engyc=rfinp(rhomt,rhoir,ecmt,ecir)
 end if
 !----------------------!
 !     DFT+U energy     !
@@ -182,7 +181,7 @@ end if
 evalsum=0.d0
 do ias=1,natmtot
   is=idxis(ias)
-  do ist=1,spnst(is)
+  do ist=1,nstsp(is)
     if (spcore(ist,is)) evalsum=evalsum+occcr(ist,ias)*evalcr(ist,ias)
   end do
 end do
@@ -202,31 +201,29 @@ if (task.eq.5) then
 ! Hartree-Fock case
   engykn=engykncr
 ! kinetic energy from valence states
-  allocate(evecsv(nstsv,nstsv))
-  allocate(c(nstsv,nstsv))
+  allocate(evecsv(nstsv,nstsv),kmat(nstsv,nstsv),c(nstsv,nstsv))
   do ik=1,nkpt
-    call getevecsv(vkl(:,ik),evecsv)
-    call zgemm('N','N',nstsv,nstsv,nstsv,zone,kmatc(:,:,ik),nstsv,evecsv, &
-     nstsv,zzero,c,nstsv)
+    call getevecsv(filext,ik,vkl(:,ik),evecsv)
+    call getkmat(ik,kmat)
+    call zgemm('N','N',nstsv,nstsv,nstsv,zone,kmat,nstsv,evecsv,nstsv,zzero,c, &
+     nstsv)
     do ist=1,nstsv
       z1=zdotc(nstsv,evecsv(:,ist),1,c(:,ist),1)
       engykn=engykn+wkpt(ik)*occsv(ist,ik)*dble(z1)
     end do
   end do
-  deallocate(evecsv,c)
+  deallocate(evecsv,kmat,c)
 else
 ! Kohn-Sham case
-  allocate(rfmt(lmmaxvr,nrmtmax,natmtot))
+  allocate(rfmt(npmtmax,natmtot))
   sum=0.d0
   do idm=1,ndmag
     do ias=1,natmtot
       is=idxis(ias)
-      nrc=nrcmt(is)
-      nrci=nrcmtinr(is)
-      call rfsht(nrc,nrci,1,bsmt(:,:,ias,idm),lradstp,rfmt(:,:,ias))
+      call rfsht(nrcmt(is),nrcmti(is),bsmt(:,ias,idm),rfmt(:,ias))
     end do
     call rfmtctof(rfmt)
-    sum=sum+rfinp(1,magmt(:,:,:,idm),rfmt,magir(:,idm),bsir(:,idm))
+    sum=sum+rfinp(magmt(:,:,idm),magir(:,idm),rfmt,bsir(:,idm))
   end do
 ! remove fixed tensor moment potential matrix contribution
   if (ftmtype.ne.0) then
