@@ -11,8 +11,8 @@ subroutine eveqnfvr(nmatp,ngp,vpc,h,o,evalfv,evecfv)
 use modmain
 ! !INPUT/OUTPUT PARAMETERS:
 !   nmatp  : order of overlap and Hamiltonian matrices (in,integer)
-!   ngp    : number of G+k-vectors for augmented plane waves (in,integer)
-!   vpc    : k-vector in Cartesian coordinates (in,real(3))
+!   ngp    : number of G+p-vectors (in,integer)
+!   vpc    : p-vector in Cartesian coordinates (in,real(3))
 !   h,o    : Hamiltonian and overlap matrices in packed or upper triangular
 !            form (in,complex(*))
 !   evalfv : first-variational eigenvalues (out,real(nstfv))
@@ -231,10 +231,8 @@ do m1=1,nlotot
   end do
 end do
 ! solve the generalised eigenvalue problem for real symmetric matrices
-allocate(iwork(5*nmatp))
-allocate(ifail(nmatp))
-allocate(w(nmatp))
-allocate(rv(nmatp,nstfv))
+allocate(iwork(5*nmatp),ifail(nmatp))
+allocate(w(nmatp),rv(nmatp,nstfv))
 lwork=8*nmatp
 allocate(work(lwork))
 call dsygvx(1,'V','I','U',nmatp,rh,nmatp,ro,nmatp,vl,vu,1,nstfv,evaltol,m,w, &
@@ -279,8 +277,9 @@ end do
 deallocate(iwork,ifail,w,rv,work)
 deallocate(tr,tp,idx,s,map,rh,ro,zp)
 call timesec(ts1)
-!$OMP ATOMIC
+!$OMP CRITICAL
 timefv=timefv+ts1-ts0
+!$OMP END CRITICAL
 return
 end subroutine
 !EOC
