@@ -8,8 +8,7 @@ use modmain
 use moddftu
 implicit none
 ! arguments
-integer, intent(in) :: ngp(nspnfv)
-integer, intent(in) :: igpig(ngkmax,nspnfv)
+integer, intent(in) :: ngp(nspnfv),igpig(ngkmax,nspnfv)
 complex(8), intent(in) :: apwalm(ngkmax,apwordmax,lmmaxapw,natmtot,nspnfv)
 real(8), intent(in) :: evalfv(nstfv,nspnfv)
 complex(8), intent(in) :: evecfv(nmatmax,nstfv,nspnfv)
@@ -17,15 +16,17 @@ real(8), intent(out) :: evalsvp(nstsv)
 complex(8), intent(out) :: evecsv(nstsv,nstsv)
 ! local variables
 integer ld,ist,jst,ispn,jspn
-integer is,ia,ias,nrc,nrci,iro
-integer l,lm,lmi,nm,igp,ifg
+integer is,ia,ias
+integer nrc,nrci,nrco
+integer npc,npci
+integer l,lm,nm,igp,ifg
 integer i,j,k,lwork,info
 real(8) t1
 real(8) ts0,ts1
 complex(8) zq
 ! allocatable arrays
 real(8), allocatable :: rwork(:)
-complex(8), allocatable :: wfmt1(:,:,:,:),wfmt2(:,:,:),wfmt3(:,:),wfmt4(:,:,:)
+complex(8), allocatable :: wfmt1(:,:,:),wfmt2(:,:),wfmt3(:),wfmt4(:,:)
 complex(8), allocatable :: wfir1(:,:),wfir2(:),z(:,:),work(:)
 ! external functions
 complex(8) zdotc,zfmtinp
@@ -43,16 +44,17 @@ evecsv(:,:)=0.d0
 !-------------------------!
 !     muffin-tin part     !
 !-------------------------!
-lmi=lmmaxinr
-allocate(wfmt1(lmmaxvr,nrcmtmax,nstfv,nspnfv))
-allocate(wfmt2(lmmaxvr,nrcmtmax,nspnfv))
-allocate(wfmt3(lmmaxvr,nrcmtmax),wfmt4(lmmaxvr,nrcmtmax,3))
+allocate(wfmt1(npcmtmax,nstfv,nspnfv))
+allocate(wfmt2(npcmtmax,nspnfv))
+allocate(wfmt3(npcmtmax),wfmt4(npcmtmax,3))
 do ias=1,natmtot
   is=idxis(ias)
   ia=idxia(ias)
   nrc=nrcmt(is)
-  nrci=nrcmtinr(is)
-  iro=nrci+1
+  nrci=nrcmti(is)
+  nrco=nrc-nrci
+  npc=npcmt(is)
+  npci=npcmti(is)
 ! de-phasing factor (FC, FB & LN)
   t1=-0.5d0*dot_product(vqcss(:),atposc(:,ia,is))
   zq=cmplx(cos(t1),sin(t1),8)
@@ -60,29 +62,24 @@ do ias=1,natmtot
   do ispn=1,nspnfv
     if (ispn.eq.2) zq=conjg(zq)
     do ist=1,nstfv
-      call wavefmt(lradstp,lmaxvr,ias,ngp(ispn),apwalm(:,:,:,:,ispn), &
-       evecfv(:,ist,ispn),lmmaxvr,wfmt1(:,:,ist,ispn))
+      call wavefmt(lradstp,ias,ngp(ispn),apwalm(:,:,:,:,ispn), &
+       evecfv(:,ist,ispn),wfmt1(:,ist,ispn))
 ! de-phase if required
-      if (ssdph) wfmt1(:,1:nrc,ist,ispn)=zq*wfmt1(:,1:nrc,ist,ispn)
+      if (ssdph) wfmt1(1:npc,ist,ispn)=zq*wfmt1(1:npc,ist,ispn)
     end do
   end do
   do jst=1,nstfv
 ! convert wavefunction to spherical coordinates
     do ispn=1,nspnfv
-      call zbsht(nrc,nrci,wfmt1(:,:,jst,ispn),wfmt2(:,:,ispn))
+      call zbsht(nrc,nrci,wfmt1(:,jst,ispn),wfmt2(:,ispn))
     end do
 ! apply effective magnetic field and convert to spherical harmonics
-    wfmt3(1:lmi,1:nrci)=bsmt(1:lmi,1:nrci,ias,3)*wfmt2(1:lmi,1:nrci,1)
-    wfmt3(:,iro:nrc)=bsmt(:,iro:nrc,ias,3)*wfmt2(:,iro:nrc,1)
-    call zfsht(nrc,nrci,wfmt3,wfmt4(:,:,1))
-    wfmt3(1:lmi,1:nrci)=-bsmt(1:lmi,1:nrci,ias,3)*wfmt2(1:lmi,1:nrci,2)
-    wfmt3(:,iro:nrc)=-bsmt(:,iro:nrc,ias,3)*wfmt2(:,iro:nrc,2)
-    call zfsht(nrc,nrci,wfmt3,wfmt4(:,:,2))
-    wfmt3(1:lmi,1:nrci)=cmplx(bsmt(1:lmi,1:nrci,ias,1), &
-     -bsmt(1:lmi,1:nrci,ias,2),8)*wfmt2(1:lmi,1:nrci,2)
-    wfmt3(:,iro:nrc)=cmplx(bsmt(:,iro:nrc,ias,1), &
-     -bsmt(:,iro:nrc,ias,2),8)*wfmt2(:,iro:nrc,2)
-    call zfsht(nrc,nrci,wfmt3,wfmt4(:,:,3))
+    wfmt3(1:npc)=bsmt(1:npc,ias,3)*wfmt2(1:npc,1)
+    call zfsht(nrc,nrci,wfmt3,wfmt4(:,1))
+    wfmt3(1:npc)=-bsmt(1:npc,ias,3)*wfmt2(1:npc,2)
+    call zfsht(nrc,nrci,wfmt3,wfmt4(:,2))
+    wfmt3(1:npc)=cmplx(bsmt(1:npc,ias,1),-bsmt(1:npc,ias,2),8)*wfmt2(1:npc,2)
+    call zfsht(nrc,nrci,wfmt3,wfmt4(:,3))
 ! apply muffin-tin potential matrix if required
     if (tvmatmt) then
       do l=0,lmaxdm
@@ -100,13 +97,20 @@ do ias=1,natmtot
               ispn=1
               jspn=2
             end if
-            call zgemm('N','N',nm,nrc,nm,zone,vmatmt(lm,ispn,lm,jspn,ias),ld, &
-             wfmt1(lm,1,jst,jspn),lmmaxvr,zone,wfmt4(lm,1,k),lmmaxvr)
+            if (l.le.lmaxi) then
+              call zgemm('N','N',nm,nrci,nm,zone,vmatmt(lm,ispn,lm,jspn,ias), &
+               ld,wfmt1(lm,jst,jspn),lmmaxi,zone,wfmt4(lm,k),lmmaxi)
+            end if
+            i=npci+lm
+            call zgemm('N','N',nm,nrco,nm,zone,vmatmt(lm,ispn,lm,jspn,ias),ld, &
+             wfmt1(i,jst,jspn),lmmaxo,zone,wfmt4(i,k),lmmaxo)
           end do
         end if
       end do
     end if
 ! second-variational Hamiltonian matrix
+!$OMP PARALLEL DEFAULT(SHARED) PRIVATE(i,j,k,ispn)
+!$OMP DO
     do ist=1,nstfv
       do k=1,3
         if (k.eq.1) then
@@ -123,11 +127,13 @@ do ias=1,natmtot
           j=jst+nstfv
         end if
         if (i.le.j) then
-          evecsv(i,j)=evecsv(i,j)+zfmtinp(.true.,nrc,nrci,rcmt(:,is), &
-           wfmt1(:,:,ist,ispn),wfmt4(:,:,k))
+          evecsv(i,j)=evecsv(i,j)+zfmtinp(nrc,nrci,rcmt(:,is),r2cmt(:,is), &
+           wfmt1(:,ist,ispn),wfmt4(:,k))
         end if
       end do
     end do
+!$OMP END DO
+!$OMP END PARALLEL
   end do
 end do
 deallocate(wfmt1,wfmt2,wfmt3,wfmt4)
@@ -165,6 +171,8 @@ do jst=1,nstfv
     z(igp,3)=wfir2(ifg)
   end do
 ! add to Hamiltonian matrix
+!$OMP PARALLEL DEFAULT(SHARED) PRIVATE(i,j,k,ispn)
+!$OMP DO
   do ist=1,nstfv
     do k=1,3
       if (k.eq.1) then
@@ -185,6 +193,8 @@ do jst=1,nstfv
       end if
     end do
   end do
+!$OMP END DO
+!$OMP END PARALLEL
 end do
 deallocate(wfir1,wfir2,z)
 ! add the diagonal first-variational part
@@ -210,8 +220,9 @@ if (info.ne.0) then
 end if
 deallocate(rwork,work)
 call timesec(ts1)
-!$OMP ATOMIC
+!$OMP CRITICAL
 timesv=timesv+ts1-ts0
+!$OMP END CRITICAL
 return
 end subroutine
 
