@@ -9,8 +9,7 @@ use modmain
 use moddftu
 implicit none
 ! arguments
-integer, intent(in) :: ngp
-integer, intent(in) :: igpig(ngkmax)
+integer, intent(in) :: ngp,igpig(ngkmax)
 real(8), intent(in) :: vgpc(3,ngkmax)
 complex(8), intent(in) :: apwalm(ngkmax,apwordmax,lmmaxapw,natmtot)
 real(8), intent(in) :: evalfv(nstfv)
@@ -18,20 +17,22 @@ complex(8), intent(in) :: evecfv(nmatmax,nstfv)
 real(8), intent(out) :: evalsvp(nstsv)
 complex(8), intent(out) :: evecsv(nstsv,nstsv)
 ! local variables
+logical socz
 integer nsc,nsd,ld,ist,jst
 integer ispn,jspn,is,ias
-integer nrc,nrci,iro,irc
-integer l,lm,lmi,nm,igp,ifg
+integer nrc,nrci,nrco
+integer irco,irc,npc,npci
+integer l,lm,nm,igp,ifg
 integer i,j,k,lwork,info
 real(8) ca,t1
 real(8) ts0,ts1
 complex(8) z1
 ! automatic arrays
-complex(8) zlflm(lmmaxvr,3)
+complex(8) zlflm(lmmaxo,3)
 ! allocatable arrays
 real(8), allocatable :: rwork(:)
-complex(8), allocatable :: wfmt1(:,:,:),wfmt2(:,:),wfmt3(:,:),wfmt4(:,:,:)
-complex(8), allocatable :: gwfmt(:,:,:),wfir1(:),wfir2(:),z(:,:),work(:)
+complex(8), allocatable :: wfmt1(:,:),wfmt2(:),wfmt3(:),wfmt4(:,:)
+complex(8), allocatable :: gwfmt(:,:),wfir1(:),wfir2(:),z(:,:),work(:)
 ! external functions
 complex(8) zdotc,zfmtinp
 external zdotc,zfmtinp
@@ -51,7 +52,7 @@ call timesec(ts0)
 ca=1.d0/solsc
 ! number of spin combinations after application of Hamiltonian
 if (spinpol) then
-  if (ncmag) then
+  if (ncmag.or.spinorb) then
     nsc=3
   else
     nsc=2
@@ -61,75 +62,82 @@ else
   nsc=1
   nsd=1
 end if
+! special case of spin-orbit coupling and collinear magnetism
+if (spinorb.and.cmagz) then
+  socz=.true.
+else
+  socz=.false.
+end if
 ld=lmmaxdm*nspinor
 ! zero the second-variational Hamiltonian (stored in the eigenvector array)
 evecsv(:,:)=0.d0
 !-------------------------!
 !     muffin-tin part     !
 !-------------------------!
-lmi=lmmaxinr
+allocate(wfmt1(npcmtmax,nstfv),wfmt2(npcmtmax))
+allocate(wfmt3(npcmtmax),wfmt4(npcmtmax,nsc))
+if (afieldpol) allocate(gwfmt(npcmtmax,3))
 ! begin loop over atoms
-!$OMP PARALLEL DEFAULT(SHARED) &
-!$OMP PRIVATE(wfmt1,wfmt2,wfmt3,wfmt4,gwfmt) &
-!$OMP PRIVATE(is,nrc,nrci,iro,ist,jst,irc,zlflm) &
-!$OMP PRIVATE(t1,l,nm,lm,i,j,k,ispn,jspn)
-!$OMP DO
 do ias=1,natmtot
-  allocate(wfmt1(lmmaxvr,nrcmtmax,nstfv),wfmt2(lmmaxvr,nrcmtmax))
-  allocate(wfmt3(lmmaxvr,nrcmtmax),wfmt4(lmmaxvr,nrcmtmax,nsc))
-  if (afieldpol) allocate(gwfmt(lmmaxvr,nrcmtmax,3))
   is=idxis(ias)
   nrc=nrcmt(is)
-  nrci=nrcmtinr(is)
-  iro=nrci+1
+  nrci=nrcmti(is)
+  nrco=nrc-nrci
+  irco=nrci+1
+  npc=npcmt(is)
+  npci=npcmti(is)
 ! compute the first-variational wavefunctions
   do ist=1,nstfv
-    call wavefmt(lradstp,lmaxvr,ias,ngp,apwalm,evecfv(:,ist),lmmaxvr, &
-     wfmt1(:,:,ist))
+    call wavefmt(lradstp,ias,ngp,apwalm,evecfv(:,ist),wfmt1(:,ist))
   end do
 ! begin loop over states
   do jst=1,nstfv
     if (spinpol) then
 ! convert wavefunction to spherical coordinates
-      call zbsht(nrc,nrci,wfmt1(:,:,jst),wfmt2)
+      call zbsht(nrc,nrci,wfmt1(:,jst),wfmt2)
 ! apply Kohn-Sham effective magnetic field
-      wfmt3(1:lmi,1:nrci)=bsmt(1:lmi,1:nrci,ias,ndmag)*wfmt2(1:lmi,1:nrci)
-      wfmt3(:,iro:nrc)=bsmt(:,iro:nrc,ias,ndmag)*wfmt2(:,iro:nrc)
+      wfmt3(1:npc)=bsmt(1:npc,ias,ndmag)*wfmt2(1:npc)
 ! convert to spherical harmonics and store in wfmt4
-      call zfsht(nrc,nrci,wfmt3,wfmt4(:,:,1))
-      wfmt4(1:lmi,1:nrci,2)=-wfmt4(1:lmi,1:nrci,1)
-      wfmt4(:,iro:nrc,2)=-wfmt4(:,iro:nrc,1)
+      call zfsht(nrc,nrci,wfmt3,wfmt4(:,1))
+      wfmt4(1:npc,2)=-wfmt4(1:npc,1)
 ! non-collinear magnetic field
       if (ncmag) then
-        wfmt3(1:lmi,1:nrci)=cmplx(bsmt(1:lmi,1:nrci,ias,1), &
-         -bsmt(1:lmi,1:nrci,ias,2),8)*wfmt2(1:lmi,1:nrci)
-        wfmt3(:,iro:nrc)=cmplx(bsmt(:,iro:nrc,ias,1), &
-         -bsmt(:,iro:nrc,ias,2),8)*wfmt2(:,iro:nrc)
-        call zfsht(nrc,nrci,wfmt3,wfmt4(:,:,3))
+        wfmt3(1:npc)=cmplx(bsmt(1:npc,ias,1),-bsmt(1:npc,ias,2),8)*wfmt2(1:npc)
+        call zfsht(nrc,nrci,wfmt3,wfmt4(:,3))
       end if
+      if (socz) wfmt4(1:npc,3)=0.d0
 ! apply spin-orbit coupling if required
       if (spinorb) then
 ! inner part of muffin-tin
+        i=1
         do irc=1,nrci
-          call lopzflm(lmaxinr,wfmt1(:,irc,jst),lmmaxvr,zlflm)
+          call lopzflm(lmaxi,wfmt1(i,jst),lmmaxo,zlflm)
           t1=socfr(irc,ias)
-          wfmt4(1:lmi,irc,1)=wfmt4(1:lmi,irc,1)+t1*zlflm(1:lmi,3)
-          wfmt4(1:lmi,irc,2)=wfmt4(1:lmi,irc,2)-t1*zlflm(1:lmi,3)
-          if (ncmag) wfmt4(1:lmi,irc,3)=wfmt4(1:lmi,irc,3)+t1*(zlflm(1:lmi,1) &
-           +cmplx(aimag(zlflm(1:lmi,2)),-dble(zlflm(1:lmi,2)),8))
+          do j=1,lmmaxi
+            wfmt4(i,1)=wfmt4(i,1)+t1*zlflm(j,3)
+            wfmt4(i,2)=wfmt4(i,2)-t1*zlflm(j,3)
+            wfmt4(i,3)=wfmt4(i,3)+t1*(zlflm(j,1) &
+             +cmplx(aimag(zlflm(j,2)),-dble(zlflm(j,2)),8))
+            i=i+1
+          end do
         end do
 ! outer part of muffin-tin
-        do irc=iro,nrc
-          call lopzflm(lmaxvr,wfmt1(:,irc,jst),lmmaxvr,zlflm)
+        do irc=irco,nrc
+          call lopzflm(lmaxo,wfmt1(i,jst),lmmaxo,zlflm)
           t1=socfr(irc,ias)
-          wfmt4(:,irc,1)=wfmt4(:,irc,1)+t1*zlflm(:,3)
-          wfmt4(:,irc,2)=wfmt4(:,irc,2)-t1*zlflm(:,3)
-          if (ncmag) wfmt4(:,irc,3)=wfmt4(:,irc,3)+t1*(zlflm(:,1) &
-           +cmplx(aimag(zlflm(:,2)),-dble(zlflm(:,2)),8))
+          do j=1,lmmaxo
+            wfmt4(i,1)=wfmt4(i,1)+t1*zlflm(j,3)
+            wfmt4(i,2)=wfmt4(i,2)-t1*zlflm(j,3)
+            wfmt4(i,3)=wfmt4(i,3)+t1*(zlflm(j,1) &
+             +cmplx(aimag(zlflm(j,2)),-dble(zlflm(j,2)),8))
+            i=i+1
+          end do
         end do
       end if
     else
-      wfmt4(:,:,:)=0.d0
+      do k=1,nsc
+        wfmt4(1:npc,k)=0.d0
+      end do
     end if
 ! apply muffin-tin potential matrix if required
     if (tvmatmt) then
@@ -148,26 +156,29 @@ do ias=1,natmtot
               ispn=1
               jspn=2
             end if
-            call zgemm('N','N',nm,nrc,nm,zone,vmatmt(lm,ispn,lm,jspn,ias),ld, &
-             wfmt1(lm,1,jst),lmmaxvr,zone,wfmt4(lm,1,k),lmmaxvr)
+            if (l.le.lmaxi) then
+              call zgemm('N','N',nm,nrci,nm,zone,vmatmt(lm,ispn,lm,jspn,ias), &
+               ld,wfmt1(lm,jst),lmmaxi,zone,wfmt4(lm,k),lmmaxi)
+            end if
+            i=npci+lm
+            call zgemm('N','N',nm,nrco,nm,zone,vmatmt(lm,ispn,lm,jspn,ias),ld, &
+             wfmt1(i,jst),lmmaxo,zone,wfmt4(i,k),lmmaxo)
           end do
         end if
       end do
     end if
 ! apply vector potential if required
     if (afieldpol) then
-      call gradzfmt(nrc,nrci,rcmt(:,is),wfmt1(:,:,jst),nrcmtmax,gwfmt)
-      do irc=1,nrc
-        wfmt3(:,irc)=afieldc(1)*gwfmt(:,irc,1) &
-                    +afieldc(2)*gwfmt(:,irc,2) &
-                    +afieldc(3)*gwfmt(:,irc,3)
-        wfmt3(:,irc)=ca*cmplx(aimag(wfmt3(:,irc)),-dble(wfmt3(:,irc)),8)
-      end do
-      do k=1,nsd
-        wfmt4(:,1:nrc,k)=wfmt4(:,1:nrc,k)+wfmt3(:,1:nrc)
+      call gradzfmt(nrc,nrci,rcmt(:,is),wfmt1(:,jst),npcmtmax,gwfmt)
+      do i=1,npc
+        z1=afieldc(1)*gwfmt(i,1)+afieldc(2)*gwfmt(i,2)+afieldc(3)*gwfmt(i,3)
+        z1=ca*cmplx(-aimag(z1),dble(z1),8)
+        wfmt4(i,1:nsd)=wfmt4(i,1:nsd)+z1
       end do
     end if
 ! second-variational Hamiltonian matrix
+!$OMP PARALLEL DEFAULT(SHARED) PRIVATE(i,j,k)
+!$OMP DO
     do ist=1,nstfv
       do k=1,nsc
         if (k.eq.1) then
@@ -181,31 +192,27 @@ do ias=1,natmtot
           j=jst+nstfv
         end if
         if (i.le.j) then
-!$OMP ATOMIC
-          evecsv(i,j)=evecsv(i,j)+zfmtinp(.true.,nrc,nrci,rcmt(:,is), &
-           wfmt1(:,:,ist),wfmt4(:,:,k))
+          evecsv(i,j)=evecsv(i,j)+zfmtinp(nrc,nrci,rcmt(:,is),r2cmt(:,is), &
+           wfmt1(:,ist),wfmt4(:,k))
         end if
       end do
     end do
-! end loop over states
-  end do
-  deallocate(wfmt1,wfmt2,wfmt3,wfmt4)
-  if (afieldpol) deallocate(gwfmt)
-! end loop over atoms
-end do
 !$OMP END DO
 !$OMP END PARALLEL
+! end loop over states
+  end do
+! end loop over atoms
+end do
+deallocate(wfmt1,wfmt2,wfmt3,wfmt4)
+if (afieldpol) deallocate(gwfmt)
 !---------------------------!
 !     interstitial part     !
 !---------------------------!
 if (spinpol) then
+  if (socz) nsc=2
+  allocate(wfir1(ngtot),wfir2(ngtot),z(ngkmax,nsc))
 ! begin loop over states
-!$OMP PARALLEL DEFAULT(SHARED) &
-!$OMP PRIVATE(wfir1,wfir2,z) &
-!$OMP PRIVATE(igp,ifg,t1,z1,i,j,k,ist)
-!$OMP DO
   do jst=1,nstfv
-    allocate(wfir1(ngtot),wfir2(ngtot),z(ngkmax,nsc))
     wfir1(:)=0.d0
     do igp=1,ngp
       ifg=igfft(igpig(igp))
@@ -219,8 +226,8 @@ if (spinpol) then
     do igp=1,ngp
       ifg=igfft(igpig(igp))
       z(igp,1)=wfir2(ifg)
-      z(igp,2)=-wfir2(ifg)
     end do
+    z(1:ngp,2)=-z(1:ngp,1)
     if (ncmag) then
       wfir2(:)=cmplx(bsir(:,1),-bsir(:,2),8)*wfir1(:)
       call zfftifc(3,ngridg,-1,wfir2)
@@ -238,12 +245,12 @@ if (spinpol) then
         ifg=igfft(igpig(igp))
         t1=ca*dot_product(afieldc(:),vgpc(:,igp))
         z1=t1*wfir1(ifg)
-        do k=1,nsd
-          z(igp,k)=z(igp,k)+z1
-        end do
+        z(igp,1:nsd)=z(igp,1:nsd)+z1
       end do
     end if
 ! add to Hamiltonian matrix
+!$OMP PARALLEL DEFAULT(SHARED) PRIVATE(i,j,k)
+!$OMP DO
     do ist=1,nstfv
       do k=1,nsc
         if (k.eq.1) then
@@ -257,16 +264,15 @@ if (spinpol) then
           j=jst+nstfv
         end if
         if (i.le.j) then
-!$OMP ATOMIC
           evecsv(i,j)=evecsv(i,j)+zdotc(ngp,evecfv(:,ist),1,z(:,k),1)
         end if
       end do
     end do
-    deallocate(wfir1,wfir2,z)
-! end loop over states
-  end do
 !$OMP END DO
 !$OMP END PARALLEL
+! end loop over states
+  end do
+  deallocate(wfir1,wfir2,z)
 end if
 ! add the diagonal first-variational part
 i=0
@@ -280,30 +286,31 @@ end do
 allocate(rwork(3*nstsv))
 lwork=2*nstsv
 allocate(work(lwork))
-if (ndmag.eq.1) then
-! collinear: block diagonalise H
+if (spcpl.or.(.not.spinpol)) then
+! spins are coupled; or spin-unpolarised: full diagonalisation
+  call zheev('V','U',nstsv,evecsv,nstsv,evalsvp,work,lwork,rwork,info)
+  if (info.ne.0) goto 10
+else
+! spins not coupled: block diagonalise H
   call zheev('V','U',nstfv,evecsv,nstsv,evalsvp,work,lwork,rwork,info)
-  if (info.ne.0) goto 20
+  if (info.ne.0) goto 10
   i=nstfv+1
   call zheev('V','U',nstfv,evecsv(i,i),nstsv,evalsvp(i),work,lwork,rwork,info)
-  if (info.ne.0) goto 20
+  if (info.ne.0) goto 10
   do i=1,nstfv
     do j=1,nstfv
       evecsv(i,j+nstfv)=0.d0
       evecsv(i+nstfv,j)=0.d0
     end do
   end do
-else
-! non-collinear or spin-unpolarised: full diagonalisation
-  call zheev('V','U',nstsv,evecsv,nstsv,evalsvp,work,lwork,rwork,info)
-  if (info.ne.0) goto 20
 end if
 deallocate(rwork,work)
 call timesec(ts1)
-!$OMP ATOMIC
+!$OMP CRITICAL
 timesv=timesv+ts1-ts0
+!$OMP END CRITICAL
 return
-20 continue
+10 continue
 write(*,*)
 write(*,'("Error(eveqnsv): diagonalisation of the second-variational &
  &Hamiltonian failed")')
@@ -311,3 +318,4 @@ write(*,'(" ZHEEV returned INFO = ",I8)') info
 write(*,*)
 stop
 end subroutine
+
