@@ -8,15 +8,14 @@ use modmain
 implicit none
 ! arguments
 real(8), intent(in) :: vpl(3)
-integer, intent(out) :: isym
-integer, intent(out) :: ik
+integer, intent(out) :: isym,ik
 ! local variables
 integer ivp(3),lspl
 real(8) v1(3),v2(3),t1
 v1(:)=vpl(:)-vkloff(:)/dble(ngridk(:))
 ivp(:)=nint(v1(:)*ngridk(:))
 ivp(:)=modulo(ivp(:),ngridk(:))
-ik=ikmap(ivp(1),ivp(2),ivp(3))
+ik=ivkik(ivp(1),ivp(2),ivp(3))
 v1(:)=vkl(:,ik)
 call r3frac(epslat,v1)
 ! find the symmetry which maps vpl to k-point ik
