@@ -23,15 +23,9 @@ implicit none
 integer, intent(in) :: x,y
 ! local variables
 integer a,b,c
-if (x.le.0) then
+if ((x.le.0).or.(y.le.0)) then
   write(*,*)
-  write(*,'("Error(gcd): x <= 0 : ",I8)') x
-  write(*,*)
-  stop
-end if
-if (y.le.0) then
-  write(*,*)
-  write(*,'("Error(gcd): y <= 0 : ",I8)') y
+  write(*,'("Error(gcd): x <= 0 or y <= 0 : ",2I8)') x,y
   write(*,*)
   stop
 end if
