@@ -28,50 +28,62 @@ use modmain
 implicit none
 ! local variables
 integer is,ia,ja,ias,jas
-integer nr,ir,nn,l,io,jo
-real(8) t1
+integer nr,nri,ir,i
+integer nn,l,io,jo
+real(8) e,t1
 ! automatic arrays
 logical done(natmmax)
-real(8) vr(nrmtmax),fr(nrmtmax),gr(nrmtmax)
+real(8) vr(nrmtmax),fr(nrmtmax)
 real(8) p0(nrmtmax,apwordmax),p1(nrmtmax),p1s(apwordmax)
-real(8) q0(nrmtmax,apwordmax),q1(nrmtmax,apwordmax)
-real(8) hp0(nrmtmax)
+real(8) q0(nrmtmax),q1(nrmtmax),ep0(nrmtmax,apwordmax)
+! external functions
+real(8) fintgt
+external fintgt
 do is=1,nspecies
   nr=nrmt(is)
+  nri=nrmti(is)
   done(:)=.false.
   do ia=1,natoms(is)
     if (done(ia)) cycle
     ias=idxas(ia,is)
 ! use spherical part of potential
-    vr(1:nr)=vsmt(1,1:nr,ias)*y00
+    i=1
+    do ir=1,nri
+      vr(ir)=vsmt(i,ias)*y00
+      i=i+lmmaxi
+    end do
+    do ir=nri+1,nr
+      vr(ir)=vsmt(i,ias)*y00
+      i=i+lmmaxo
+    end do
     do l=0,lmaxapw
       do io=1,apword(l,is)
+! linearisation energy accounting for energy derivative
+        e=apwe(io,l,ias)+dble(apwdm(io,l,is))*deapwlo
 ! integrate the radial Schrodinger equation
-        call rschroddme(solsc,apwdm(io,l,is),l,0,apwe(io,l,ias),nr,spr(:,is), &
-         vr,nn,p0(:,io),p1,q0(:,io),q1(:,io))
+        call rschrodint(solsc,l,e,nr,rsp(:,is),vr,nn,p0(:,io),p1,q0,q1)
+! multiply by the linearisation energy
+        ep0(1:nr,io)=e*p0(1:nr,io)
 ! normalise radial functions
         fr(1:nr)=p0(1:nr,io)**2
-        call fderiv(-1,nr,spr(:,is),fr,gr)
-        t1=1.d0/sqrt(abs(gr(nr)))
+        t1=fintgt(-1,nr,rsp(:,is),fr)
+        t1=1.d0/sqrt(abs(t1))
         call dscal(nr,t1,p0(:,io),1)
         p1s(io)=t1*p1(nr)
-        call dscal(nr,t1,q0(:,io),1)
-        call dscal(nr,t1,q1(:,io),1)
+        call dscal(nr,t1,ep0(:,io),1)
 ! subtract linear combination of previous vectors
         do jo=1,io-1
           fr(1:nr)=p0(1:nr,io)*p0(1:nr,jo)
-          call fderiv(-1,nr,spr(:,is),fr,gr)
-          t1=-gr(nr)
+          t1=-fintgt(-1,nr,rsp(:,is),fr)
           call daxpy(nr,t1,p0(:,jo),1,p0(:,io),1)
           p1s(io)=p1s(io)+t1*p1s(jo)
-          call daxpy(nr,t1,q0(:,jo),1,q0(:,io),1)
-          call daxpy(nr,t1,q1(:,jo),1,q1(:,io),1)
+          call daxpy(nr,t1,ep0(:,jo),1,ep0(:,io),1)
         end do
 ! normalise radial functions again
         fr(1:nr)=p0(1:nr,io)**2
-        call fderiv(-1,nr,spr(:,is),fr,gr)
-        t1=abs(gr(nr))
-        if (t1.lt.1.d-14) then
+        t1=fintgt(-1,nr,rsp(:,is),fr)
+        t1=abs(t1)
+        if (t1.lt.1.d-25) then
           write(*,*)
           write(*,'("Error(genapwfr): degenerate APW radial functions")')
           write(*,'(" for species ",I4)') is
@@ -84,15 +96,12 @@ do is=1,nspecies
         t1=1.d0/sqrt(t1)
         call dscal(nr,t1,p0(:,io),1)
         p1s(io)=t1*p1s(io)
-        call dscal(nr,t1,q0(:,io),1)
-        call dscal(nr,t1,q1(:,io),1)
-! apply the Hamiltonian
-        call rschrodapp(solsc,l,nr,spr(:,is),vr,p0(:,io),q0(:,io),q1(:,io),hp0)
+        call dscal(nr,t1,ep0(:,io),1)
 ! divide by r and store in global array
         do ir=1,nr
-          t1=1.d0/spr(ir,is)
+          t1=1.d0/rsp(ir,is)
           apwfr(ir,1,io,l,ias)=t1*p0(ir,io)
-          apwfr(ir,2,io,l,ias)=t1*hp0(ir)
+          apwfr(ir,2,io,l,ias)=t1*ep0(ir,io)
         end do
 ! derivative at the muffin-tin surface
         apwdfr(io,l,ias)=(p1s(io)-p0(nr,io)*t1)*t1
