@@ -20,63 +20,44 @@ use moddftu
 !BOC
 implicit none
 ! local variables
-integer is,ia,ias,i
-integer l,nn,io,nr,ir
+integer is,ia,ias
+integer nr,nri,ir
+integer nn,i,l
 real(8) t1
 ! automatic arrays
-real(8) vr(nrmtmax),fr(nrmtmax),gr(nrmtmax)
-real(8) p0(nrmtmax,apwordmax),p1(nrmtmax),p1s(apwordmax)
-real(8) q0(nrmtmax,apwordmax),q1(nrmtmax,apwordmax)
-real(8) hp0(nrmtmax)
+real(8) vr(nrmtmax),fr(nrmtmax)
+real(8) p0(nrmtmax),p1(nrmtmax),q0(nrmtmax),q1(nrmtmax)
+! external functions
+real(8) fintgt
+external fintgt
 do i=1,ndftu
   is=idftu(1,i)
   l=idftu(2,i)
-  io=1
   nr=nrmt(is)
+  nri=nrmti(is)
   do ia=1,natoms(is)
     ias=idxas(ia,is)
-    vr(1:nr)=vsmt(1,1:nr,ias)*y00
+    call rfmtlm(1,nr,nri,vsmt(:,ias),vr)
+    vr(1:nr)=vr(1:nr)*y00
 ! integrate the radial Schrodinger equation
-    call rschroddme(solsc,0,l,0,fdue(io,l,ias),nr,spr(1,is),vr,nn,p0(1,io),p1, &
-     q0(1,io),q1(1,io))
+    call rschrodint(solsc,l,fdue(l,ias),nr,rsp(:,is),vr,nn,p0,p1,q0,q1)
 ! normalise radial functions
-    do ir=1,nr
-      fr(ir)=p0(ir,io)**2
-    end do
-    call fderiv(-1,nr,spr(1,is),fr,gr)
-    t1=1.d0/sqrt(abs(gr(nr)))
-    p0(1:nr,io)=t1*p0(1:nr,io)
-    p1s(io)=t1*p1(nr)
-    q0(1:nr,io)=t1*q0(1:nr,io)
-    q1(1:nr,io)=t1*q1(1:nr,io)
-! normalise radial functions
-    do ir=1,nr
-      fr(ir)=p0(ir,io)**2
-    end do
-    call fderiv(-1,nr,spr(1,is),fr,gr)
-    t1=abs(gr(nr))
+    fr(1:nr)=p0(1:nr)**2
+    t1=fintgt(-1,nr,rsp(:,is),fr)
     if (t1.lt.1.d-20) then
       write(*,*)
       write(*,'("Error(genfdufr): degenerate APW radial functions")')
       write(*,'(" for species ",I4)') is
       write(*,'(" atom ",I4)') ia
-      write(*,'(" angular momentum ",I4)') l
-      write(*,'(" and order ",I4)') io
+      write(*,'(" and angular momentum ",I4)') l
       write(*,*)
       stop
     end if
-    t1=1.d0/sqrt(t1)
-    p0(1:nr,io)=t1*p0(1:nr,io)
-    p1s(io)=t1*p1s(io)
-    q0(1:nr,io)=t1*q0(1:nr,io)
-    q1(1:nr,io)=t1*q1(1:nr,io)
-! apply the Hamiltonian
-    call rschrodapp(solsc,l,nr,spr(1,is),vr,p0(1,io),q0(1,io),q1(1,io),hp0)
+    t1=1.d0/sqrt(abs(t1))
+    p0(1:nr)=t1*p0(1:nr)
 ! divide by r and store in global array
     do ir=1,nr
-      t1=1.d0/spr(ir,is)
-      fdufr(ir,1,io,l,ias)=t1*p0(ir,io)
-      fdufr(ir,2,io,l,ias)=t1*hp0(ir)
+      fdufr(ir,l,ias)=p0(ir)/rsp(ir,is)
     end do
   end do
 end do
