@@ -25,14 +25,6 @@ do ig=1,ngtot
     ffacgp(ig)=(t1/3.d0)*rmt(is)**3
   end if
 end do
-! apply damping if required
-if (ffdamp) then
-  do ig=1,ngvec
-    t1=(1.d0-(gpc(ig)/gmaxvr)**12)**4
-    ffacgp(ig)=ffacgp(ig)*t1
-  end do
-  ffacgp(ngvec+1:ngtot)=0.d0
-end if
 return
 end subroutine
 
