@@ -10,7 +10,7 @@ implicit none
 real(8), intent(in) :: vqpc(3)
 integer, intent(out) :: igq0
 real(8), intent(out) :: vgqc(3,ngrf),gqc(ngrf)
-complex(8), intent(out) :: ylmgq(lmmaxvr,ngrf)
+complex(8), intent(out) :: ylmgq(lmmaxo,ngrf)
 complex(8), intent(out) :: sfacgq(ngrf,natmtot)
 ! local variables
 integer ig
@@ -21,7 +21,7 @@ do ig=1,ngrf
 ! G+q-vector length and (theta, phi) coordinates
   call sphcrd(vgqc(:,ig),gqc(ig),tp)
 ! spherical harmonics for G+q-vectors
-  call genylm(lmaxvr,tp,ylmgq(:,ig))
+  call genylm(lmaxo,tp,ylmgq(:,ig))
 end do
 ! structure factors for G+q
 call gensfacgp(ngrf,vgqc,ngrf,sfacgq)
