@@ -6,20 +6,9 @@
 !BOP
 ! !ROUTINE: gengvec
 ! !INTERFACE:
-subroutine gengvec(ngridg,ngtot,intgv,bvec,gmaxvr,ngvec,ivg,ivgig,igfft,vgc,gc)
-! !INPUT/OUTPUT PARAMETERS:
-!   ngridg : G-vector grid sizes (in,integer(3))
-!   ngtot  : total number of G-vectors (in,integer)
-!   intgv  : integer grid intervals for each direction (in,intgv(2,3))
-!   bvec   : reciprocal lattice vectors (in,real(3,3))
-!   gmaxvr : G-vector cut-off (in,gmaxvr)
-!   ngvec  : number of G-vectors with G < gmaxvr (out,integer)
-!   ivg    : G-vector integer coordinates (out,integer(3,ngtot))
-!   ivgig  : map from (i1,i2,i3) to G-vector index (out,integer(intgv(1,1):
-!            intgv(2,1),intgv(1,2):intgv(2,2),intgv(1,3):intgv(2,3)))
-!   igfft  : map from G-vector array to FFT array (out,integer(ngtot))
-!   vgc    : G-vectors in Cartesian coordinates (out,real(3,ngtot))
-!   gc     : length of G-vectors (out,real(ngtot))
+subroutine gengvec
+! !USES:
+use modmain
 ! !DESCRIPTION:
 !   Generates a set of ${\bf G}$-vectors used for the Fourier transform of the
 !   charge density and potential and sorts them according to length. Integers
@@ -31,26 +20,12 @@ subroutine gengvec(ngridg,ngtot,intgv,bvec,gmaxvr,ngvec,ivg,ivgig,igfft,vgc,gc)
 !
 ! !REVISION HISTORY:
 !   Created October 2002 (JKD)
-!   Removed modmain and added arguments, September 2012 (JKD)
 !EOP
 !BOC
 implicit none
-! arguments
-integer, intent(in) :: ngridg(3)
-integer, intent(in) :: ngtot
-integer, intent(in) :: intgv(2,3)
-real(8), intent(in) :: bvec(3,3)
-real(8), intent(in) :: gmaxvr
-integer, intent(out) :: ngvec
-integer, intent(out) :: ivg(3,ngtot)
-integer, intent(out) :: ivgig(*)
-integer, intent(out) :: igfft(ngtot)
-real(8), intent(out) :: vgc(3,ngtot)
-real(8), intent(out) :: gc(ngtot)
 ! local variables
-integer ig,jg
-integer i1,i2,i3,j1,j2,j3
-real(8) v1(3),v2(3),v3(3)
+integer ig,jg,i1,i2,i3,j1,j2,j3
+real(8) v1(3),v2(3),v3(3),t1
 ! allocatable arrays
 integer, allocatable :: idx(:),ivg0(:,:)
 real(8), allocatable :: vgc0(:,:),gc0(:)
@@ -78,7 +53,7 @@ do i1=intgv(1,1),intgv(2,1)
 end do
 ! sort by vector length
 call sortidx(ngtot,gc0,idx)
-! re-order arrays
+! reorder arrays
 do ig=1,ngtot
   jg=idx(ig)
   ivg(:,ig)=ivg0(:,jg)
@@ -87,9 +62,18 @@ do ig=1,ngtot
 end do
 ! find the number of vectors with G < gmaxvr
 ngvec=1
-do ig=ngtot,1,-1
-  if (gc(ig).lt.gmaxvr) then
-    ngvec=ig
+do ig=2,ngtot
+  if (gc(ig).gt.gmaxvr) then
+    ngvec=ig-1
+    exit
+  end if
+end do
+! find the number of vectors with G < gmaxvr/2
+t1=gmaxvr/2.d0
+ngv2=1
+do ig=2,ngvec
+  if (gc(ig).gt.t1) then
+    ngv2=ig-1
     exit
   end if
 end do
@@ -99,11 +83,7 @@ do ig=1,ngtot
   i2=ivg(2,ig)
   i3=ivg(3,ig)
 ! map from (i1,i2,i3) to G-vector index
-  j1=i1-intgv(1,1)
-  j2=i2-intgv(1,2)
-  j3=i3-intgv(1,3)
-  jg=j3*ngridg(2)*ngridg(1)+j2*ngridg(1)+j1+1
-  ivgig(jg)=ig
+  ivgig(i1,i2,i3)=ig
 ! Fourier transform index
   if (i1.ge.0) then
     j1=i1
