@@ -8,7 +8,7 @@ use modmain
 implicit none
 ! arguments
 real(8), intent(in) :: gq0
-real(8), intent(out) :: jlgq0r(0:lmaxvr,nrcmtmax,nspecies)
+real(8), intent(out) :: jlgq0r(0:lmaxo,nrcmtmax,nspecies)
 ! local variables
 integer is,irc
 real(8) t1
@@ -17,7 +17,7 @@ real(8) t1
 do is=1,nspecies
   do irc=1,nrcmt(is)
     t1=gq0*rcmt(irc,is)
-    call sbessel(lmaxvr,t1,jlgq0r(:,irc,is))
+    call sbessel(lmaxo,t1,jlgq0r(:,irc,is))
   end do
 end do
 !$OMP END DO
