@@ -24,59 +24,58 @@ implicit none
 integer is,ir,irc
 real(8) t1,t2
 ! estimate the number of radial mesh points to infinity
-spnrmax=1
+nrspmax=1
 do is=1,nspecies
 ! logarithmic mesh
-  t1=log(sprmax(is)/sprmin(is))/log(rmt(is)/sprmin(is))
+  t1=log(rmaxsp(is)/rminsp(is))/log(rmt(is)/rminsp(is))
   t2=dble(nrmt(is)-1)*t1
-  spnr(is)=nint(t2)+1
-  spnrmax=max(spnrmax,spnr(is))
+  nrsp(is)=nint(t2)+1
+  nrspmax=max(nrspmax,nrsp(is))
 end do
-! allocate the global radial mesh arrays
-if (allocated(spr)) deallocate(spr)
-allocate(spr(spnrmax,nspecies))
-if (allocated(rcmt)) deallocate(rcmt)
-allocate(rcmt(nrcmtmax,nspecies))
 ! generate the radial meshes
+if (allocated(rsp)) deallocate(rsp)
+allocate(rsp(nrspmax,nspecies))
+if (allocated(r2sp)) deallocate(r2sp)
+allocate(r2sp(nrspmax,nspecies))
 do is=1,nspecies
   t1=1.d0/dble(nrmt(is)-1)
 ! logarithmic mesh
-  t2=log(rmt(is)/sprmin(is))
-  do ir=1,spnr(is)
-    spr(ir,is)=sprmin(is)*exp(dble(ir-1)*t1*t2)
+  t2=log(rmt(is)/rminsp(is))
+  do ir=1,nrsp(is)
+    rsp(ir,is)=rminsp(is)*exp(dble(ir-1)*t1*t2)
+    r2sp(ir,is)=rsp(ir,is)**2
   end do
 end do
 ! set up the coarse radial meshes and find the inner part of the muffin-tin
-! where rho is calculated with lmaxinr
+! where rho is calculated with lmaxi
+if (allocated(rcmt)) deallocate(rcmt)
+allocate(rcmt(nrcmtmax,nspecies))
+if (allocated(r2cmt)) deallocate(r2cmt)
+allocate(r2cmt(nrcmtmax,nspecies))
 do is=1,nspecies
   t1=fracinr*rmt(is)
-  nrmtinr(is)=0
-  nrcmtinr(is)=0
+  nrmti(is)=1
+  nrcmti(is)=1
   irc=0
   do ir=1,nrmt(is),lradstp
     irc=irc+1
-    rcmt(irc,is)=spr(ir,is)
-    if (spr(ir,is).lt.t1) then
-      nrmtinr(is)=ir
-      nrcmtinr(is)=irc
+    rcmt(irc,is)=rsp(ir,is)
+    r2cmt(irc,is)=r2sp(ir,is)
+    if (rsp(ir,is).lt.t1) then
+      nrmti(is)=ir
+      nrcmti(is)=irc
     end if
   end do
 end do
-! determine at which radius the Hellmann-Feynman force is to be evaluated
-do is=1,nspecies
-  do ir=1,nrmt(is)
-    if (spr(ir,is).lt.radfhf) irfhf(is)=ir
-  end do
-end do
 ! write to VARIABLES.OUT
-call writevars('spnr',nv=nspecies,iva=spnr)
+call writevars('nrsp',nv=nspecies,iva=nrsp)
 call writevars('nrmt',nv=nspecies,iva=nrmt)
-call writevars('nrmtinr',nv=nspecies,iva=nrmtinr)
+call writevars('nrmti',nv=nspecies,iva=nrmti)
 call writevars('lradstp',iv=lradstp)
 call writevars('nrcmt',nv=nspecies,iva=nrcmt)
-call writevars('nrcmtinr',nv=nspecies,iva=nrcmtinr)
+call writevars('nrcmti',nv=nspecies,iva=nrcmti)
 do is=1,nspecies
-  call writevars('spr',nv=nrmt(is),rva=spr(:,is))
+  call writevars('rsp',nv=nrmt(is),rva=rsp(:,is))
 end do
 return
 end subroutine
