@@ -8,7 +8,7 @@ use modmain
 implicit none
 ! local variables
 integer is,ias
-integer nr,ir,irc
+integer nr,nri,ir,irc
 real(8) cso,rm
 ! allocatable arrays
 real(8), allocatable :: vr(:),dvr(:)
@@ -19,14 +19,16 @@ allocate(vr(nrmtmax),dvr(nrmtmax))
 do ias=1,natmtot
   is=idxis(ias)
   nr=nrmt(is)
+  nri=nrmti(is)
 ! radial derivative of the spherical part of the Kohn-Sham potential
-  vr(1:nr)=vsmt(1,1:nr,ias)*y00
-  call fderiv(1,nr,spr(:,is),vr,dvr)
+  call rfmtlm(1,nr,nri,vsmt(:,ias),vr)
+  vr(1:nr)=vr(1:nr)*y00
+  call fderiv(1,nr,rsp(:,is),vr,dvr)
   irc=0
   do ir=1,nr,lradstp
     irc=irc+1
     rm=1.d0-2.d0*cso*vr(ir)
-    socfr(irc,ias)=cso*dvr(ir)/(spr(ir,is)*rm**2)
+    socfr(irc,ias)=cso*dvr(ir)/(rsp(ir,is)*rm**2)
   end do
 end do
 deallocate(vr,dvr)
