@@ -14,7 +14,7 @@ use modmain
 !   scsr   : scissor correction (in,real)
 !   vqpl   : input q-point in lattice coordinates (in,real(3))
 !   gqc    : length of G+q-vectors (in,real(ngrf))
-!   ylmgq  : spherical harmonics of the G+q-vectors (in,complex(lmmaxvr,ngrf))
+!   ylmgq  : spherical harmonics of the G+q-vectors (in,complex(lmmaxo,ngrf))
 !   sfacgq : structure factors of G+q-vectors (in,complex(ngrf,natmtot))
 !   chi0   : spin-dependent Kohn-Sham response function in G-space
 !            (out,complex(ngrf,4,ngrf,4,nwrf))
@@ -58,11 +58,8 @@ use modmain
 implicit none
 ! local variables
 integer, intent(in) :: ikp
-real(8), intent(in) :: scsr
-real(8), intent(in) :: vqpl(3)
-real(8), intent(in) :: gqc(ngrf)
-complex(8), intent(in) :: ylmgq(lmmaxvr,ngrf)
-complex(8), intent(in) :: sfacgq(ngrf,natmtot)
+real(8), intent(in) :: scsr,vqpl(3),gqc(ngrf)
+complex(8), intent(in) :: ylmgq(lmmaxo,ngrf),sfacgq(ngrf,natmtot)
 complex(8), intent(inout) :: chi0(nwrf,ngrf,4,ngrf,4)
 ! local variables
 logical tz(4)
@@ -75,10 +72,10 @@ complex(8) z1,z2
 ! automatic arrays
 integer idx(nstsv),idxq(nstsv)
 ! allocatable arrays
-complex(8), allocatable :: wfmt(:,:,:,:,:),wfir(:,:,:)
-complex(8), allocatable :: wfmtq(:,:,:,:,:),wfirq(:,:,:)
-complex(8), allocatable :: zrhomt(:,:,:),zrhoir(:)
-complex(8), allocatable :: zw(:),zg(:,:)
+complex(8), allocatable :: wfmt(:,:,:,:),wfir(:,:,:)
+complex(8), allocatable :: wfmtq(:,:,:,:),wfirq(:,:,:)
+complex(8), allocatable :: zrhomt(:,:),zrhoir(:)
+complex(8), allocatable :: zrhoig(:,:),zw(:)
 if (.not.spinpol) then
   write(*,*)
   write(*,'("Error(genspchi0): spin-unpolarised calculation")')
@@ -106,20 +103,18 @@ do jst=1,nstsv
   end if
 end do
 ! generate the wavefunctions for all states at k and k+q in energy window
-allocate(wfmt(lmmaxvr,nrcmtmax,natmtot,nspinor,nst))
-allocate(wfir(ngtot,nspinor,nst))
+allocate(wfmt(npcmtmax,natmtot,nspinor,nst),wfir(ngtot,nspinor,nst))
 call genwfsvp(.false.,.false.,nst,idx,vkl(:,ikp),wfmt,ngtot,wfir)
-allocate(wfmtq(lmmaxvr,nrcmtmax,natmtot,nspinor,nstq))
-allocate(wfirq(ngtot,nspinor,nstq))
+allocate(wfmtq(npcmtmax,natmtot,nspinor,nstq),wfirq(ngtot,nspinor,nstq))
 call genwfsvp(.false.,.false.,nstq,idxq,vkql,wfmtq,ngtot,wfirq)
 !$OMP PARALLEL DEFAULT(SHARED) &
-!$OMP PRIVATE(zrhomt,zrhoir,zw,zg) &
+!$OMP PRIVATE(zrhomt,zrhoir,zrhoig,zw) &
 !$OMP PRIVATE(jst,kst,lst,t1,eij,iw) &
 !$OMP PRIVATE(i,j,a,b,tz,ig,jg,z1,z2)
 !$OMP DO
 do ist=1,nst
-  allocate(zrhomt(lmmaxvr,nrcmtmax,natmtot),zrhoir(ngtot))
-  allocate(zw(nwrf),zg(ngrf,4))
+  allocate(zrhomt(npcmtmax,natmtot),zrhoir(ngtot))
+  allocate(zrhoig(ngrf,4),zw(nwrf))
   kst=idx(ist)
   do jst=1,nstq
     lst=idxq(jst)
@@ -154,20 +149,20 @@ do ist=1,nst
             cycle
           end if
         end if
-        call genzrho(.true.,.false.,wfmt(:,:,:,a,ist),wfir(:,a,ist), &
-         wfmtq(:,:,:,b,jst),wfirq(:,b,jst),zrhomt,zrhoir)
-        call zftzf(ngrf,gqc,ylmgq,ngrf,sfacgq,zrhomt,zrhoir,zg(:,i))
+        call genzrho(.true.,.false.,wfmt(:,:,a,ist),wfir(:,a,ist), &
+         wfmtq(:,:,b,jst),wfirq(:,b,jst),zrhomt,zrhoir)
+        call zftzf(ngrf,gqc,ylmgq,ngrf,sfacgq,zrhomt,zrhoir,zrhoig(:,i))
       end do
     end do
 !$OMP CRITICAL
     do j=1,4
       if (tz(j)) cycle
       do jg=1,ngrf
-        z1=conjg(zg(jg,j))
+        z1=conjg(zrhoig(jg,j))
         do i=1,4
           if (tz(i)) cycle
           do ig=1,ngrf
-            z2=zg(ig,i)*z1
+            z2=zrhoig(ig,i)*z1
             call zaxpy(nwrf,z2,zw,1,chi0(:,ig,i,jg,j),1)
           end do
         end do
@@ -176,7 +171,7 @@ do ist=1,nst
 !$OMP END CRITICAL
 ! end loop over jst
   end do
-  deallocate(zrhomt,zrhoir,zw,zg)
+  deallocate(zrhomt,zrhoir,zrhoig,zw)
 ! end loop over ist
 end do
 !$OMP END DO
