@@ -7,13 +7,12 @@ subroutine genvchi0(ikp,icmp,scsr,vqpl,igq0,gqc,ylmgq,sfacgq,vchi0)
 use modmain
 implicit none
 ! local variables
-integer, intent(in) :: ikp
-integer, intent(in) :: icmp
+integer, intent(in) :: ikp,icmp
 real(8), intent(in) :: scsr
 real(8), intent(in) :: vqpl(3)
 integer, intent(in) :: igq0
 real(8), intent(in) :: gqc(ngrf)
-complex(8), intent(in) :: ylmgq(lmmaxvr,ngrf)
+complex(8), intent(in) :: ylmgq(lmmaxo,ngrf)
 complex(8), intent(in) :: sfacgq(ngrf,natmtot)
 complex(8), intent(inout) :: vchi0(nwrf,ngrf,ngrf)
 ! local variables
@@ -26,10 +25,10 @@ complex(8) z1,z2
 integer idx(nstsv),idxq(nstsv)
 ! allocatable arrays
 complex(8), allocatable :: pmat(:,:,:)
-complex(8), allocatable :: wfmt(:,:,:,:,:),wfir(:,:,:)
-complex(8), allocatable :: wfmtq(:,:,:,:,:),wfirq(:,:,:)
-complex(8), allocatable :: zrhomt(:,:,:),zrhoir(:)
-complex(8), allocatable :: zw(:),zg(:)
+complex(8), allocatable :: wfmt(:,:,:,:),wfir(:,:,:)
+complex(8), allocatable :: wfmtq(:,:,:,:),wfirq(:,:,:)
+complex(8), allocatable :: zrhomt(:,:),zrhoir(:)
+complex(8), allocatable :: zrhoig(:),zw(:)
 ! k+q-vector in lattice coordinates
 vkql(:)=vkl(:,ikp)+vqpl(:)
 ! equivalent reduced k-points for k and k+q
@@ -51,26 +50,24 @@ do jst=1,nstsv
   end if
 end do
 ! generate the wavefunctions for all states at k and k+q in energy window
-allocate(wfmt(lmmaxvr,nrcmtmax,natmtot,nspinor,nst))
-allocate(wfir(ngtot,nspinor,nst))
+allocate(wfmt(npcmtmax,natmtot,nspinor,nst),wfir(ngtot,nspinor,nst))
 call genwfsvp(.false.,.false.,nst,idx,vkl(:,ikp),wfmt,ngtot,wfir)
-allocate(wfmtq(lmmaxvr,nrcmtmax,natmtot,nspinor,nstq))
-allocate(wfirq(ngtot,nspinor,nstq))
+allocate(wfmtq(npcmtmax,natmtot,nspinor,nstq),wfirq(ngtot,nspinor,nstq))
 call genwfsvp(.false.,.false.,nstq,idxq,vkql,wfmtq,ngtot,wfirq)
 ! read the momentum matrix elements from file
-allocate(pmat(3,nstsv,nstsv))
-call getpmat(vkl(:,ikp),pmat)
+allocate(pmat(nstsv,nstsv,3))
+call getpmat(.false.,vkl(:,ikp),pmat)
 ! divide by unit cell volume
 t1=1.d0/omega
 pmat(:,:,:)=t1*pmat(:,:,:)
 !$OMP PARALLEL DEFAULT(SHARED) &
-!$OMP PRIVATE(zrhomt,zrhoir,zw,zg) &
+!$OMP PRIVATE(zrhomt,zrhoir,zrhoig,zw) &
 !$OMP PRIVATE(jst,kst,lst,t1,t2,eij) &
 !$OMP PRIVATE(iw,ig,jg,z1,z2)
 !$OMP DO
 do ist=1,nst
-  allocate(zrhomt(lmmaxvr,nrcmtmax,natmtot),zrhoir(ngtot))
-  allocate(zw(nwrf),zg(ngrf))
+  allocate(zrhomt(npcmtmax,natmtot),zrhoir(ngtot))
+  allocate(zrhoig(ngrf),zw(nwrf))
   kst=idx(ist)
   do jst=1,nstq
     lst=idxq(jst)
@@ -87,26 +84,26 @@ do ist=1,nst
       end if
       t2=eij/t2
 ! scale the momentum matrix elements
-      pmat(:,kst,lst)=t2*pmat(:,kst,lst)
+      pmat(kst,lst,:)=t2*pmat(kst,lst,:)
     end if
 ! frequency-dependent part in response function formula for all frequencies
     do iw=1,nwrf
       zw(iw)=t1/(eij+wrf(iw))
     end do
 ! compute the complex density in G+q-space
-    call genzrho(.true.,.true.,wfmt(:,:,:,:,ist),wfir(:,:,ist), &
-     wfmtq(:,:,:,:,jst),wfirq(:,:,jst),zrhomt,zrhoir)
-    call zftzf(ngrf,gqc,ylmgq,ngrf,sfacgq,zrhomt,zrhoir,zg)
+    call genzrho(.true.,.true.,wfmt(:,:,:,ist),wfir(:,:,ist),wfmtq(:,:,:,jst), &
+     wfirq(:,:,jst),zrhomt,zrhoir)
+    call zftzf(ngrf,gqc,ylmgq,ngrf,sfacgq,zrhomt,zrhoir,zrhoig)
 !$OMP CRITICAL
 !------------------------!
 !     body of matrix     !
 !------------------------!
     do jg=1,ngrf
-      z1=conjg(zg(jg))
+      z1=conjg(zrhoig(jg))
       do ig=1,ngrf
         t1=gqc(ig)*gqc(jg)
         if (t1.gt.1.d-8) then
-          z2=(fourpi/t1)*zg(ig)*z1
+          z2=(fourpi/t1)*zrhoig(ig)*z1
           call zaxpy(nwrf,z2,zw,1,vchi0(:,ig,jg),1)
         end if
       end do
@@ -118,10 +115,10 @@ do ist=1,nst
 !----------------------------------------!
       if (icmp.eq.0) then
 ! trace of dielectric tensor
-        t1=sum(dble(pmat(:,kst,lst))**2+aimag(pmat(:,kst,lst))**2)/3.d0
+        t1=sum(dble(pmat(kst,lst,:))**2+aimag(pmat(kst,lst,:))**2)/3.d0
       else
 ! particular macroscopic component
-        t1=dble(pmat(icmp,kst,lst))**2+aimag(pmat(icmp,kst,lst))**2
+        t1=dble(pmat(kst,lst,icmp))**2+aimag(pmat(kst,lst,icmp))**2
       end if
       t1=fourpi*t1/eij**2
       vchi0(:,igq0,igq0)=vchi0(:,igq0,igq0)+t1*zw(:)
@@ -130,25 +127,25 @@ do ist=1,nst
 !-------------------------!
       t1=-fourpi/eij
       if (icmp.eq.0) then
-        z1=(t1/3.d0)*(pmat(1,kst,lst)+pmat(2,kst,lst)+pmat(3,kst,lst))
+        z1=(t1/3.d0)*(pmat(kst,lst,1)+pmat(kst,lst,2)+pmat(kst,lst,3))
       else
-        z1=t1*pmat(icmp,kst,lst)
+        z1=t1*pmat(kst,lst,icmp)
       end if
 ! G = q = 0
       do ig=2,ngrf
-        z2=zg(ig)*conjg(z1)/gqc(ig)
+        z2=zrhoig(ig)*conjg(z1)/gqc(ig)
         call zaxpy(nwrf,z2,zw,1,vchi0(:,ig,igq0),1)
       end do
 ! G' = q = 0
       do jg=2,ngrf
-        z2=z1*conjg(zg(jg))/gqc(jg)
+        z2=z1*conjg(zrhoig(jg))/gqc(jg)
         call zaxpy(nwrf,z2,zw,1,vchi0(:,igq0,jg),1)
       end do
     end if
 !$OMP END CRITICAL
 ! end loop over jst
   end do
-  deallocate(zrhomt,zrhoir,zw,zg)
+  deallocate(zrhomt,zrhoir,zrhoig,zw)
 ! end loop over ist
 end do
 !$OMP END DO
