@@ -11,7 +11,7 @@ subroutine genvsig
 use modmain
 ! !DESCRIPTION:
 !   Generates the Fourier transform of the Kohn-Sham effective potential in the
-!   intersitial region. The potential is first multiplied by the characteristic
+!   interstitial region. The potential is first multiplied by the characteristic
 !   function which zeros it in the muffin-tins. See routine {\tt gencfun}.
 !
 ! !REVISION HISTORY:
@@ -20,8 +20,7 @@ use modmain
 !BOC
 implicit none
 ! local variables
-integer ig,ifg
-real(8) gm2
+integer ig
 ! allocatable arrays
 complex(8), allocatable :: zfft(:)
 allocate(zfft(ngtot))
@@ -29,31 +28,22 @@ if (trimvg) then
 ! trim the Fourier components of vsir for |G| > gmaxvr/2
   zfft(:)=vsir(:)
   call zfftifc(3,ngridg,-1,zfft)
-  gm2=gmaxvr/2.d0
-  do ig=1,ngtot
-    if (gc(ig).gt.gm2) then
-      ifg=igfft(ig)
-      zfft(ifg)=0.d0
-    end if
+  do ig=ngv2+1,ngtot
+    zfft(igfft(ig))=0.d0
   end do
 ! Fourier transform back to real-space
   call zfftifc(3,ngridg,1,zfft)
 ! multiply trimmed potential by characteristic function in real-space
-!$OMP PARALLEL WORKSHARE
   zfft(:)=dble(zfft(:))*cfunir(:)
-!$OMP END PARALLEL WORKSHARE
 else
 ! multiply potential by characteristic function in real-space
-!$OMP PARALLEL WORKSHARE
   zfft(:)=vsir(:)*cfunir(:)
-!$OMP END PARALLEL WORKSHARE
 end if
 ! Fourier transform to G-space
 call zfftifc(3,ngridg,-1,zfft)
 ! store in global array
 do ig=1,ngvec
-  ifg=igfft(ig)
-  vsig(ig)=zfft(ifg)
+  vsig(ig)=zfft(igfft(ig))
 end do
 deallocate(zfft)
 return
