@@ -3,12 +3,13 @@
 ! This file is distributed under the terms of the GNU General Public License.
 ! See the file COPYING for license details.
 
-subroutine getpmat(vpl,pmat)
+subroutine getpmat(tfv,vpl,pmat)
 use modmain
 implicit none
 ! arguments
+logical, intent(in) :: tfv
 real(8), intent(in) :: vpl(3)
-complex(8), intent(out) :: pmat(3,nstsv,nstsv)
+complex(8), intent(out) :: pmat(nstsv,nstsv,3)
 ! local variables
 integer isym,ik,ist,jst
 integer recl,nstsv_
@@ -19,8 +20,13 @@ call findkpt(vpl,isym,ik)
 ! find the record length
 inquire(iolength=recl) vkl_,nstsv_,pmat
 !$OMP CRITICAL
-open(85,file='PMAT.OUT',action='READ',form='UNFORMATTED',access='DIRECT', &
- recl=recl)
+if (tfv) then
+  open(85,file='PMATFV.OUT',action='READ',form='UNFORMATTED',access='DIRECT', &
+   recl=recl)
+else
+  open(85,file='PMAT.OUT',action='READ',form='UNFORMATTED',access='DIRECT', &
+   recl=recl)
+end if
 read(85,rec=ik) vkl_,nstsv_,pmat
 close(85)
 !$OMP END CRITICAL
@@ -28,16 +34,16 @@ t1=abs(vkl(1,ik)-vkl_(1))+abs(vkl(2,ik)-vkl_(2))+abs(vkl(3,ik)-vkl_(3))
 if (t1.gt.epslat) then
   write(*,*)
   write(*,'("Error(getpmat): differing vectors for k-point ",I8)') ik
-  write(*,'(" current    : ",3G18.10)') vkl(:,ik)
-  write(*,'(" EVECSV.OUT : ",3G18.10)') vkl_
+  write(*,'(" current  : ",3G18.10)') vkl(:,ik)
+  write(*,'(" PMAT.OUT : ",3G18.10)') vkl_
   write(*,*)
   stop
 end if
 if (nstsv.ne.nstsv_) then
   write(*,*)
   write(*,'("Error(getpmat): differing nstsv for k-point ",I8)') ik
-  write(*,'(" current    : ",I8)') nstsv
-  write(*,'(" EVECSV.OUT : ",I8)') nstsv_
+  write(*,'(" current  : ",I8)') nstsv
+  write(*,'(" PMAT.OUT : ",I8)') nstsv_
   write(*,*)
   stop
 end if
@@ -48,11 +54,11 @@ if (t1.lt.epslat) return
 sc(:,:)=symlatc(:,:,lsplsymc(isym))
 do ist=1,nstsv
   do jst=1,nstsv
-    v1(:)=dble(pmat(:,ist,jst))
+    v1(:)=dble(pmat(ist,jst,:))
     call r3mv(sc,v1,v2)
-    v1(:)=aimag(pmat(:,ist,jst))
+    v1(:)=aimag(pmat(ist,jst,:))
     call r3mv(sc,v1,v3)
-    pmat(:,ist,jst)=cmplx(v2(:),v3(:),8)
+    pmat(ist,jst,:)=cmplx(v2(:),v3(:),8)
   end do
 end do
 return
