@@ -34,6 +34,7 @@ real(8), allocatable :: v(:),work(:)
 ! initialise global variables
 call init0
 call init1
+if (ultracell) call init2
 ! set the stop signal to .false.
 tstop=.false.
 ! initialise OEP variables if required
@@ -97,8 +98,8 @@ else
 end if
 if (mp_mpi) call flushifc(60)
 ! size of mixing vector
-n=lmmaxvr*nrmtmax*natmtot+ngtot
-if (spinpol) n=n+ndmag*(lmmaxvr*nrcmtmax*natmtot+ngtot)
+n=npmtmax*natmtot+ngtot
+if (spinpol) n=n+ndmag*(npcmtmax*natmtot+ngtot)
 if (tvmatmt) n=n+2*((lmmaxdm*nspinor)**2)*natmtot
 ! allocate mixing array
 allocate(v(n))
@@ -165,7 +166,7 @@ do iscl=1,maxscl
   if (mp_mpi) then
 ! write the occupation numbers to file
     do ik=1,nkpt
-      call putoccsv(ik,occsv(:,ik))
+      call putoccsv(filext,ik,occsv(:,ik))
     end do
 ! write eigenvalues to file
     call writeeval
