@@ -12,17 +12,17 @@ logical exist
 integer ik,lp
 real(8) etp,de
 ! allocatable arrays
-real(8), allocatable :: vmt(:,:,:),vir(:)
-real(8), allocatable :: bmt(:,:,:,:),bir(:,:)
+real(8), allocatable :: vmt(:,:),vir(:)
+real(8), allocatable :: bmt(:,:,:),bir(:,:)
 complex(8), allocatable :: evecsv(:,:)
 ! initialise universal variables
 call init0
 call init1
 call init2
 ! allocate local arrays
-allocate(vmt(lmmaxvr,nrcmtmax,natmtot),vir(ngtot))
+allocate(vmt(npcmtmax,natmtot),vir(ngtot))
 if (hybrid.and.spinpol) then
-  allocate(bmt(lmmaxvr,nrcmtmax,natmtot,ndmag),bir(ngtot,ndmag))
+  allocate(bmt(npcmtmax,natmtot,ndmag),bir(ngtot,ndmag))
 end if
 ! only the MPI master process should write files
 if (mp_mpi) then
@@ -46,6 +46,8 @@ end if
 call readstate
 ! generate the core wavefunctions and densities
 call gencore
+! read Fermi energy from file
+call readfermi
 ! find the new linearisation energies
 call linengy
 ! generate the APW radial functions
@@ -62,8 +64,8 @@ call gensocfr
 call genevfsv
 ! find the occupation numbers and Fermi energy
 call occupy
-! generate the kinetic matrix elements in the Cartesian basis
-call genkmatc(.true.)
+! generate the kinetic matrix elements in the first-variational basis
+call genkmat(.true.,.true.)
 ! set last self-consistent loop flag
 tlast=.false.
 etp=0.d0
@@ -101,12 +103,12 @@ do iscl=1,maxscl
 ! distribute among MPI processes
     if (mod(ik-1,np_mpi).ne.lp_mpi) cycle
     allocate(evecsv(nstsv,nstsv))
-    call getevecsv(vkl(:,ik),evecsv)
+    call getevecsv(filext,ik,vkl(:,ik),evecsv)
 ! solve the Hartree-Fock eigenvalue equation
     call eveqnhf(ik,vmt,vir,bmt,bir,evecsv)
 ! write the eigenvalues/vectors to file
-    call putevalsv(ik,evalsv(:,ik))
-    call putevecsv(ik,evecsv)
+    call putevalsv(filext,ik,evalsv(:,ik))
+    call putevecsv(filext,ik,evecsv)
     deallocate(evecsv)
   end do
 !$OMP END DO
@@ -124,7 +126,7 @@ do iscl=1,maxscl
   if (mp_mpi) then
 ! write the occupation numbers to file
     do ik=1,nkpt
-      call putoccsv(ik,occsv(:,ik))
+      call putoccsv(filext,ik,occsv(:,ik))
     end do
 ! write out the eigenvalues and occupation numbers
     call writeeval
