@@ -7,39 +7,36 @@ subroutine hflocal(vmt,vir,bmt,bir)
 use modmain
 implicit none
 ! arguments
-real(8), intent(out) :: vmt(lmmaxvr,nrcmtmax,natmtot)
-real(8), intent(out) :: vir(ngtot)
-real(8), intent(out) :: bmt(lmmaxvr,nrcmtmax,natmtot,ndmag)
-real(8), intent(out) :: bir(ngtot,ndmag)
+real(8), intent(out) :: vmt(npcmtmax,natmtot),vir(ngtot)
+real(8), intent(out) :: bmt(npcmtmax,natmtot,ndmag),bir(ngtot,ndmag)
 ! local variables
-integer idm,is,ias,ir,irc
+integer idm,is,ias,np
 ! allocatable arrays
-real(8), allocatable :: rfmt(:,:)
+real(8), allocatable :: rfmt1(:),rfmt2(:)
 ! compute the Coulomb potential
 call potcoul
 ! generate the exchange-correlation potentials for hybrids
 if (hybrid) call potxc
 ! convert to spherical coordinates and store in output arrays
+allocate(rfmt1(npmtmax),rfmt2(npcmtmax))
 if (hybrid) then
 ! hybrid functional case
-  allocate(rfmt(lmmaxvr,nrcmtmax))
   do ias=1,natmtot
     is=idxis(ias)
-    irc=0
-    do ir=1,nrmt(is),lradstp
-      irc=irc+1
-      rfmt(:,irc)=vclmt(:,ir,ias)+vxcmt(:,ir,ias)
-    end do
-    call rbsht(nrcmt(is),nrcmtinr(is),1,rfmt,1,vmt(:,:,ias))
+    np=npmt(is)
+    rfmt1(1:np)=vclmt(1:np,ias)+vxcmt(1:np,ias)
+    call rfmtftoc(nrmt(is),nrmti(is),rfmt1,rfmt2)
+    call rbsht(nrcmt(is),nrcmti(is),rfmt2,vmt(:,ias))
   end do
-  deallocate(rfmt)
   vir(:)=(vclir(:)+vxcir(:))*cfunir(:)
   if (spinpol) then
     do idm=1,ndmag
       do ias=1,natmtot
         is=idxis(ias)
-        call rbsht(nrcmt(is),nrcmtinr(is),lradstp,bxcmt(:,:,ias,idm),1, &
-         bmt(:,:,ias,idm))
+        np=npmt(is)
+        rfmt1(1:np)=bxcmt(1:np,ias,idm)
+        call rfmtftoc(nrmt(is),nrmti(is),rfmt1,rfmt2)
+        call rbsht(nrcmt(is),nrcmti(is),rfmt2,bmt(:,ias,idm))
       end do
       bir(:,idm)=bxcir(:,idm)*cfunir(:)
     end do
@@ -48,10 +45,14 @@ else
 ! normal Hartree-Fock case
   do ias=1,natmtot
     is=idxis(ias)
-    call rbsht(nrcmt(is),nrcmtinr(is),lradstp,vclmt(:,:,ias),1,vmt(:,:,ias))
+    np=npmt(is)
+    rfmt1(1:np)=vclmt(1:np,ias)
+    call rfmtftoc(nrmt(is),nrmti(is),rfmt1,rfmt2)
+    call rbsht(nrcmt(is),nrcmti(is),rfmt2,vmt(:,ias))
   end do
   vir(:)=vclir(:)*cfunir(:)
 end if
+deallocate(rfmt1,rfmt2)
 return
 end subroutine
 
