@@ -7,9 +7,7 @@ subroutine hmllolo(ias,ngp,ld,h)
 use modmain
 implicit none
 ! arguments
-integer, intent(in) :: ias
-integer, intent(in) :: ngp
-integer, intent(in) :: ld
+integer, intent(in) :: ias,ngp,ld
 complex(8), intent(inout) :: h(ld,*)
 ! local variables
 integer is,ilo,jlo
@@ -17,19 +15,19 @@ integer l1,l2,l3,m1,m2,m3
 integer lm1,lm2,lm3,i,j
 complex(8) zsum
 is=idxis(ias)
-do ilo=1,nlorb(is)
-  l1=lorbl(ilo,is)
-  do m1=-l1,l1
-    lm1=idxlm(l1,m1)
-    i=ngp+idxlo(lm1,ilo,ias)
-    do jlo=1,nlorb(is)
-      l3=lorbl(jlo,is)
-      do m3=-l3,l3
-        lm3=idxlm(l3,m3)
-        j=ngp+idxlo(lm3,jlo,ias)
+do jlo=1,nlorb(is)
+  l3=lorbl(jlo,is)
+  do m3=-l3,l3
+    lm3=idxlm(l3,m3)
+    j=ngp+idxlo(lm3,jlo,ias)
+    do ilo=1,nlorb(is)
+      l1=lorbl(ilo,is)
+      do m1=-l1,l1
+        lm1=idxlm(l1,m1)
+        i=ngp+idxlo(lm1,ilo,ias)
         if (i.le.j) then
           zsum=0.d0
-          do l2=0,lmaxvr
+          do l2=0,lmaxo
             if (mod(l1+l2+l3,2).eq.0) then
               do m2=-l2,l2
                 lm2=idxlm(l2,m2)
