@@ -45,13 +45,9 @@ call timesec(ts0)
 !------------------------------------!
 !     angular momentum variables     !
 !------------------------------------!
-lmmaxvr=(lmaxvr+1)**2
-lmmaxapw=(lmaxapw+1)**2
-lmmaxmat=(lmaxmat+1)**2
-lmmaxinr=(lmaxinr+1)**2
-if (lmaxvr.gt.lmaxapw) then
+if (lmaxo.gt.lmaxapw) then
   write(*,*)
-  write(*,'("Error(init0): lmaxvr > lmaxapw : ",2I8)') lmaxvr,lmaxapw
+  write(*,'("Error(init0): lmaxo > lmaxapw : ",2I8)') lmaxo,lmaxapw
   write(*,*)
   stop
 end if
@@ -61,8 +57,13 @@ if (lmaxmat.gt.lmaxapw) then
   write(*,*)
   stop
 end if
+lmaxi=min(lmaxi,lmaxo)
+lmmaxapw=(lmaxapw+1)**2
+lmmaxmat=(lmaxmat+1)**2
+lmmaxi=(lmaxi+1)**2
+lmmaxo=(lmaxo+1)**2
 ! check DOS lmax is within range
-lmaxdos=min(lmaxdos,lmaxvr)
+lmaxdos=min(lmaxdos,lmaxo)
 ! index to (l,m) pairs
 if (allocated(idxlm)) deallocate(idxlm)
 allocate(idxlm(0:lmaxapw,-lmaxapw:lmaxapw))
@@ -88,9 +89,9 @@ do l=0,lmaxapw
   zilc(l)=conjg(zil(l))
 end do
 ! write to VARIABLES.OUT
-call writevars('lmaxvr',iv=lmaxvr)
 call writevars('lmaxapw',iv=lmaxapw)
-call writevars('lmaxinr',iv=lmaxinr)
+call writevars('lmaxi',iv=lmaxi)
+call writevars('lmaxo',iv=lmaxo)
 
 !------------------------------------!
 !     index to atoms and species     !
@@ -206,6 +207,13 @@ if ((xcgrad.eq.3).and.ncmag) then
   write(*,*)
   stop
 end if
+if (ncmag.or.spinorb) then
+! spins are coupled together
+  spcpl=.true.
+else
+! spins are decoupled
+  spcpl=.false.
+end if
 ! spin-polarised cores
 if (.not.spinpol) spincore=.false.
 if (fsmtype.ne.0) then
@@ -255,7 +263,7 @@ call writevars('ndmag',iv=ndmag)
 !     crystal structure set up     !
 !----------------------------------!
 ! generate the reciprocal lattice vectors and unit cell volume
-call reciplat
+call reciplat(avec,bvec,omega,omegabz)
 ! inverse of the lattice vector matrix
 call r3minv(avec,ainv)
 ! inverse of the reciprocal vector matrix
@@ -277,6 +285,10 @@ omegamt=0.d0
 do is=1,nspecies
   omegamt=omegamt+dble(natoms(is))*(fourpi/3.d0)*rmt(is)**3
 end do
+! generate ultracell reciprocal lattice vectors if required
+if (ultracell) then
+  call reciplat(avecu,bvecu,omegau,omegabzu)
+end if
 ! write to VARIABLES.OUT
 call writevars('avec',nv=9,rva=avec)
 call writevars('bvec',nv=9,rva=bvec)
@@ -322,6 +334,17 @@ do is=1,nspecies
 end do
 ! set up atomic and muffin-tin radial meshes
 call genrmesh
+! number of points in packed muffin-tins
+npmtmax=1
+npcmtmax=1
+do is=1,nspecies
+  npmti(is)=lmmaxi*nrmti(is)
+  npmt(is)=npmti(is)+lmmaxo*(nrmt(is)-nrmti(is))
+  npmtmax=max(npmtmax,npmt(is))
+  npcmti(is)=lmmaxi*nrcmti(is)
+  npcmt(is)=npcmti(is)+lmmaxo*(nrcmt(is)-nrcmti(is))
+  npcmtmax=max(npcmtmax,npcmt(is))
+end do
 
 !--------------------------------------!
 !     charges and number of states     !
@@ -329,24 +352,24 @@ call genrmesh
 chgzn=0.d0
 chgcrtot=0.d0
 chgval=0.d0
-spnstmax=0
+nstspmax=0
 nstcr=0
 do is=1,nspecies
 ! nuclear charge
   chgzn=chgzn+spzn(is)*natoms(is)
 ! find the maximum number of atomic states
-  spnstmax=max(spnstmax,spnst(is))
+  nstspmax=max(nstspmax,nstsp(is))
 ! compute the electronic charge for each species, as well as the total core and
 ! valence charge
   spze(is)=0.d0
   chgcr(is)=0.d0
-  do ist=1,spnst(is)
-    spze(is)=spze(is)+spocc(ist,is)
+  do ist=1,nstsp(is)
+    spze(is)=spze(is)+occsp(ist,is)
     if (spcore(ist,is)) then
-      chgcr(is)=chgcr(is)+spocc(ist,is)
-      nstcr=nstcr+2*spk(ist,is)*natoms(is)
+      chgcr(is)=chgcr(is)+occsp(ist,is)
+      nstcr=nstcr+2*ksp(ist,is)*natoms(is)
     else
-      chgval=chgval+spocc(ist,is)*natoms(is)
+      chgval=chgval+occsp(ist,is)*natoms(is)
     end if
   end do
   chgcrtot=chgcrtot+chgcr(is)*natoms(is)
@@ -410,7 +433,7 @@ allocate(vgc(3,ngtot))
 if (allocated(gc)) deallocate(gc)
 allocate(gc(ngtot))
 ! generate the G-vectors
-call gengvec(ngridg,ngtot,intgv,bvec,gmaxvr,ngvec,ivg,ivgig,igfft,vgc,gc)
+call gengvec
 ! write number of G-vectors to test file
 call writetest(900,'number of G-vectors',iv=ngvec)
 ! Poisson solver pseudocharge density constant
@@ -420,7 +443,7 @@ else
   t1=0.25d0*gmaxvr*2.d0
 end if
 npsd=max(nint(t1),1)
-lnpsd=lmaxvr+npsd+1
+lnpsd=lmaxo+npsd+1
 ! compute the spherical Bessel functions j_l(|G|R_mt)
 if (allocated(jlgr)) deallocate(jlgr)
 allocate(jlgr(0:lnpsd,ngvec,nspecies))
@@ -455,21 +478,21 @@ call writevars('igfft',nv=ngtot,iva=igfft)
 call allatoms
 ! allocate core state occupancy and eigenvalue arrays and set to default
 if (allocated(occcr)) deallocate(occcr)
-allocate(occcr(spnstmax,natmtot))
+allocate(occcr(nstspmax,natmtot))
 if (allocated(evalcr)) deallocate(evalcr)
-allocate(evalcr(spnstmax,natmtot))
+allocate(evalcr(nstspmax,natmtot))
 do is=1,nspecies
   do ia=1,natoms(is)
     ias=idxas(ia,is)
-    do ist=1,spnst(is)
-      occcr(ist,ias)=spocc(ist,is)
-      evalcr(ist,ias)=speval(ist,is)
+    do ist=1,nstsp(is)
+      occcr(ist,ias)=occsp(ist,is)
+      evalcr(ist,ias)=evalsp(ist,is)
     end do
   end do
 end do
 ! allocate core state radial wavefunction array
 if (allocated(rwfcr)) deallocate(rwfcr)
-allocate(rwfcr(spnrmax,2,spnstmax,natmtot))
+allocate(rwfcr(nrspmax,2,nstspmax,natmtot))
 ! number of core spin channels
 if (spincore) then
   nspncr=2
@@ -478,46 +501,46 @@ else
 end if
 ! allocate core state charge density array
 if (allocated(rhocr)) deallocate(rhocr)
-allocate(rhocr(spnrmax,natmtot,nspncr))
+allocate(rhocr(nrspmax,natmtot,nspncr))
 
-!---------------------------------------!
-!     charge density and potentials     !
-!---------------------------------------!
+!-------------------------------------------------------------!
+!     charge density, potentials and exchange-correlation     !
+!-------------------------------------------------------------!
 ! allocate charge density arrays
 if (allocated(rhomt)) deallocate(rhomt)
-allocate(rhomt(lmmaxvr,nrmtmax,natmtot))
+allocate(rhomt(npmtmax,natmtot))
 if (allocated(rhoir)) deallocate(rhoir)
 allocate(rhoir(ngtot))
 ! allocate magnetisation arrays
 if (allocated(magmt)) deallocate(magmt)
 if (allocated(magir)) deallocate(magir)
 if (spinpol) then
-  allocate(magmt(lmmaxvr,nrmtmax,natmtot,ndmag))
+  allocate(magmt(npmtmax,natmtot,ndmag))
   allocate(magir(ngtot,ndmag))
 end if
 ! Coulomb potential
 if (allocated(vclmt)) deallocate(vclmt)
-allocate(vclmt(lmmaxvr,nrmtmax,natmtot))
+allocate(vclmt(npmtmax,natmtot))
 if (allocated(vclir)) deallocate(vclir)
 allocate(vclir(ngtot))
 ! exchange energy density
 if (allocated(exmt)) deallocate(exmt)
-allocate(exmt(lmmaxvr,nrmtmax,natmtot))
+allocate(exmt(npmtmax,natmtot))
 if (allocated(exir)) deallocate(exir)
 allocate(exir(ngtot))
 ! correlation energy density
 if (allocated(ecmt)) deallocate(ecmt)
-allocate(ecmt(lmmaxvr,nrmtmax,natmtot))
+allocate(ecmt(npmtmax,natmtot))
 if (allocated(ecir)) deallocate(ecir)
 allocate(ecir(ngtot))
 ! exchange-correlation potential
 if (allocated(vxcmt)) deallocate(vxcmt)
-allocate(vxcmt(lmmaxvr,nrmtmax,natmtot))
+allocate(vxcmt(npmtmax,natmtot))
 if (allocated(vxcir)) deallocate(vxcir)
 allocate(vxcir(ngtot))
 ! effective Kohn-Sham potential
 if (allocated(vsmt)) deallocate(vsmt)
-allocate(vsmt(lmmaxvr,nrmtmax,natmtot))
+allocate(vsmt(npmtmax,natmtot))
 if (allocated(vsir)) deallocate(vsir)
 allocate(vsir(ngtot))
 if (allocated(vsig)) deallocate(vsig)
@@ -528,9 +551,9 @@ if (allocated(bxcir)) deallocate(bxcir)
 if (allocated(bsmt)) deallocate(bsmt)
 if (allocated(bsir)) deallocate(bsir)
 if (spinpol) then
-  allocate(bxcmt(lmmaxvr,nrmtmax,natmtot,ndmag))
+  allocate(bxcmt(npmtmax,natmtot,ndmag))
   allocate(bxcir(ngtot,ndmag))
-  allocate(bsmt(lmmaxvr,nrcmtmax,natmtot,ndmag))
+  allocate(bsmt(npcmtmax,natmtot,ndmag))
   allocate(bsir(ngtot,ndmag))
 end if
 ! spin-orbit coupling radial function
@@ -545,6 +568,17 @@ if (allocated(chgmt)) deallocate(chgmt)
 allocate(chgmt(natmtot))
 if (allocated(mommt)) deallocate(mommt)
 allocate(mommt(3,natmtot))
+! check if reduced Stoner theory (RST) should be used
+if (abs(rstsf-1.d0).gt.1.d-6) then
+  trst=.true.
+else
+  trst=.false.
+end if
+! set Fermi-Dirac smearing if temperature is finite
+if (tempk.gt.0.d0) then
+  stype=3
+  swidth=kboltz*tempk
+end if
 
 !-------------------------!
 !     force variables     !
