@@ -12,6 +12,7 @@ use modmain
 use moddftu
 use modtest
 use modvars
+use modstore
 ! !DESCRIPTION:
 !   Generates the $k$-point set and then allocates and initialises global
 !   variables which depend on the $k$-point set.
@@ -73,8 +74,8 @@ else
   end do
 end if
 if ((task.eq.20).or.(task.eq.21)) then
-! for band structure plots generate k-points along a line
-  call connect(bvec,nvp1d,npp1d,vvlp1d,vplp1d,dvp1d,dpp1d)
+! generate k-points along a line for band structure plots
+  call plotpt1d(bvec,nvp1d,npp1d,vvlp1d,vplp1d,dvp1d,dpp1d)
   nkpt=npp1d
   if (allocated(vkl)) deallocate(vkl)
   allocate(vkl(3,nkpt))
@@ -118,24 +119,24 @@ else
     ngridk(:)=int(t1*sqrt(bvec(1,:)**2+bvec(2,:)**2+bvec(3,:)**2))+1
   end if
 ! set up the default k-point box
-  kptboxl(:,1)=vkloff(:)/dble(ngridk(:))
-  if (task.eq.102) kptboxl(:,1)=0.d0
-  kptboxl(:,2)=kptboxl(:,1)
-  kptboxl(:,3)=kptboxl(:,1)
-  kptboxl(:,4)=kptboxl(:,1)
-  kptboxl(1,2)=kptboxl(1,2)+1.d0
-  kptboxl(2,3)=kptboxl(2,3)+1.d0
-  kptboxl(3,4)=kptboxl(3,4)+1.d0
+  kptboxl(:,0)=vkloff(:)/dble(ngridk(:))
+  if (task.eq.102) kptboxl(:,0)=0.d0
+  kptboxl(:,1)=kptboxl(:,0)
+  kptboxl(:,2)=kptboxl(:,0)
+  kptboxl(:,3)=kptboxl(:,0)
+  kptboxl(1,1)=kptboxl(1,1)+1.d0
+  kptboxl(2,2)=kptboxl(2,2)+1.d0
+  kptboxl(3,3)=kptboxl(3,3)+1.d0
 ! k-point set and box for Fermi surface plots
   if ((task.eq.100).or.(task.eq.101).or.(task.eq.102)) then
     ngridk(:)=np3d(:)
     if (task.ne.102) kptboxl(:,:)=vclp3d(:,:)
   end if
 ! allocate the k-point set arrays
-  if (allocated(ikmap)) deallocate(ikmap)
-  allocate(ikmap(0:ngridk(1)-1,0:ngridk(2)-1,0:ngridk(3)-1))
-  if (allocated(ikmapnr)) deallocate(ikmapnr)
-  allocate(ikmapnr(0:ngridk(1)-1,0:ngridk(2)-1,0:ngridk(3)-1))
+  if (allocated(ivkik)) deallocate(ivkik)
+  allocate(ivkik(0:ngridk(1)-1,0:ngridk(2)-1,0:ngridk(3)-1))
+  if (allocated(ivkiknr)) deallocate(ivkiknr)
+  allocate(ivkiknr(0:ngridk(1)-1,0:ngridk(2)-1,0:ngridk(3)-1))
   nkptnr=ngridk(1)*ngridk(2)*ngridk(3)
   if (allocated(ivk)) deallocate(ivk)
   allocate(ivk(3,nkptnr))
@@ -147,18 +148,20 @@ else
   allocate(wkpt(nkptnr))
 ! generate the k-point set
   call genppts(.false.,nsymkpt,symkpt,ngridk,nkptnr,epslat,bvec,kptboxl,nkpt, &
-   ikmap,ikmapnr,ivk,vkl,vkc,wkpt,wkptnr)
+   ivkik,ivkiknr,ivk,vkl,vkc,wkpt,wkptnr)
 ! write to VARIABLES.OUT
   call writevars('nsymkpt',iv=nsymkpt)
   call writevars('symkpt',nv=9*nsymkpt,iva=symkpt)
   call writevars('ngridk',nv=3,iva=ngridk)
   call writevars('vkloff',nv=3,rva=vkloff)
   call writevars('nkpt',iv=nkpt)
-  call writevars('ikmap',nv=nkptnr,iva=ikmap)
+  call writevars('ivkik',nv=nkptnr,iva=ivkik)
   call writevars('ivk',nv=3*nkptnr,iva=ivk)
   call writevars('vkl',nv=3*nkptnr,rva=vkl)
   call writevars('wkpt',nv=nkpt,rva=wkpt)
 end if
+! generate the kappa- and k+kappa-points if required
+call genkappa
 ! write the k-points to test file
 call writetest(910,'k-points (Cartesian)',nv=3*nkpt,tol=1.d-8,rva=vkc)
 
@@ -277,17 +280,17 @@ allocate(lofr(nrmtmax,2,nlomax,natmtot))
 if (dftu.ne.0) then
 ! allocate energy arrays to calculate Slater integrals with Yukawa potential
   if (allocated(fdue)) deallocate(fdue)
-  allocate(fdue(maxapword,0:lmaxdm,natmtot))
+  allocate(fdue(0:lmaxdm,natmtot))
 ! allocate radial functions to calculate Slater integrals with Yukawa potential
   if (allocated(fdufr)) deallocate(fdufr)
-  allocate(fdufr(nrmtmax,2,apwordmax,0:lmaxdm,natmtot))
+  allocate(fdufr(nrmtmax,0:lmaxdm,natmtot))
 end if
 
 !---------------------------------------!
 !     eigenvalue equation variables     !
 !---------------------------------------!
 ! total number of empty states (M. Meinert)
-nempty=nint(nempty0*natmtot*nspinor)
+nempty=nint(nempty0*max(natmtot,1))
 if (nempty.lt.1) nempty=1
 ! number of first-variational states
 nstfv=int(chgval/2.d0)+nempty+1
@@ -323,18 +326,18 @@ allocate(oalo(apwordmax,nlomax,natmtot))
 if (allocated(ololo)) deallocate(ololo)
 allocate(ololo(nlomax,nlomax,natmtot))
 if (allocated(haa)) deallocate(haa)
-allocate(haa(lmmaxvr,apwordmax,0:lmaxmat,apwordmax,0:lmaxmat,natmtot))
+allocate(haa(lmmaxo,apwordmax,0:lmaxmat,apwordmax,0:lmaxmat,natmtot))
 if (allocated(hloa)) deallocate(hloa)
-allocate(hloa(lmmaxvr,apwordmax,0:lmaxmat,nlomax,natmtot))
+allocate(hloa(lmmaxo,apwordmax,0:lmaxmat,nlomax,natmtot))
 if (allocated(hlolo)) deallocate(hlolo)
-allocate(hlolo(lmmaxvr,nlomax,nlomax,natmtot))
+allocate(hlolo(lmmaxo,nlomax,nlomax,natmtot))
 ! allocate and generate complex Gaunt coefficient array
 if (allocated(gntyry)) deallocate(gntyry)
-allocate(gntyry(lmmaxmat,lmmaxvr,lmmaxmat))
+allocate(gntyry(lmmaxmat,lmmaxo,lmmaxmat))
 do l1=0,lmaxmat
   do m1=-l1,l1
     lm1=idxlm(l1,m1)
-    do l2=0,lmaxvr
+    do l2=0,lmaxo
       do m2=-l2,l2
         lm2=idxlm(l2,m2)
         do l3=0,lmaxmat
