@@ -85,49 +85,54 @@ real(8) spze(maxspecies)
 ! species mass
 real(8) spmass(maxspecies)
 ! smallest radial point for each species
-real(8) sprmin(maxspecies)
+real(8) rminsp(maxspecies)
 ! effective infinity for species
-real(8) sprmax(maxspecies)
+real(8) rmaxsp(maxspecies)
 ! number of radial points to effective infinity for each species
-integer spnr(maxspecies)
-! maximum spnr over all the species
-integer spnrmax
+integer nrsp(maxspecies)
+! maximum nrsp over all the species
+integer nrspmax
 ! maximum allowed states for each species
-integer, parameter :: maxspst=40
+integer, parameter :: maxstsp=40
 ! number of states for each species
-integer spnst(maxspecies)
-! maximum spnst over all the species
-integer spnstmax
+integer nstsp(maxspecies)
+! maximum nstsp over all the species
+integer nstspmax
 ! core-valence cut-off energy for species file generation
 real(8) ecvcut
 ! semi-core-valence cut-off energy for species file generation
 real(8) esccut
 ! state principle quantum number for each species
-integer spn(maxspst,maxspecies)
+integer nsp(maxstsp,maxspecies)
 ! state l value for each species
-integer spl(maxspst,maxspecies)
+integer lsp(maxstsp,maxspecies)
 ! state k value for each species
-integer spk(maxspst,maxspecies)
+integer ksp(maxstsp,maxspecies)
 ! spcore is .true. if species state is core
-logical spcore(maxspst,maxspecies)
+logical spcore(maxstsp,maxspecies)
 ! total number of core states
 integer nstcr
 ! state eigenvalue for each species
-real(8) speval(maxspst,maxspecies)
+real(8) evalsp(maxstsp,maxspecies)
 ! state occupancy for each species
-real(8) spocc(maxspst,maxspecies)
+real(8) occsp(maxstsp,maxspecies)
 ! species radial mesh
-real(8), allocatable :: spr(:,:)
+real(8), allocatable :: rsp(:,:)
+! r^2 on radial mesh
+real(8), allocatable :: r2sp(:,:)
 ! species charge density
-real(8), allocatable :: sprho(:,:)
+real(8), allocatable :: rhosp(:,:)
 ! species self-consistent potential
-real(8), allocatable :: spvr(:,:)
+real(8), allocatable :: vrsp(:,:)
+! exchange-correlation type for atomic species (the converged ground-state of
+! the crystal does not depend on this choice)
+integer xctsp(3)
 
 !---------------------------------------------------------------!
 !     muffin-tin radial mesh and angular momentum variables     !
 !---------------------------------------------------------------!
 ! scale factor for number of muffin-tin points
-integer nrmtscf
+real(8) nrmtscf
 ! number of muffin-tin radial points for each species
 integer nrmt(maxspecies)
 ! maximum nrmt over all the species
@@ -146,32 +151,39 @@ integer nrcmt(maxspecies)
 integer nrcmtmax
 ! coarse muffin-tin radial mesh
 real(8), allocatable :: rcmt(:,:)
+! r^2 on coarse radial mesh
+real(8), allocatable :: r2cmt(:,:)
 ! maximum allowable angular momentum for augmented plane waves
 integer, parameter :: maxlapw=50
 ! maximum angular momentum for augmented plane waves
 integer lmaxapw
 ! (lmaxapw+1)^2
 integer lmmaxapw
-! maximum angular momentum for potentials and densities
-integer lmaxvr
-! (lmaxvr+1)^2
-integer lmmaxvr
 ! maximum angular momentum used when evaluating the Hamiltonian matrix elements
 integer lmaxmat
 ! (lmaxmat+1)^2
 integer lmmaxmat
-! maximum angular momentum in the inner part of the muffin-int
-integer lmaxinr
-! (lmaxinr+1)^2
-integer lmmaxinr
+! maximum angular momentum on the outer part of the muffin-tin
+integer lmaxo
+! (lmaxo+1)^2
+integer lmmaxo
+! maximum angular momentum on the inner part of the muffin-tin
+integer lmaxi
+! (lmaxi+1)^2
+integer lmmaxi
 ! fraction of muffin-tin radius which constitutes the inner part
 real(8) fracinr
 ! number of fine/coarse radial points on the inner part of the muffin-tin
-integer nrmtinr(maxspecies),nrcmtinr(maxspecies)
+integer nrmti(maxspecies),nrcmti(maxspecies)
 ! index to (l,m) pairs
 integer, allocatable :: idxlm(:,:)
 ! inverse index to (l,m) pairs
 integer, allocatable :: idxil(:),idxim(:)
+! number of fine/coarse points in packed muffin-tins
+integer npmti(maxspecies),npmt(maxspecies)
+integer npcmti(maxspecies),npcmt(maxspecies)
+! maximum number of points over all packed muffin-tins
+integer npmtmax,npcmtmax
 
 !--------------------------------!
 !     spin related variables     !
@@ -188,6 +200,8 @@ integer ndmag
 logical ncmag
 ! if cmagz is .true. then collinear magnetism along the z-axis is enforced
 logical cmagz
+! spcpl is .true. if the up and down spins are coupled
+logical spcpl
 ! fixed spin moment type
 !  0      : none
 !  1 (-1) : total moment (direction)
@@ -312,6 +326,8 @@ integer ngtot
 integer intgv(2,3)
 ! number of G-vectors with G < gmaxvr
 integer ngvec
+! number of G-vectors with G < gmaxvr/2
+integer ngv2
 ! G-vector integer coordinates (i1,i2,i3)
 integer, allocatable :: ivg(:,:)
 ! map from (i1,i2,i3) to G-vector index
@@ -330,8 +346,6 @@ complex(8), allocatable :: ylmg(:,:)
 complex(8), allocatable :: sfacg(:,:)
 ! smooth step function form factors for all species and G-vectors
 real(8), allocatable :: ffacg(:,:)
-! ffdamp is .true. if the form factors should be damped to zero at gmaxvr
-logical ffdamp
 ! characteristic function in G-space: 0 inside the muffin-tins and 1 outside
 complex(8), allocatable :: cfunig(:)
 ! characteristic function in real-space: 0 inside the muffin-tins and 1 outside
@@ -348,8 +362,9 @@ real(8) radkpt
 integer ngridk(3)
 ! k-point offset
 real(8) vkloff(3)
-! corners of box in lattice coordinates containing the k-points
-real(8) kptboxl(3,4)
+! corners of box in lattice coordinates containing the k-points, the zeroth
+! vector is the origin
+real(8) kptboxl(3,0:3)
 ! type of reduction to perform on k-point set
 !  0 : no reduction
 !  1 : reduce with full crystal symmetry group
@@ -363,12 +378,12 @@ integer symkpt(3,3,48)
 integer nkpt
 ! total number of non-reduced k-points
 integer nkptnr
-! map from non-reduced grid to reduced index
-integer, allocatable :: ikmap(:,:,:)
-! map from non-reduced grid to non-reduced index
-integer, allocatable :: ikmapnr(:,:,:)
 ! locations of k-points on integer grid
 integer, allocatable :: ivk(:,:)
+! map from (i1,i2,i3) to reduced k-point index
+integer, allocatable :: ivkik(:,:,:)
+! map from (i1,i2,i3) to non-reduced k-point index
+integer, allocatable :: ivkiknr(:,:,:)
 ! k-points in lattice coordinates
 real(8), allocatable :: vkl(:,:)
 ! k-points in Cartesian coordinates
@@ -444,29 +459,56 @@ integer iq0
 ! weights associated with the integral of 1/q^2
 real(8), allocatable :: wiq2(:)
 
+!-----------------------------!
+!     ultracell variables     !
+!-----------------------------!
+! ultracell is .true. if an ultracell is to be used
+logical ultracell
+! kappa-point grid sizes
+integer ngridkpa(3)
+! ultracell lattice vectors stored column-wise
+real(8) avecu(3,3)
+! ultracell reciprocal lattice vectors
+real(8) bvecu(3,3)
+! ultracell volume and Brillouin zone volume
+real(8) omegau,omegabzu
+! number of kappa-points
+integer nkpa
+! kappa-points in ultracell lattice coordinates
+real(8), allocatable :: vkpalu(:,:)
+! kappa-points in unit cell lattice coordinates
+real(8), allocatable :: vkpal(:,:)
+! kappa-points in Cartesian coordinates
+real(8), allocatable :: vkpac(:,:)
+
 !-----------------------------------------------------!
 !     spherical harmonic transform (SHT) matrices     !
 !-----------------------------------------------------!
-! real backward SHT matrix for lmaxvr
-real(8), allocatable :: rbshtvr(:,:)
-! real forward SHT matrix for lmaxvr
-real(8), allocatable :: rfshtvr(:,:)
-! real backward SHT matrix for lmaxinr
-real(8), allocatable :: rbshtinr(:,:)
-! real forward SHT matrix for lmaxinr
-real(8), allocatable :: rfshtinr(:,:)
-! complex backward SHT matrix for lmaxvr
-complex(8), allocatable :: zbshtvr(:,:)
-! complex forward SHT matrix for lmaxvr
-complex(8), allocatable :: zfshtvr(:,:)
-! complex backward SHT matrix for lmaxinr
-complex(8), allocatable :: zbshtinr(:,:)
-! complex forward SHT matrix for lmaxinr
-complex(8), allocatable :: zfshtinr(:,:)
+! trotsht is .true. if the spherical cover used for the SHT is to be rotated
+logical trotsht
+data trotsht / .false. /
+! spherical cover rotation matrix
+real(8) rotsht(3,3)
+! real backward SHT matrix for lmaxi
+real(8), allocatable :: rbshti(:,:)
+! real forward SHT matrix for lmaxi
+real(8), allocatable :: rfshti(:,:)
+! real backward SHT matrix for lmaxo
+real(8), allocatable :: rbshto(:,:)
+! real forward SHT matrix for lmaxo
+real(8), allocatable :: rfshto(:,:)
+! complex backward SHT matrix for lmaxi
+complex(8), allocatable :: zbshti(:,:)
+! complex forward SHT matrix for lmaxi
+complex(8), allocatable :: zfshti(:,:)
+! complex backward SHT matrix for lmaxo
+complex(8), allocatable :: zbshto(:,:)
+! complex forward SHT matrix for lmaxo
+complex(8), allocatable :: zfshto(:,:)
 
-!-----------------------------------------!
-!     potential and density variables     !
-!-----------------------------------------!
+!---------------------------------------------------------------!
+!     density, potential and exchange-correlation variables     !
+!---------------------------------------------------------------!
 ! exchange-correlation functional type
 integer xctype(3)
 ! exchange-correlation functional description
@@ -475,71 +517,73 @@ character(512) xcdescr
 integer xcspin
 ! exchange-correlation functional density gradient requirement
 integer xcgrad
-! setting ncgga to .true. improves convergence of non-collinear GGA calculations
-logical ncgga
+! small constant added to the up-density to stabilise non-collinear GGA
+real(8) dncgga
 ! Tran-Blaha '09 constant c [Phys. Rev. Lett. 102, 226401 (2009)]
 real(8) c_tb09
 ! tc_tb09 is .true. if the Tran-Blaha constant has been read in
 logical tc_tb09
 ! muffin-tin charge density
-real(8), allocatable :: rhomt(:,:,:)
+real(8), allocatable :: rhomt(:,:)
 ! interstitial real-space charge density
 real(8), allocatable :: rhoir(:)
 ! trhonorm is .true. if the density is to be normalised after every iteration
 logical trhonorm
 ! muffin-tin magnetisation vector field
-real(8), allocatable :: magmt(:,:,:,:)
+real(8), allocatable :: magmt(:,:,:)
 ! interstitial magnetisation vector field
 real(8), allocatable :: magir(:,:)
 ! amount of smoothing to be applied to the density; this is the number of
 ! 3-point running averages performed on the radial functions in the muffin-tins
 integer msmooth
 ! muffin-tin Coulomb potential
-real(8), allocatable :: vclmt(:,:,:)
+real(8), allocatable :: vclmt(:,:)
 ! interstitial real-space Coulomb potential
 real(8), allocatable :: vclir(:)
 ! Poisson solver pseudocharge density constant
 integer npsd
-! lmaxvr+npsd+1
+! lmaxo+npsd+1
 integer lnpsd
 ! muffin-tin exchange energy density
-real(8), allocatable :: exmt(:,:,:)
+real(8), allocatable :: exmt(:,:)
 ! interstitial real-space exchange energy density
 real(8), allocatable :: exir(:)
 ! muffin-tin correlation energy density
-real(8), allocatable :: ecmt(:,:,:)
+real(8), allocatable :: ecmt(:,:)
 ! interstitial real-space correlation energy density
 real(8), allocatable :: ecir(:)
 ! muffin-tin exchange-correlation potential
-real(8), allocatable :: vxcmt(:,:,:)
+real(8), allocatable :: vxcmt(:,:)
 ! interstitial real-space exchange-correlation potential
 real(8), allocatable :: vxcir(:)
 ! muffin-tin Kohn-Sham effective potential
-real(8), allocatable :: vsmt(:,:,:)
+real(8), allocatable :: vsmt(:,:)
 ! interstitial Kohn-Sham effective potential
 real(8), allocatable :: vsir(:)
 ! G-space interstitial Kohn-Sham effective potential
 complex(8), allocatable :: vsig(:)
-! trimvg is .true. if vsir should be trimmed for |G| > gmaxvr/2
+! trimvg is .true. if vsig should be trimmed for |G| > gmaxvr/2
 logical trimvg
 ! muffin-tin exchange-correlation magnetic field
-real(8), allocatable :: bxcmt(:,:,:,:)
+real(8), allocatable :: bxcmt(:,:,:)
 ! interstitial exchange-correlation magnetic field
 real(8), allocatable :: bxcir(:,:)
 ! muffin-tin Kohn-Sham effective magnetic field in spherical coordinates
-real(8), allocatable :: bsmt(:,:,:,:)
+real(8), allocatable :: bsmt(:,:,:)
 ! interstitial Kohn-Sham effective magnetic field
 real(8), allocatable :: bsir(:,:)
 ! spin-orbit coupling radial function
 real(8), allocatable :: socfr(:,:)
 ! nosource is .true. if the field is to be made source-free
 logical nosource
-! muffin-tin paramagnetic current
-real(8), allocatable :: jcmt(:,:,:,:)
-! interstitial paramagnetic current
-real(8), allocatable :: jcir(:,:)
+! trst is .true. if reduced Stoner theory (RST) is to be used
+logical trst
+! RST scale factor
+real(8) rstsf
 ! if trdstate is .true. the density and potential can be read from STATE.OUT
 logical trdstate
+! temperature in degrees kelvin
+real(8) tempk
 
 !--------------------------!
 !     mixing variables     !
@@ -551,16 +595,14 @@ character(256) mixdescr
 ! adaptive mixing parameter
 real(8) beta0
 real(8) betamax
-! subspace dimension for Pulay mixing
-integer mixsdp
 ! subspace dimension for Broyden mixing
 integer mixsdb
 ! Broyden mixing parameters alpha and w0
 real(8) broydpm(2)
 
-!-------------------------------------!
-!     charge and moment variables     !
-!-------------------------------------!
+!----------------------------------------------!
+!     charge, moment and current variables     !
+!----------------------------------------------!
 ! tolerance for error in total charge
 real(8) epschg
 ! total nuclear charge
@@ -597,10 +639,14 @@ real(8) momir(3)
 real(8), allocatable :: mommt(:,:)
 ! total muffin-tin moment
 real(8) mommttot(3)
+! total current
+real(8) curtot(3)
 
 !-----------------------------------------!
 !     APW and local-orbital variables     !
 !-----------------------------------------!
+! energy step used for numerical calculation of energy derivatives
+real(8) deapwlo
 ! maximum allowable APW order
 integer, parameter :: maxapword=4
 ! APW order
@@ -663,6 +709,10 @@ real(8) dlefe
 logical lorbcnd
 ! conduction state local-orbital order
 integer lorbordc
+! excess order of the APW and local-orbital functions
+integer nxoapwlo
+! excess local orbitals
+integer nxlo
 
 !-------------------------------------------!
 !     overlap and Hamiltonian variables     !
@@ -807,12 +857,6 @@ real(8) engytot
 !------------------------------------!
 ! tforce is .true. if force should be calculated
 logical tforce
-! tfibs is .true. if the IBS contribution to the force is to be calculated
-logical tfibs
-! radial distance at which Hellmann-Feynman force is to be evaluated
-real(8) radfhf
-! nearest radial mesh point to radfhf
-integer irfhf(maxspecies)
 ! Hellmann-Feynman force on each atom
 real(8), allocatable :: forcehf(:,:)
 ! incomplete basis set (IBS) force on each atom
@@ -925,11 +969,11 @@ real(8), allocatable :: vplp1d(:,:)
 ! distance to points in 1D plot
 real(8), allocatable :: dpp1d(:)
 ! corner vectors of 2D plot in lattice coordinates
-real(8) vclp2d(3,3)
+real(8) vclp2d(3,0:2)
 ! grid sizes of 2D plot
 integer np2d(2)
 ! corner vectors of 3D plot in lattice coordinates
-real(8) vclp3d(3,4)
+real(8) vclp3d(3,0:3)
 ! grid sizes of 3D plot
 integer np3d(3)
 
@@ -944,11 +988,9 @@ integer maxitoep
 real(8) tauoep(3)
 ! magnitude of the OEP residual
 real(8) resoep
-! kinetic matrix elements in the Cartesian basis
-complex(8), allocatable :: kmatc(:,:,:)
-! complex versions of the exchange potential and field
-complex(8), allocatable :: zvxmt(:,:,:),zvxir(:)
-complex(8), allocatable :: zbxmt(:,:,:,:),zbxir(:,:)
+! exchange potential and magnetic field
+real(8), allocatable :: vxmt(:,:),vxir(:)
+real(8), allocatable :: bxmt(:,:,:),bxir(:,:)
 ! hybrid is .true. if a hybrid functional is to be used
 logical hybrid
 ! hybrid functional mixing coefficient
@@ -1033,7 +1075,6 @@ real(8), parameter :: y00=0.28209479177387814347d0
 ! complex constants
 complex(8), parameter :: zzero=(0.d0,0.d0)
 complex(8), parameter :: zone=(1.d0,0.d0)
-complex(8), parameter :: ztwo=(2.d0,0.d0)
 complex(8), parameter :: zi=(0.d0,1.d0)
 ! array of i^l and (-i)^l values
 complex(8), allocatable :: zil(:),zilc(:)
@@ -1068,6 +1109,8 @@ real(8), parameter :: hbar_si=1.054571726d-34
 real(8), parameter :: e_si=1.602176565d-19
 ! atomic unit of magnetic flux density in SI
 real(8), parameter :: b_si=hbar_si/(e_si*br_si**2)
+! atomic unit of electric field in SI
+real(8), parameter :: ef_si=ha_si/(e_si*br_si)
 ! atomic unit of time in SI
 real(8), parameter :: t_si=hbar_si/ha_si
 ! electron mass in SI (CODATA 2010)
@@ -1082,7 +1125,7 @@ real(8), parameter :: amu=amu_si/em_si
 !---------------------------------!
 ! code version
 integer version(3)
-data version / 2,3,22 /
+data version / 4,0,15 /
 ! maximum number of tasks
 integer, parameter :: maxtasks=40
 ! number of tasks
