@@ -23,6 +23,11 @@ integer npulse
 ! laser pulse parameters: vector amplitude, peak time, full-width at
 ! half-maximum, frequency and phase
 real(8), allocatable :: pulse(:,:)
+! number of A-field ramps
+integer nramp
+! ramp parameters: vector amplitude, ramp start time, linear and quadratic
+! coefficients
+real(8), allocatable :: ramp(:,:)
 ! total simulation time
 real(8) tstime
 ! time step length
@@ -35,14 +40,15 @@ integer itimes
 real(8), allocatable :: times(:)
 ! time-dependent A-field
 real(8), allocatable :: afieldt(:,:)
-! momentum matrix elements in the Cartesian basis
-complex(8), allocatable :: pmatc(:,:,:,:)
 ! number of time steps after which observables are written to file
-integer ntwrite
+integer ntswrite
 ! the following variables are .true. if the corresponding quantities are to be
-! written every ntwrite time steps
-logical tdrho1d
-!****** readinput
+! written every ntswrite time steps
+logical tdrho1d,tdrho2d,tdrho3d
+logical tdmag2d,tdmag3d
+logical tddos
+! magnitude of complex numbers added to initial eigenvectors
+real(8) rndevt0
 
 end module
 
