@@ -9,37 +9,35 @@ use modmpi
 implicit none
 ! local variables
 integer ik,idm,is,ias
-integer nr,nrc,nrci,n,it
+integer nrc,nrci,np,npc
+integer it,n
 real(8) tau,resp,t1
 ! allocatable arrays
-real(8), allocatable :: rfmt1(:,:,:),rfmt2(:,:),rfir(:)
-real(8), allocatable :: rvfmt(:,:,:,:),rvfir(:,:)
-real(8), allocatable :: dvxmt(:,:,:),dvxir(:)
-real(8), allocatable :: dbxmt(:,:,:,:),dbxir(:,:)
+real(8), allocatable :: dvxmt(:,:),dvxir(:)
+real(8), allocatable :: dbxmt(:,:,:),dbxir(:,:)
+real(8), allocatable :: rfmt1(:,:),rfmt2(:),rfir(:)
+real(8), allocatable :: rvfmt(:,:,:),rvfir(:,:)
 complex(8), allocatable :: vclcv(:,:,:,:),vclvv(:,:,:)
 ! external functions
-real(8) rfinp
-external rfinp
+real(8) rfinpc
+external rfinpc
 if (iscl.lt.1) return
 ! calculate Coulomb matrix elements
-allocate(vclcv(ncrmax,natmtot,nstsv,nkpt))
-allocate(vclvv(nstsv,nstsv,nkpt))
+allocate(vclcv(ncrmax,natmtot,nstsv,nkpt),vclvv(nstsv,nstsv,nkpt))
 call oepvcl(vclcv,vclvv)
 ! allocate local arrays
-allocate(rfmt1(lmmaxvr,nrmtmax,natmtot),rfir(ngtot))
-allocate(dvxmt(lmmaxvr,nrcmtmax,natmtot),dvxir(ngtot))
+allocate(dvxmt(npcmtmax,natmtot),dvxir(ngtot))
+allocate(rfmt1(npmtmax,natmtot),rfir(ngtot))
 if (spinpol) then
-  allocate(rvfmt(lmmaxvr,nrmtmax,natmtot,ndmag))
-  allocate(rvfir(ngtot,ndmag))
-  allocate(dbxmt(lmmaxvr,nrcmtmax,natmtot,ndmag))
-  allocate(dbxir(ngtot,ndmag))
+  allocate(dbxmt(npcmtmax,natmtot,ndmag),dbxir(ngtot,ndmag))
+  allocate(rvfmt(npmtmax,natmtot,ndmag),rvfir(ngtot,ndmag))
 end if
-! set the exchange potential to zero
-zvxmt(:,:,:)=0.d0
-zvxir(:)=0.d0
+! set the exchange potential and magnetic field to zero
+vxmt(:,:)=0.d0
+vxir(:)=0.d0
 if (spinpol) then
-  zbxmt(:,:,:,:)=0.d0
-  zbxir(:,:)=0.d0
+  bxmt(:,:,:)=0.d0
+  bxir(:,:)=0.d0
 end if
 resp=0.d0
 ! initial step size
@@ -52,10 +50,10 @@ do it=1,maxitoep
     write(*,'("Info(oepmain): done ",I4," iterations of ",I4)') it,maxitoep
   end if
 ! zero the residuals
-  dvxmt(:,:,:)=0.d0
+  dvxmt(:,:)=0.d0
   dvxir(:)=0.d0
   if (spinpol) then
-    dbxmt(:,:,:,:)=0.d0
+    dbxmt(:,:,:)=0.d0
     dbxir(:,:)=0.d0
   end if
 ! calculate the k-dependent residuals
@@ -70,7 +68,7 @@ do it=1,maxitoep
 !$OMP END PARALLEL
 ! add residuals from each process and redistribute
   if (np_mpi.gt.1) then
-    n=lmmaxvr*nrcmtmax*natmtot
+    n=npcmtmax*natmtot
     call mpi_allreduce(mpi_in_place,dvxmt,n,mpi_double_precision,mpi_sum, &
      mpi_comm_kpt,ierror)
     call mpi_allreduce(mpi_in_place,dvxir,ngtot,mpi_double_precision, &
@@ -85,26 +83,26 @@ do it=1,maxitoep
     end if
   end if
 ! convert muffin-tin residuals to spherical harmonics
-!$OMP PARALLEL DEFAULT(SHARED) PRIVATE(is,idm)
+!$OMP PARALLEL DEFAULT(SHARED) PRIVATE(is,nrc,nrci,idm)
 !$OMP DO
   do ias=1,natmtot
     is=idxis(ias)
-    call rfsht(nrcmt(is),nrcmtinr(is),1,dvxmt(:,:,ias),lradstp,rfmt1(:,:,ias))
+    nrc=nrcmt(is)
+    nrci=nrcmti(is)
+    call rfsht(nrc,nrci,dvxmt(:,ias),rfmt1(:,ias))
     do idm=1,ndmag
-      call rfsht(nrcmt(is),nrcmtinr(is),1,dbxmt(:,:,ias,idm),lradstp, &
-       rvfmt(:,:,ias,idm))
+      call rfsht(nrc,nrci,dbxmt(:,ias,idm),rvfmt(:,ias,idm))
     end do
   end do
 !$OMP END DO
 !$OMP END PARALLEL
 ! symmetrise the residuals
-  call symrf(lradstp,rfmt1,dvxir)
-  if (spinpol) call symrvf(lradstp,rvfmt,dbxir)
+  call symrf(nrcmt,nrcmti,npcmt,npmtmax,rfmt1,dvxir)
+  if (spinpol) call symrvf(nrcmt,nrcmti,npcmt,npmtmax,rvfmt,dbxir)
 ! magnitude of residuals
-  resoep=sqrt(abs(rfinp(lradstp,rfmt1,rfmt1,dvxir,dvxir)))
+  resoep=sqrt(abs(rfinpc(npmtmax,rfmt1,dvxir,rfmt1,dvxir)))
   do idm=1,ndmag
-    t1=rfinp(lradstp,rvfmt(:,:,:,idm),rvfmt(:,:,:,idm),dbxir(:,idm), &
-     dbxir(:,idm))
+    t1=rfinpc(npmtmax,rvfmt(:,:,idm),dbxir(:,idm),rvfmt(:,:,idm),dbxir(:,idm))
     resoep=resoep+sqrt(abs(t1))
   end do
   resoep=resoep/omega
@@ -117,72 +115,71 @@ do it=1,maxitoep
     end if
   end if
   resp=resoep
-! update complex potential and field
+! update exchange potential and magnetic field
 !$OMP PARALLEL DEFAULT(SHARED) &
-!$OMP PRIVATE(rfmt2,is,nrc,nrci,idm)
+!$OMP PRIVATE(rfmt2,is,nrc,nrci,npc,idm)
 !$OMP DO
   do ias=1,natmtot
-    allocate(rfmt2(lmmaxvr,nrcmtmax))
+    allocate(rfmt2(npcmtmax))
     is=idxis(ias)
     nrc=nrcmt(is)
-    nrci=nrcmtinr(is)
-! convert residual to spherical coordinates and subtract from complex potential
-    call rbsht(nrc,nrci,lradstp,rfmt1(:,:,ias),1,rfmt2)
-    zvxmt(:,1:nrc,ias)=zvxmt(:,1:nrc,ias)-tau*rfmt2(:,1:nrc)
+    nrci=nrcmti(is)
+    npc=npcmt(is)
+! convert residual to spherical coordinates
+    call rbsht(nrc,nrci,rfmt1(:,ias),rfmt2)
+! subtract from exchange potential
+    vxmt(1:npc,ias)=vxmt(1:npc,ias)-tau*rfmt2(1:npc)
+! repeat for exchange magnetic field
     do idm=1,ndmag
-      call rbsht(nrc,nrci,lradstp,rvfmt(:,:,ias,idm),1,rfmt2)
-      zbxmt(:,1:nrc,ias,idm)=zbxmt(:,1:nrc,ias,idm)-tau*rfmt2(:,1:nrc)
+      call rbsht(nrc,nrci,rvfmt(:,ias,idm),rfmt2)
+      bxmt(1:npc,ias,idm)=bxmt(1:npc,ias,idm)-tau*rfmt2(1:npc)
     end do
     deallocate(rfmt2)
   end do
 !$OMP END DO
 !$OMP END PARALLEL
-  zvxir(:)=zvxir(:)-tau*dvxir(:)
+  vxir(:)=vxir(:)-tau*dvxir(:)
   do idm=1,ndmag
-    zbxir(:,idm)=zbxir(:,idm)-tau*dbxir(:,idm)
+    bxir(:,idm)=bxir(:,idm)-tau*dbxir(:,idm)
   end do
 ! end iteration loop
 end do
-! generate the real potential and field
+! convert the exchange potential and field to spherical harmonics
 !$OMP PARALLEL DEFAULT(SHARED) &
-!$OMP PRIVATE(rfmt2,is,nrc,nrci,idm)
+!$OMP PRIVATE(is,nrc,nrci,idm)
 !$OMP DO
 do ias=1,natmtot
-  allocate(rfmt2(lmmaxvr,nrcmtmax))
   is=idxis(ias)
   nrc=nrcmt(is)
-  nrci=nrcmtinr(is)
-  rfmt2(:,1:nrc)=dble(zvxmt(:,1:nrc,ias))
-  call rfsht(nrc,nrci,1,rfmt2,lradstp,rfmt1(:,:,ias))
+  nrci=nrcmti(is)
+  call rfsht(nrc,nrci,vxmt(:,ias),rfmt1(:,ias))
   do idm=1,ndmag
-    rfmt2(:,1:nrc)=dble(zbxmt(:,1:nrc,ias,idm))
-    call rfsht(nrc,nrci,1,rfmt2,lradstp,rvfmt(:,:,ias,idm))
+    call rfsht(nrc,nrci,bxmt(:,ias,idm),rvfmt(:,ias,idm))
   end do
-  deallocate(rfmt2)
 end do
 !$OMP END DO
 !$OMP END PARALLEL
 ! convert potential and field from a coarse to a fine radial mesh
 call rfmtctof(rfmt1)
 do idm=1,ndmag
-  call rfmtctof(rvfmt(:,:,:,idm))
+  call rfmtctof(rvfmt(:,:,idm))
 end do
 ! add to existing (density derived) correlation potential and field
 do ias=1,natmtot
   is=idxis(ias)
-  nr=nrmt(is)
-  vxcmt(:,1:nr,ias)=vxcmt(:,1:nr,ias)+rfmt1(:,1:nr,ias)
+  np=npmt(is)
+  vxcmt(1:np,ias)=vxcmt(1:np,ias)+rfmt1(1:np,ias)
   do idm=1,ndmag
-    bxcmt(:,1:nr,ias,idm)=bxcmt(:,1:nr,ias,idm)+rvfmt(:,1:nr,ias,idm)
+    bxcmt(1:np,ias,idm)=bxcmt(1:np,ias,idm)+rvfmt(1:np,ias,idm)
   end do
 end do
-vxcir(:)=vxcir(:)+dble(zvxir(:))
+vxcir(:)=vxcir(:)+vxir(:)
 do idm=1,ndmag
-  bxcir(:,idm)=bxcir(:,idm)+dble(zbxir(:,idm))
+  bxcir(:,idm)=bxcir(:,idm)+bxir(:,idm)
 end do
 ! symmetrise the exchange potential and field
-call symrf(1,vxcmt,vxcir)
-if (spinpol) call symrvf(1,bxcmt,bxcir)
+call symrf(nrmt,nrmti,npmt,npmtmax,vxcmt,vxcir)
+if (spinpol) call symrvf(nrmt,nrmti,npmt,npmtmax,bxcmt,bxcir)
 deallocate(rfmt1,rfir,vclcv,vclvv)
 deallocate(dvxmt,dvxir)
 if (spinpol) then
