@@ -9,8 +9,8 @@ implicit none
 ! arguments
 integer, intent(in) :: ias
 integer, intent(in) :: ngp,ngpq
-complex(8), intent(in) :: apwalm(ngkmax,apwordmax,lmmaxapw,natmtot)
-complex(8), intent(in) :: apwalmq(ngkmax,apwordmax,lmmaxapw,natmtot)
+complex(8), intent(in) :: apwalm(ngkmax,apwordmax,lmmaxapw)
+complex(8), intent(in) :: apwalmq(ngkmax,apwordmax,lmmaxapw)
 integer, intent(in) :: ld
 complex(8), intent(inout) :: oq(ld,*)
 ! local variables
@@ -24,13 +24,13 @@ do ilo=1,nlorb(is)
     j=ngp+idxlo(lm,ilo,ias)
     do i=1,ngpq
       do io=1,apword(l,is)
-        oq(i,j)=oq(i,j)+conjg(apwalmq(i,io,lm,ias))*oalo(io,ilo,ias)
+        oq(i,j)=oq(i,j)+conjg(apwalmq(i,io,lm))*oalo(io,ilo,ias)
       end do
     end do
     i=ngpq+idxlo(lm,ilo,ias)
     do j=1,ngp
       do io=1,apword(l,is)
-        oq(i,j)=oq(i,j)+oalo(io,ilo,ias)*apwalm(j,io,lm,ias)
+        oq(i,j)=oq(i,j)+oalo(io,ilo,ias)*apwalm(j,io,lm)
       end do
     end do
   end do
