@@ -27,51 +27,43 @@ use modmain
 !BOC
 implicit none
 ! local variables
-integer is,ia,ias,nr
+integer is,ias,nr
 integer ilo,jlo,l,io
-! allocatable arrays
-real(8), allocatable :: fr(:),gr(:)
+real(8) t1
 ! automatic arrays
-real(8) r2(nrmtmax)
-do is=1,nspecies
+real(8) fr(nrmtmax)
+! external functions
+real(8) fintgt
+external fintgt
+do ias=1,natmtot
+  is=idxis(ias)
   nr=nrmt(is)
-  r2(1:nr)=spr(1:nr,is)**2
-!$OMP PARALLEL DEFAULT(SHARED) &
-!$OMP PRIVATE(fr,gr,ias) &
-!$OMP PRIVATE(ilo,jlo,l,io) SHARED(is)
-!$OMP DO
-  do ia=1,natoms(is)
-    allocate(fr(nrmtmax),gr(nrmtmax))
-    ias=idxas(ia,is)
-!--------------------------------------!
-!     APW-local-orbital integtrals     !
-!--------------------------------------!
-    do ilo=1,nlorb(is)
-      l=lorbl(ilo,is)
-      do io=1,apword(l,is)
-        fr(1:nr)=apwfr(1:nr,1,io,l,ias)*lofr(1:nr,1,ilo,ias)*r2(1:nr)
-        call fderiv(-1,nr,spr(:,is),fr,gr)
-        oalo(io,ilo,ias)=gr(nr)
-      end do
+!-------------------------------------!
+!     APW-local-orbital integrals     !
+!-------------------------------------!
+  do ilo=1,nlorb(is)
+    l=lorbl(ilo,is)
+    do io=1,apword(l,is)
+      fr(1:nr)=apwfr(1:nr,1,io,l,ias)*lofr(1:nr,1,ilo,ias)*r2sp(1:nr,is)
+      t1=fintgt(-1,nr,rsp(:,is),fr)
+      oalo(io,ilo,ias)=t1
     end do
+  end do
 !-----------------------------------------------!
 !     local-orbital-local-orbital integrals     !
 !-----------------------------------------------!
-    do ilo=1,nlorb(is)
-      l=lorbl(ilo,is)
-      do jlo=1,nlorb(is)
-        if (lorbl(jlo,is).eq.l) then
-          fr(1:nr)=lofr(1:nr,1,ilo,ias)*lofr(1:nr,1,jlo,ias)*r2(1:nr)
-          call fderiv(-1,nr,spr(:,is),fr,gr)
-          ololo(ilo,jlo,ias)=gr(nr)
-        end if
-      end do
+  do ilo=1,nlorb(is)
+    l=lorbl(ilo,is)
+    do jlo=1,nlorb(is)
+      if (lorbl(jlo,is).eq.l) then
+        fr(1:nr)=lofr(1:nr,1,ilo,ias)*lofr(1:nr,1,jlo,ias)*r2sp(1:nr,is)
+        t1=fintgt(-1,nr,rsp(:,is),fr)
+        ololo(ilo,jlo,ias)=t1
+      end if
     end do
-    deallocate(fr,gr)
   end do
-!$OMP END DO
-!$OMP END PARALLEL
 end do
 return
 end subroutine
 !EOC
+
