@@ -10,14 +10,13 @@ use modpw
 use modmpi
 implicit none
 ! local variables
-integer jspn,idm,iv(3)
+integer ik,jk,iv(3)
+integer jspn,idm
 integer is,ia,ias,ip
-integer ik,jk,ig,igkq
-integer nwork,n
+integer nwork,n,lp
 ! use Broyden mixing only
 integer, parameter :: mtype=3
-real(8) vl(3),vc(3)
-real(8) tp(2),ddv,a,b
+real(8) ddv,a,b
 character(256) fext
 ! allocatable arrays
 real(8), allocatable :: evalfv(:,:)
@@ -25,7 +24,7 @@ real(8), allocatable :: v(:),work(:)
 complex(8), allocatable :: dyn(:,:)
 complex(8), allocatable :: apwalm(:,:,:,:,:),apwalmq(:,:,:,:,:)
 complex(8), allocatable :: dapwalm(:,:,:,:),dapwalmq(:,:,:,:)
-complex(8), allocatable :: evecfv(:,:,:),devalfv(:,:),devecfv(:,:,:)
+complex(8), allocatable :: evecfv(:,:,:),devecfv(:,:,:)
 complex(8), allocatable :: evecsv(:,:),devecsv(:,:)
 ! initialise universal variables
 call init0
@@ -73,20 +72,21 @@ call olprad
 call hmlrad
 ! generate the spin-orbit coupling radial functions
 call gensocfr
-! generate the first- and second-variational eigenvectors and eigenvalues
-call genevfsv
-! find the occupation numbers
-call occupy
+! get the eigenvalues and occupancies from file
+do ik=1,nkpt
+  call getevalsv(filext,ik,vkl(:,ik),evalsv(:,ik))
+  call getoccsv(filext,ik,vkl(:,ik),occsv(:,ik))
+end do
 ! size of mixing vector (complex array)
-n=2*(lmmaxvr*nrmtmax*natmtot+ngtot)
-if (spinpol) n=n+2*ndmag*(lmmaxvr*nrcmtmax*natmtot+ngtot)
-! allocate mixing arrays
-if (allocated(v)) deallocate(v)
+n=2*(npmtmax*natmtot+ngtot)
+if (spinpol) n=n+2*ndmag*(npcmtmax*natmtot+ngtot)
+! allocate mixing array
 allocate(v(n))
 ! determine the size of the mixer work array
 nwork=-1
 call mixerifc(mtype,n,v,ddv,nwork,v)
 allocate(work(nwork))
+! allocate dynamical matrix column
 allocate(dyn(3,natmtot))
 ! begin new phonon task
 10 continue
@@ -102,62 +102,19 @@ end if
 dyn(:,:)=0.d0
 ! check to see if mass is considered infinite
 if (spmass(isph).le.0.d0) goto 20
-! loop over non-reduced k-point set
-do ik=1,nkptnr
-! k+q-vectors in lattice and Cartesian coordinates
-  vkql(:,ik)=vkl(:,ik)+vql(:,iqph)
-  vkqc(:,ik)=vkc(:,ik)+vqc(:,iqph)
-  do jspn=1,nspnfv
-    vl(:)=vkql(:,ik)
-    vc(:)=vkqc(:,ik)
-! spin-spiral case
-    if (spinsprl) then
-      if (jspn.eq.1) then
-        vl(:)=vl(:)+0.5d0*vqlss(:)
-        vc(:)=vc(:)+0.5d0*vqcss(:)
-      else
-        vl(:)=vl(:)-0.5d0*vqlss(:)
-        vc(:)=vc(:)-0.5d0*vqcss(:)
-      end if
-    end if
-! generate the G+k+q-vectors
-    call gengkvec(ngvec,ivg,vgc,vl,vc,gkmax,ngkmax,ngkq(jspn,ik), &
-     igkqig(:,jspn,ik),vgkql(:,:,jspn,ik),vgkqc(:,:,jspn,ik))
-! generate the spherical coordinates of the G+k+q-vectors
-    do igkq=1,ngkq(jspn,ik)
-      call sphcrd(vgkqc(:,igkq,jspn,ik),gkqc(igkq,jspn,ik), &
-       tpgkqc(:,igkq,jspn,ik))
-    end do
-! generate structure factors for the G+k+q-vectors
-    call gensfacgp(ngkq(jspn,ik),vgkqc(:,:,jspn,ik),ngkmax,sfacgkq(:,:,jspn,ik))
-  end do
-end do
-! loop over G-vectors
-do ig=1,ngtot
-! G+q-vector in Cartesian coordinates
-  vgqc(:,ig)=vgc(:,ig)+vqc(:,iqph)
-! G+q-vector length and (theta, phi) coordinates
-  call sphcrd(vgqc(:,ig),gqc(ig),tp)
-! spherical harmonics for G+q-vectors
-  call genylm(lmaxvr,tp,ylmgq(:,ig))
-end do
-! compute the spherical Bessel functions j_l(|G+q|R_mt)
-call genjlgpr(lnpsd,gqc,jlgqr)
-! structure factors for G+q
-call gensfacgp(ngvec,vgqc,ngvec,sfacgq)
-! generate the smooth step function form factors for G+q
-do is=1,nspecies
-  call genffacgp(is,gqc,ffacgq(:,is))
-end do
+! generate the G+k+q-vectors and related quantities
+call gengkqvec(iqph)
+! generate the G+q-vectors and related quantities
+call gengqvec(iqph)
 ! generate the characteristic function derivative
 call gendcfun
 ! generate the gradient of the Kohn-Sham potential
 call gengvsmt
 ! initialise the potential derivative
-drhomt(:,:,:)=0.d0
+drhomt(:,:)=0.d0
 drhoir(:)=0.d0
 if (spinpol) then
-  dmagmt(:,:,:,:)=0.d0
+  dmagmt(:,:,:)=0.d0
   dmagir(:,:)=0.d0
 end if
 call dpotks
@@ -166,34 +123,37 @@ call gendvsig
 iscl=0
 call phmixpack(.true.,n,v)
 call mixerifc(mtype,n,v,ddv,nwork,work)
+! initialise the Fermi energy and occupancy derivatives
+defermi=0.d0
+doccsv(:,:)=0.d0
 ! begin the self-consistent loop
 do iscl=1,maxscl
 ! compute the Hamiltonian radial integral derivatives
   call dhmlrad
 ! zero the density and magnetisation derivatives
-  drhomt(:,:,:)=0.d0
+  drhomt(:,:)=0.d0
   drhoir(:)=0.d0
   if (spinpol) then
-    dmagmt(:,:,:,:)=0.d0
+    dmagmt(:,:,:)=0.d0
     dmagir(:,:)=0.d0
   end if
 ! parallel loop over k-points
 !$OMP PARALLEL DEFAULT(SHARED) &
 !$OMP PRIVATE(evalfv,apwalm,apwalmq,dapwalm,dapwalmq) &
-!$OMP PRIVATE(evecfv,devalfv,devecfv,evecsv,devecsv) &
-!$OMP PRIVATE(jk,jspn)
+!$OMP PRIVATE(evecfv,devecfv,evecsv,devecsv,jk,jspn)
 !$OMP DO
   do ik=1,nkptnr
+! distribute among MPI processes
+    if (mod(ik-1,np_mpi).ne.lp_mpi) cycle
     allocate(evalfv(nstfv,nspnfv))
     allocate(apwalm(ngkmax,apwordmax,lmmaxapw,natmtot,nspnfv))
     allocate(apwalmq(ngkmax,apwordmax,lmmaxapw,natmtot,nspnfv))
     allocate(dapwalm(ngkmax,apwordmax,lmmaxapw,nspnfv))
     allocate(dapwalmq(ngkmax,apwordmax,lmmaxapw,nspnfv))
-    allocate(evecfv(nmatmax,nstfv,nspnfv))
-    allocate(devalfv(nstfv,nspnfv),devecfv(nmatmax,nstfv,nspnfv))
+    allocate(evecfv(nmatmax,nstfv,nspnfv),devecfv(nmatmax,nstfv,nspnfv))
     allocate(evecsv(nstsv,nstsv),devecsv(nstsv,nstsv))
 ! equivalent reduced k-point
-    jk=ikmap(ivk(1,ik),ivk(2,ik),ivk(3,ik))
+    jk=ivkik(ivk(1,ik),ivk(2,ik),ivk(3,ik))
 ! compute the matching coefficients and derivatives
     do jspn=1,nspnfv
       call match(ngk(jspn,ik),gkc(:,jspn,ik),tpgkc(:,:,jspn,ik), &
@@ -206,15 +166,16 @@ do iscl=1,maxscl
        apwalmq(:,:,:,:,jspn),dapwalmq(:,:,:,jspn))
     end do
 ! get the first- and second-variational eigenvalues and eigenvectors from file
-    call getevalfv(vkl(:,ik),evalfv)
-    call getevecfv(vkl(:,ik),vgkl(:,:,:,ik),evecfv)
-    call getevecsv(vkl(:,ik),evecsv)
+    call getevalfv(filext,0,vkl(:,ik),evalfv)
+    call getevecfv(filext,0,vkl(:,ik),vgkl(:,:,:,ik),evecfv)
+    call getevecsv(filext,0,vkl(:,ik),evecsv)
 ! solve the first-variational eigenvalue equation derivative
     do jspn=1,nspnfv
       call deveqnfv(ngk(jspn,ik),ngkq(jspn,ik),igkig(:,jspn,ik), &
        igkqig(:,jspn,ik),vgkc(:,:,jspn,ik),vgkqc(:,:,jspn,ik),evalfv(:,jspn), &
        apwalm(:,:,:,:,jspn),apwalmq(:,:,:,:,jspn),dapwalm(:,:,:,jspn), &
-       dapwalmq(:,:,:,jspn),evecfv(:,:,jspn),devalfv(:,jspn),devecfv(:,:,jspn))
+       dapwalmq(:,:,:,jspn),evecfv(:,:,jspn),devalfv(:,jspn,ik), &
+       devecfv(:,:,jspn))
     end do
     if (spinsprl) then
 ! solve the spin-spiral second-variational eigenvalue equation derivative
@@ -228,26 +189,55 @@ do iscl=1,maxscl
     end if
 
 !*******
-devecsv=0.d0
+devalsv(:,ik)=devalfv(:,1,ik)
 !*******
 
 ! write the eigenvalue/vector derivatives to file
-    call putdevalfv(ik,devalfv)
     call putdevecfv(ik,devecfv)
-    call putdevecsv(ik,devecsv)
+    if (tevecsv) call putdevecsv(ik,devecsv)
 ! add to the density and magnetisation derivatives
     call drhomagk(ngk(:,ik),ngkq(:,ik),igkig(:,:,ik),igkqig(:,:,ik), &
-     occsv(:,jk),apwalm,apwalmq,dapwalm,evecfv,devecfv,evecsv,devecsv)
+     occsv(:,jk),doccsv(:,ik),apwalm,apwalmq,dapwalm,evecfv,devecfv,evecsv, &
+     devecsv)
     deallocate(evalfv,apwalm,apwalmq,dapwalm,dapwalmq)
-    deallocate(evecfv,devalfv,devecfv,evecsv,devecsv)
+    deallocate(evecfv,devecfv,evecsv,devecsv)
   end do
 !$OMP END DO
 !$OMP END PARALLEL
+! broadcast eigenvalue derivative arrays to every process
+  n=nstfv*nspnfv
+  do ik=1,nkptnr
+    lp=mod(ik-1,np_mpi)
+    call mpi_bcast(devalfv(:,:,ik),n,mpi_double_precision,lp,mpi_comm_kpt, &
+     ierror)
+    call mpi_bcast(devalsv(:,ik),nstsv,mpi_double_precision,lp,mpi_comm_kpt, &
+     ierror)
+  end do
+! convert to spherical harmonic representation
+  call drhomagsh
 ! convert from a coarse to a fine radial mesh
   call zfmtctof(drhomt)
   do idm=1,ndmag
-    call zfmtctof(dmagmt(:,:,:,idm))
+    call zfmtctof(dmagmt(:,:,idm))
   end do
+! add densities from each process and redistribute
+  if (np_mpi.gt.1) then
+    n=npmtmax*natmtot
+    call mpi_allreduce(mpi_in_place,drhomt,n,mpi_double_complex,mpi_sum, &
+     mpi_comm_kpt,ierror)
+    call mpi_allreduce(mpi_in_place,drhoir,ngtot,mpi_double_complex,mpi_sum, &
+     mpi_comm_kpt,ierror)
+    if (spinpol) then
+      n=npmtmax*natmtot*ndmag
+      call mpi_allreduce(mpi_in_place,dmagmt,n,mpi_double_complex,mpi_sum, &
+       mpi_comm_kpt,ierror)
+      n=ngtot*ndmag
+      call mpi_allreduce(mpi_in_place,dmagir,n,mpi_double_complex,mpi_sum, &
+       mpi_comm_kpt,ierror)
+    end if
+  end if
+! synchronise MPI processes
+  call mpi_barrier(mpi_comm_kpt,ierror)
 ! add gradient contribution to density derivative
   call gradrhomt
 ! compute the Kohn-Sham potential derivative
@@ -256,41 +246,60 @@ devecsv=0.d0
   call phmixpack(.true.,n,v)
 ! mix in the old potential and field with the new
   call mixerifc(mtype,n,v,ddv,nwork,work)
+! make sure every MPI process has a numerically identical potential
+  if (np_mpi.gt.1) then
+    call mpi_bcast(v,n,mpi_double_precision,0,mpi_comm_kpt,ierror)
+    call mpi_bcast(ddv,1,mpi_double_precision,0,mpi_comm_kpt,ierror)
+  end if
 ! unpack potential and field
   call phmixpack(.false.,n,v)
-  write(65,'(G18.10)') ddv
-  call flushifc(65)
+  if (mp_mpi) then
+    write(65,'(G18.10)') ddv
+    call flushifc(65)
+  end if
 ! check for convergence
   if (iscl.ge.2) then
     if (ddv.lt.epspot) goto 20
   end if
 ! Fourier transform Kohn-Sham potential derivative to G+q-space
   call gendvsig
+! compute the occupation number derivatives
+  call doccupy
 ! end the self-consistent loop
 end do
 write(*,*)
 write(*,'("Warning(phonon): failed to reach self-consistency after ",I4,&
  &" loops")') maxscl
 20 continue
-! close the RMSDDV.OUT file
-close(65)
+! close the RMSDDVS.OUT file
+if (mp_mpi) close(65)
+! synchronise MPI processes
+call mpi_barrier(mpi_comm_kpt,ierror)
 ! generate the dynamical matrix row from force derivatives
 call dforce(dyn)
+! synchronise MPI processes
+call mpi_barrier(mpi_comm_kpt,ierror)
 ! write dynamical matrix row to file
-do ias=1,natmtot
-  is=idxis(ias)
-  ia=idxia(ias)
-  do ip=1,3
-    a=dble(dyn(ip,ias))
-    b=aimag(dyn(ip,ias))
-    if (abs(a).lt.1.d-12) a=0.d0
-    if (abs(b).lt.1.d-12) b=0.d0
-    write(80,'(2G18.10," : is = ",I4,", ia = ",I4,", ip = ",I4)') a,b,is,ia,ip
+if (mp_mpi) then
+  do ias=1,natmtot
+    is=idxis(ias)
+    ia=idxia(ias)
+    do ip=1,3
+      a=dble(dyn(ip,ias))
+      b=aimag(dyn(ip,ias))
+      if (abs(a).lt.1.d-12) a=0.d0
+      if (abs(b).lt.1.d-12) b=0.d0
+      write(80,'(2G18.10," : is = ",I4,", ia = ",I4,", ip = ",I4)') a,b,is,ia,ip
+    end do
   end do
-end do
-close(80)
+  close(80)
+! write the complex Kohn-Sham potential derivative to file
+  call writedvs(fext)
 ! delete the non-essential files
-call phdelete
+  call phdelete
+end if
+! synchronise MPI processes
+call mpi_barrier(mpi_comm_kpt,ierror)
 goto 10
 end subroutine
 
