@@ -21,36 +21,46 @@ use modmain
 !BOC
 implicit none
 ! local variables
-integer is,ia,ias,nr
+integer is,ia,ias
+integer nr,nri,ir,i
 real(8) t1
 complex(8) zrho0
 ! automatic arrays
 real(8) vn(nrmtmax)
 ! allocatable arrays
-complex(8), allocatable :: zrhomt(:,:,:),zrhoir(:)
-complex(8), allocatable :: zvclmt(:,:,:),zvclir(:)
-allocate(zrhomt(lmmaxvr,nrmtmax,natmtot))
+complex(8), allocatable :: zrhomt(:,:),zrhoir(:)
+complex(8), allocatable :: zvclmt(:,:),zvclir(:)
+allocate(zrhomt(npmtmax,natmtot))
 ! convert real muffin-tin charge density to complex spherical harmonic expansion
 !$OMP PARALLEL DEFAULT(SHARED) PRIVATE(is)
 !$OMP DO
 do ias=1,natmtot
   is=idxis(ias)
-  call rtozfmt(nrmt(is),nrmtinr(is),1,rhomt(:,:,ias),1,zrhomt(:,:,ias))
+  call rtozfmt(nrmt(is),nrmti(is),rhomt(:,ias),zrhomt(:,ias))
 end do
 !$OMP END DO
 !$OMP END PARALLEL
 ! solve the complex Poisson's equation in the muffin-tins
-allocate(zvclmt(lmmaxvr,nrmtmax,natmtot))
-call genzvclmt(nrmt,nrmtinr,spnrmax,spr,nrmtmax,zrhomt,zvclmt)
+allocate(zvclmt(npmtmax,natmtot))
+call genzvclmt(nrmt,nrmti,nrspmax,rsp,npmtmax,zrhomt,zvclmt)
 deallocate(zrhomt)
 ! add the nuclear monopole potentials
 t1=1.d0/y00
 do is=1,nspecies
   nr=nrmt(is)
-  call potnucl(ptnucl,nr,spr(:,is),spzn(is),vn)
+  nri=nrmti(is)
+  call potnucl(ptnucl,nr,rsp(:,is),spzn(is),vn)
   do ia=1,natoms(is)
     ias=idxas(ia,is)
-    zvclmt(1,1:nr,ias)=zvclmt(1,1:nr,ias)+t1*vn(1:nr)
+    i=1
+    do ir=1,nri
+      zvclmt(i,ias)=zvclmt(i,ias)+t1*vn(ir)
+      i=i+lmmaxi
+    end do
+    do ir=nri+1,nr
+      zvclmt(i,ias)=zvclmt(i,ias)+t1*vn(ir)
+      i=i+lmmaxo
+    end do
   end do
 end do
 ! store real interstitial charge density in complex array
@@ -58,14 +68,14 @@ allocate(zrhoir(ngtot))
 zrhoir(:)=rhoir(:)
 ! solve Poisson's equation in the entire unit cell
 allocate(zvclir(ngtot))
-call zpotcoul(nrmt,nrmtinr,spnrmax,spr,1,gc,jlgr,ylmg,sfacg,zrhoir,nrmtmax, &
- zvclmt,zvclir,zrho0)
+call zpotcoul(nrmt,nrmti,npmt,npmti,nrspmax,rsp,1,gc,jlgr,ylmg,sfacg,zrhoir, &
+ npmtmax,zvclmt,zvclir,zrho0)
 ! convert complex muffin-tin potential to real spherical harmonic expansion
 !$OMP PARALLEL DEFAULT(SHARED) PRIVATE(is)
 !$OMP DO
 do ias=1,natmtot
   is=idxis(ias)
-  call ztorfmt(nrmt(is),nrmtinr(is),1,zvclmt(:,:,ias),1,vclmt(:,:,ias))
+  call ztorfmt(nrmt(is),nrmti(is),zvclmt(:,ias),vclmt(:,ias))
 end do
 !$OMP END DO
 !$OMP END PARALLEL
