@@ -3,10 +3,11 @@
 ! This file is distributed under the terms of the GNU General Public License.
 ! See the file COPYING for license details.
 
-subroutine putevalfv(ik,evalfv)
+subroutine putevalfv(fext,ik,evalfv)
 use modmain
 implicit none
 ! arguments
+character(*), intent(in) :: fext
 integer, intent(in) :: ik
 real(8), intent(in) :: evalfv(nstfv,nspnfv)
 ! local variables
@@ -14,7 +15,7 @@ integer recl
 ! find the record length
 inquire(iolength=recl) vkl(:,ik),nstfv,nspnfv,evalfv
 !$OMP CRITICAL
-open(70,file='EVALFV'//trim(filext),action='WRITE',form='UNFORMATTED', &
+open(70,file='EVALFV'//trim(fext),action='WRITE',form='UNFORMATTED', &
  access='DIRECT',recl=recl)
 write(70,rec=ik) vkl(:,ik),nstfv,nspnfv,evalfv
 close(70)
