@@ -3,10 +3,11 @@
 ! This file is distributed under the terms of the GNU General Public License.
 ! See the file COPYING for license details.
 
-subroutine putevecfv(ik,evecfv)
+subroutine putevecfv(fext,ik,evecfv)
 use modmain
 implicit none
 ! arguments
+character(*), intent(in) :: fext
 integer, intent(in) :: ik
 complex(8), intent(in) :: evecfv(nmatmax,nstfv,nspnfv)
 ! local variables
@@ -14,7 +15,7 @@ integer recl
 ! find the record length
 inquire(iolength=recl) vkl(:,ik),nmatmax,nstfv,nspnfv,evecfv
 !$OMP CRITICAL
-open(70,file=trim(scrpath)//'EVECFV'//trim(filext),action='WRITE', &
+open(70,file=trim(scrpath)//'EVECFV'//trim(fext),action='WRITE', &
  form='UNFORMATTED',access='DIRECT',recl=recl)
 write(70,rec=ik) vkl(:,ik),nmatmax,nstfv,nspnfv,evecfv
 close(70)
