@@ -3,10 +3,11 @@
 ! This file is distributed under the terms of the GNU General Public License.
 ! See the file COPYING for license details.
 
-subroutine putevecsv(ik,evecsv)
+subroutine putevecsv(fext,ik,evecsv)
 use modmain
 implicit none
 ! arguments
+character(*), intent(in) :: fext
 integer, intent(in) :: ik
 complex(8), intent(in) :: evecsv(nstsv,nstsv)
 ! local variables
@@ -14,7 +15,7 @@ integer recl
 ! find the record length
 inquire(iolength=recl) vkl(:,ik),nstsv,evecsv
 !$OMP CRITICAL
-open(70,file=trim(scrpath)//'EVECSV'//trim(filext),action='WRITE', &
+open(70,file=trim(scrpath)//'EVECSV'//trim(fext),action='WRITE', &
  form='UNFORMATTED',access='DIRECT',recl=recl)
 write(70,rec=ik) vkl(:,ik),nstsv,evecsv
 close(70)
