@@ -18,6 +18,7 @@ use modscdft
 use modpw
 use modtddft
 use modvars
+use modmpi
 ! !DESCRIPTION:
 !   Reads in the input parameters from the file {\tt elk.in}. Also sets default
 !   values for the input parameters.
@@ -63,14 +64,15 @@ reduceq=1
 rgkmax=7.d0
 gmaxvr=12.d0
 lmaxapw=8
-lmaxvr=7
-lmaxmat=6
-lmaxinr=3
-fracinr=0.1d0
+lmaxo=7
+lmaxmat=7
+lmaxi=3
+fracinr=0.01d0
 trhonorm=.true.
 xctype(1)=3
-xctype(2)=0
-xctype(3)=0
+xctype(2:3)=0
+xctsp(1)=3
+xctsp(2:3)=0
 stype=3
 swidth=0.001d0
 autoswidth=.false.
@@ -82,7 +84,6 @@ maxscl=200
 mixtype=1
 beta0=0.05d0
 betamax=1.d0
-mixsdp=3
 ! Broyden parameters recommended by M. Meinert
 mixsdb=5
 broydpm(1)=0.4d0
@@ -106,13 +107,13 @@ vvlp1d(:,1)=0.d0
 vvlp1d(:,2)=1.d0
 npp1d=200
 vclp2d(:,:)=0.d0
-vclp2d(1,2)=1.d0
-vclp2d(2,3)=1.d0
+vclp2d(1,1)=1.d0
+vclp2d(2,2)=1.d0
 np2d(:)=40
 vclp3d(:,:)=0.d0
-vclp3d(1,2)=1.d0
-vclp3d(2,3)=1.d0
-vclp3d(3,4)=1.d0
+vclp3d(1,1)=1.d0
+vclp3d(2,2)=1.d0
+vclp3d(3,3)=1.d0
 np3d(:)=20
 nwplot=500
 ngrkf=100
@@ -131,7 +132,7 @@ tau0atp=0.25d0
 deltast=0.005d0
 latvopt=0
 maxlatvstp=30
-tau0latv=0.1d0
+tau0latv=0.25d0
 lradstp=4
 chgexs=0.d0
 scissor=0.d0
@@ -143,6 +144,7 @@ epsband=1.d-12
 demaxbnd=2.5d0
 autolinengy=.false.
 dlefe=-0.1d0
+deapwlo=0.05d0
 bfieldc0(:)=0.d0
 efieldc(:)=0.d0
 afieldc(:)=0.d0
@@ -153,15 +155,13 @@ taufsm=0.01d0
 rmtdelta=0.05d0
 isgkmax=-1
 symtype=1
-deltaph=0.02d0
+deltaph=0.005d0
 nphwrt=1
 if (allocated(vqlwrt)) deallocate(vqlwrt)
 allocate(vqlwrt(3,nphwrt))
 vqlwrt(:,:)=0.d0
 notelns=0
 tforce=.false.
-tfibs=.true.
-radfhf=0.001d0
 maxitoep=200
 tauoep(1)=1.d0
 tauoep(2)=0.75d0
@@ -225,7 +225,7 @@ ecvcut=-3.5d0
 esccut=-0.4d0
 gmaxrf=3.d0
 emaxrf=1.d6
-ntemp=20
+ntemp=40
 trimvg=.false.
 taubdg=0.1d0
 nvbse0=2
@@ -249,9 +249,9 @@ hmaxvr=20.d0
 hkmax=12.d0
 lorbcnd=.false.
 lorbordc=3
-nrmtscf=1
+nrmtscf=1.d0
 lmaxdos=3
-epsph=0.005d0
+epsdev=0.005d0
 msmooth=0
 npmae0=-1
 wrtvars=.false.
@@ -261,12 +261,29 @@ tauftm=0.5d0
 ftmstep=1
 cmagz=.false.
 axang(:)=0.d0
-ncgga=.false.
-tstime=5.d0
-dtimes=0.01d0
+dncgga=1.d-4
+tstime=1000.d0
+dtimes=0.1d0
 npulse=0
-ntwrite=10
-ffdamp=.false.
+nramp=0
+ntswrite=10
+nxoapwlo=0
+nxlo=0
+tdrho1d=.false.
+tdrho2d=.false.
+tdrho3d=.false.
+tdmag2d=.false.
+tdmag3d=.false.
+epseph=0.02d0
+rndevt0=0.d0
+rstsf=1.d0
+tempk=0.d0
+ultracell=.false.
+ngridkpa(:)=1
+avecu(:,:)=0.d0
+avecu(1,1)=1.d0
+avecu(2,2)=1.d0
+avecu(3,3)=1.d0
 
 !--------------------------!
 !     read from elk.in     !
@@ -412,11 +429,19 @@ case('lmaxapw')
     write(*,*)
     stop
   end if
-case('lmaxvr')
-  read(50,*,err=20) lmaxvr
-  if (lmaxvr.lt.3) then
+case('lmaxo','lmaxvr')
+  read(50,*,err=20) lmaxo
+  if (lmaxo.lt.3) then
     write(*,*)
-    write(*,'("Error(readinput): lmaxvr < 3 : ",I8)') lmaxvr
+    write(*,'("Error(readinput): lmaxo < 3 : ",I8)') lmaxo
+    write(*,*)
+    stop
+  end if
+case('lmaxi','lmaxinr')
+  read(50,*,err=20) lmaxi
+  if (lmaxi.lt.0) then
+    write(*,*)
+    write(*,'("Error(readinput): lmaxi < 0 : ",I8)') lmaxi
     write(*,*)
     stop
   end if
@@ -428,14 +453,6 @@ case('lmaxmat')
     write(*,*)
     stop
   end if
-case('lmaxinr')
-  read(50,*,err=20) lmaxinr
-  if (lmaxinr.lt.0) then
-    write(*,*)
-    write(*,'("Error(readinput): lmaxinr < 0 : ",I8)') lmaxinr
-    write(*,*)
-    stop
-  end if
 case('fracinr')
   read(50,*,err=20) fracinr
 case('trhonorm')
@@ -456,6 +473,10 @@ case('xctype')
   read(50,'(A256)',err=20) str
   str=trim(str)//' 0 0'
   read(str,*,err=20) xctype
+case('xctsp')
+  read(50,'(A256)',err=20) str
+  str=trim(str)//' 0 0'
+  read(str,*,err=20) xctsp
 case('stype')
   read(50,*,err=20) stype
 case('swidth')
@@ -519,14 +540,6 @@ case('betamax')
     write(*,*)
     stop
   end if
-case('mixsdp')
-  read(50,*,err=20) mixsdp
-  if (mixsdp.lt.2) then
-    write(*,*)
-    write(*,'("Error(readinput): mixsdp < 2 : ",I8)') mixsdp
-    write(*,*)
-    stop
-  end if
 case('mixsdb')
   read(50,*,err=20) mixsdb
   if (mixsdb.lt.2) then
@@ -628,9 +641,9 @@ case('plot1d')
     read(50,*,err=20) vvlp1d(:,i)
   end do
 case('plot2d')
+  read(50,*,err=20) vclp2d(:,0)
   read(50,*,err=20) vclp2d(:,1)
   read(50,*,err=20) vclp2d(:,2)
-  read(50,*,err=20) vclp2d(:,3)
   read(50,*,err=20) np2d(:)
   if ((np2d(1).lt.1).or.(np2d(2).lt.1)) then
     write(*,*)
@@ -639,10 +652,10 @@ case('plot2d')
     stop
   end if
 case('plot3d')
+  read(50,*,err=20) vclp3d(:,0)
   read(50,*,err=20) vclp3d(:,1)
   read(50,*,err=20) vclp3d(:,2)
   read(50,*,err=20) vclp3d(:,3)
-  read(50,*,err=20) vclp3d(:,4)
   read(50,*,err=20) np3d(:)
   if ((np3d(1).lt.1).or.(np3d(2).lt.1).or.(np3d(3).lt.1)) then
     write(*,*)
@@ -798,6 +811,14 @@ case('autolinengy')
   read(50,*,err=20) autolinengy
 case('dlefe')
   read(50,*,err=20) dlefe
+case('deapwlo')
+  read(50,*,err=20) deapwlo
+  if (abs(deapwlo).lt.1.d-8) then
+    write(*,*)
+    write(*,'("Error(readinput): invalid deapwlo : ",G18.10)') deapwlo
+    write(*,*)
+    stop
+  end if
 case('bfieldc')
   read(50,*,err=20) bfieldc0
 case('efieldc')
@@ -891,15 +912,9 @@ case('notes')
 case('tforce')
   read(50,*,err=20) tforce
 case('tfibs')
-  read(50,*,err=20) tfibs
-case('radfhf')
-  read(50,*,err=20) radfhf
-  if (radfhf.lt.0.d0) then
-    write(*,*)
-    write(*,'("Error(readinput): radfhf < 0 : ",G18.10)') radfhf
-    write(*,*)
-    stop
-  end if
+  read(50,*,err=20)
+  write(*,*)
+  write(*,'("Info(readinput): variable ''tfibs'' is no longer used")')
 case('maxitoep')
   read(50,*,err=20) maxitoep
   if (maxitoep.lt.1) then
@@ -1160,6 +1175,7 @@ case('sqados')
 case('test')
   read(50,*,err=20) test
 case('frozencr')
+  read(50,*,err=20)
   write(*,*)
   write(*,'("Info(readinput): variable ''frozencr'' is no longer used")')
 case('spincore')
@@ -1330,25 +1346,100 @@ case('c_tb09')
   tc_tb09=.true.
 case('rndachi')
   read(50,*,err=20) rndachi
-case('highq')
+case('highq','vhighq','uhighq')
   read(50,*,err=20) highq
-! parameter set for high-quality calculation
   if (highq) then
-    rgkmax=7.5d0
-    gmaxvr=16.d0
-    lmaxapw=10
-    lmaxvr=8
-    lmaxmat=8
-    lradstp=2
-    fracinr=0.05d0
-    radkpt=50.d0
-    autokpt=.true.
-    vkloff(:)=0.d0
-    nempty0=10.d0
-    epspot=1.d-7
-    epsengy=1.d-5
-    epsforce=1.d-4
-    lorbcnd=.true.
+! parameter set for high quality calculation
+    if (trim(block).eq.'highq') then
+      rgkmax=8.d0
+      gmaxvr=20.d0
+      trimvg=.true.
+      lmaxapw=10
+      lmaxo=8
+      lmaxi=4
+      lmaxmat=8
+      fracinr=0.005d0
+      nrmtscf=1.5d0
+      nxlo=2
+      radkpt=50.d0
+      autokpt=.true.
+      vkloff(:)=0.d0
+      nempty0=10.d0
+      epspot=1.d-7
+      epsengy=1.d-5
+      epsforce=1.d-4
+      autolinengy=.true.
+      gmaxrf=4.d0
+    else if (trim(block).eq.'vhighq') then
+! parameter set for very high quality calculation
+      rgkmax=9.d0
+      gmaxvr=24.d0
+      trimvg=.true.
+      lmaxapw=12
+      lmaxo=9
+      lmaxi=4
+      lmaxmat=12
+      fracinr=0.005d0
+      nrmtscf=2.d0
+      nxlo=3
+      radkpt=90.d0
+      autokpt=.true.
+      vkloff(:)=0.d0
+      nempty0=20.d0
+      epspot=1.d-8
+      epsengy=1.d-6
+      epsforce=1.d-5
+      autolinengy=.true.
+      gmaxrf=5.d0
+    else
+! parameter set for ultra high quality calculation
+      rgkmax=10.d0
+      gmaxvr=36.d0
+      trimvg=.true.
+      lmaxapw=16
+      lmaxo=12
+      lmaxi=5
+      lmaxmat=12
+      fracinr=0.001d0
+      nrmtscf=4.d0
+      nxlo=3
+      lorbcnd=.true.
+      radkpt=120.d0
+      autokpt=.true.
+      vkloff(:)=0.d0
+      nempty0=60.d0
+      epspot=1.d-7
+      epsengy=1.d-5
+      epsforce=1.d-4
+      autolinengy=.true.
+      gmaxrf=6.d0
+    end if
+    if (mp_mpi) then
+      write(*,*)
+      write(*,'("Info(readinput): parameters set by ",A," option")') trim(block)
+      write(*,'(" rgkmax : ",G18.10)') rgkmax
+      write(*,'(" gmaxvr : ",G18.10)') gmaxvr
+      write(*,'(" trimvg : ",L1)') autokpt
+      write(*,'(" lmaxapw : ",I4)') lmaxapw
+      write(*,'(" lmaxmat : ",I4)') lmaxmat
+      write(*,'(" lmaxo : ",I4)') lmaxo
+      write(*,'(" lmaxi : ",I4)') lmaxi
+      write(*,'(" fracinr : ",G18.10)') fracinr
+      write(*,'(" nrmtscf : ",G18.10)') nrmtscf
+      write(*,'(" nxlo : ",I4)') nxlo
+      write(*,'(" radkpt : ",G18.10)') radkpt
+      write(*,'(" autokpt : ",L1)') autokpt
+      write(*,'(" vkloff : ",3G18.10)') vkloff
+      write(*,'(" nempty0 : ",G18.10)') nempty0
+      write(*,'(" epspot : ",G18.10)') epspot
+      write(*,'(" epsengy : ",G18.10)') epsengy
+      write(*,'(" epsforce : ",G18.10)') epsforce
+      write(*,'(" autolinengy : ",L1)') autolinengy
+      write(*,'(" gmaxrf : ",G18.10)') gmaxrf
+      if (trim(block).eq.'uhighq') then
+        write(*,'(" lorbcnd : ",L1)') lorbcnd
+      end if
+    end if
   end if
 case('hmaxvr')
   read(50,*,err=20) hmaxvr
@@ -1385,9 +1476,9 @@ case('lorbordc')
   end if
 case('nrmtscf')
   read(50,*,err=20) nrmtscf
-  if (nrmtscf.lt.1) then
+  if (nrmtscf.lt.0.5d0) then
     write(*,*)
-    write(*,'("Error(readinput): nrmtscf < 1 : ",I8)') nrmtscf
+    write(*,'("Error(readinput): nrmtscf < 0.5 : ",G18.10)') nrmtscf
     write(*,*)
     stop
   end if
@@ -1399,11 +1490,11 @@ case('lmaxdos')
     write(*,*)
     stop
   end if
-case('epsph')
-  read(50,*,err=20) epsph
-  if (epsph.le.0.d0) then
+case('epsdev')
+  read(50,*,err=20) epsdev
+  if (epsdev.le.0.d0) then
     write(*,*)
-    write(*,'("Error(readinput): epsph <= 0 : ",G18.10)') epsph
+    write(*,'("Error(readinput): epsdev <= 0 : ",G18.10)') epsdev
     write(*,*)
     stop
   end if
@@ -1518,16 +1609,93 @@ case('pulse')
     stop
   end if
   if (allocated(pulse)) deallocate(pulse)
-  allocate(pulse(7,npulse))
+  allocate(pulse(8,npulse))
   do i=1,npulse
     read(50,*,err=20) pulse(:,i)
   end do
+case('ramp')
+  read(50,*,err=20) nramp
+  if (nramp.lt.1) then
+    write(*,*)
+    write(*,'("Error(readinput): nramp < 1 : ",I8)') nramp
+    write(*,*)
+    stop
+  end if
+  if (allocated(ramp)) deallocate(ramp)
+  allocate(ramp(6,nramp))
+  do i=1,nramp
+    read(50,*,err=20) ramp(:,i)
+  end do
 case('ncgga')
-  read(50,*,err=20) ncgga
-case('ntwrite')
-  read(50,*,err=20) ntwrite
-case('ffdamp')
-  read(50,*,err=20) ffdamp
+  read(50,*,err=20)
+  write(*,*)
+  write(*,'("Info(readinput): variable ''ncgga'' is no longer used")')
+case('dncgga')
+  read(50,*,err=20) dncgga
+case('ntswrite')
+  read(50,*,err=20) ntswrite
+case('nxoapwlo','nxapwlo')
+  read(50,*,err=20) nxoapwlo
+  if (nxoapwlo.lt.0) then
+    write(*,*)
+    write(*,'("Error(readinput): nxoapwlo < 0 : ",I8)') nxoapwlo
+    write(*,*)
+    stop
+  end if
+case('nxlo')
+  read(50,*,err=20) nxlo
+  if (nxlo.lt.0) then
+    write(*,*)
+    write(*,'("Error(readinput): nxlo < 0 : ",I8)') nxlo
+    write(*,*)
+    stop
+  end if
+case('tdrho1d')
+  read(50,*,err=20) tdrho1d
+case('tdrho2d')
+  read(50,*,err=20) tdrho2d
+case('tdrho3d')
+  read(50,*,err=20) tdrho3d
+case('tdmag2d')
+  read(50,*,err=20) tdmag2d
+case('tdmag3d')
+  read(50,*,err=20) tdmag3d
+case('tddos')
+  read(50,*,err=20) tddos
+case('epseph')
+  read(50,*,err=20) epseph
+  if (epseph.le.0.d0) then
+    write(*,*)
+    write(*,'("Error(readinput): epseph <= 0 : ",G18.10)') epseph
+    write(*,*)
+    stop
+  end if
+case('rndevt0')
+  read(50,*,err=20) rndevt0
+case('rstsf')
+  read(50,*,err=20) rstsf
+case('tempk')
+  read(50,*,err=20) tempk
+  if (tempk.lt.0.d0) then
+    write(*,*)
+    write(*,'("Error(readinput): tempk < 0 : ",G18.10)') tempk
+    write(*,*)
+    stop
+  end if
+case('ultracell')
+  read(50,*,err=20) ultracell
+case('ngridkpa')
+  read(50,*,err=20) ngridkpa
+  if ((ngridkpa(1).le.0).or.(ngridkpa(2).le.0).or.(ngridkpa(3).le.0)) then
+    write(*,*)
+    write(*,'("Error(readinput): invalid ngridkpa : ",3I8)') ngridkpa(:)
+    write(*,*)
+    stop
+  end if
+case('avecu')
+  read(50,*,err=20) avecu(:,1)
+  read(50,*,err=20) avecu(:,2)
+  read(50,*,err=20) avecu(:,3)
 case('')
   goto 10
 case default
