@@ -7,27 +7,35 @@ real(8) function rfint(rfmt,rfir)
 use modmain
 implicit none
 ! arguments
-real(8), intent(in) :: rfmt(lmmaxvr,nrmtmax,natmtot)
-real(8), intent(in) :: rfir(ngtot)
+real(8), intent(in) :: rfmt(npmtmax,natmtot),rfir(ngtot)
 ! local variables
-integer is,ias,ir
-real(8) sum
+integer is,ias
+integer nr,nri,ir,i
+real(8) sum,t1
 ! automatic arrays
-real(8) fr(nrmtmax),gr(nrmtmax)
-sum=0.d0
+real(8) fr(nrmtmax)
+! external functions
+real(8) fintgt
+external fintgt
 ! interstitial contribution
-do ir=1,ngtot
-  sum=sum+rfir(ir)*cfunir(ir)
-end do
+sum=dot_product(rfir(:),cfunir(:))
 sum=sum*omega/dble(ngtot)
 ! muffin-tin contribution
 do ias=1,natmtot
   is=idxis(ias)
-  do ir=1,nrmt(is)
-    fr(ir)=rfmt(1,ir,ias)*spr(ir,is)**2
+  nr=nrmt(is)
+  nri=nrmti(is)
+  i=1
+  do ir=1,nri
+    fr(ir)=rfmt(i,ias)*r2sp(ir,is)
+    i=i+lmmaxi
   end do
-  call fderiv(-1,nrmt(is),spr(:,is),fr,gr)
-  sum=sum+fourpi*y00*gr(nrmt(is))
+  do ir=nri+1,nr
+    fr(ir)=rfmt(i,ias)*r2sp(ir,is)
+    i=i+lmmaxo
+  end do
+  t1=fintgt(-1,nr,rsp(:,is),fr)
+  sum=sum+fourpi*y00*t1
 end do
 rfint=sum
 return
