@@ -20,37 +20,26 @@ use modmain
 implicit none
 ! local variables
 integer idm,is,ias
-integer nr,nrc,nrci,ir,irc
+integer nrc,nrci,npc
 ! allocatable arrays
-real(8), allocatable :: rfmt(:,:)
+real(8), allocatable :: rfmt(:)
 !$OMP PARALLEL DEFAULT(SHARED) &
-!$OMP PRIVATE(rfmt,is,nr,nrc) &
-!$OMP PRIVATE(nrci,irc,ir,idm)
+!$OMP PRIVATE(rfmt,is,nrc,nrci,npc,idm)
 !$OMP DO
 do ias=1,natmtot
-  allocate(rfmt(lmmaxvr,nrcmtmax))
+  allocate(rfmt(npcmtmax))
   is=idxis(ias)
-  nr=nrmt(is)
   nrc=nrcmt(is)
-  nrci=nrcmtinr(is)
+  nrci=nrcmti(is)
+  npc=npcmt(is)
 ! convert the density to spherical harmonics
-  irc=0
-  do ir=1,nr,lradstp
-    irc=irc+1
-    rfmt(:,irc)=rhomt(:,ir,ias)
-  end do
-  call rfsht(nrc,nrci,1,rfmt,lradstp,rhomt(:,:,ias))
+  rfmt(1:npc)=rhomt(1:npc,ias)
+  call rfsht(nrc,nrci,rfmt,rhomt(:,ias))
 ! convert magnetisation to spherical harmonics
-  if (spinpol) then
-    do idm=1,ndmag
-      irc=0
-      do ir=1,nr,lradstp
-        irc=irc+1
-        rfmt(:,irc)=magmt(:,ir,ias,idm)
-      end do
-      call rfsht(nrc,nrci,1,rfmt,lradstp,magmt(:,:,ias,idm))
-    end do
-  end if
+  do idm=1,ndmag
+    rfmt(1:npc)=magmt(1:npc,ias,idm)
+    call rfsht(nrc,nrci,rfmt,magmt(:,ias,idm))
+  end do
   deallocate(rfmt)
 end do
 !$OMP END DO
