@@ -7,18 +7,18 @@ subroutine rhomagsm
 use modmain
 implicit none
 ! local variables
-integer is,ias,idm
+integer idm,is,ias
 if (msmooth.eq.0) return
 ! smooth the muffin-tin density
 do ias=1,natmtot
   is=idxis(ias)
-  call rfmtsm(msmooth,lmmaxvr,nrmt(is),lmmaxvr,rhomt(:,:,ias))
+  call rfmtsm(msmooth,nrmt(is),nrmti(is),rhomt(:,ias))
 end do
 ! smooth the muffin-tin magnetisation
 do idm=1,ndmag
   do ias=1,natmtot
     is=idxis(ias)
-    call rfmtsm(msmooth,lmmaxvr,nrmt(is),lmmaxvr,magmt(:,:,ias,idm))
+    call rfmtsm(msmooth,nrmt(is),nrmti(is),magmt(:,ias,idm))
   end do
 end do
 return
