@@ -50,12 +50,12 @@ call genapwfr
 call genlofr
 ! get the eigenvalues and occupancies from file
 do ik=1,nkpt
-  call getevalsv(vkl(:,ik),evalsv(:,ik))
-  call getoccsv(vkl(:,ik),occsv(:,ik))
+  call getevalsv(filext,ik,vkl(:,ik),evalsv(:,ik))
+  call getoccsv(filext,ik,vkl(:,ik),occsv(:,ik))
 end do
 ! generate the G+q-vectors and related quantities
 allocate(vgqc(3,ngrf),gqc(ngrf))
-allocate(ylmgq(lmmaxvr,ngrf),sfacgq(ngrf,natmtot))
+allocate(ylmgq(lmmaxo,ngrf),sfacgq(ngrf,natmtot))
 call gengqrf(vecqc,igq0,vgqc,gqc,ylmgq,sfacgq)
 ! allocate local arrays
 allocate(vchi0(nwrf,ngrf,ngrf),vfxc(ngrf,ngrf,nwrf))
