@@ -6,20 +6,18 @@
 !BOP
 ! !ROUTINE: wavefmt
 ! !INTERFACE:
-subroutine wavefmt(lrstp,lmax,ias,ngp,apwalm,evecfv,ld,wfmt)
+subroutine wavefmt(lrstp,ias,ngp,apwalm,evecfv,wfmt)
 ! !USES:
 use modmain
 ! !INPUT/OUTPUT PARAMETERS:
 !   lrstp  : radial step length (in,integer)
-!   lmax   : maximum angular momentum required (in,integer)
 !   ias    : joint atom and species number (in,integer)
 !   ngp    : number of G+p-vectors (in,integer)
 !   apwalm : APW matching coefficients
 !            (in,complex(ngkmax,apwordmax,lmmaxapw,natmtot))
 !   evecfv : first-variational eigenvector (in,complex(nmatmax))
-!   ld     : leading dimension (in,integer)
 !   wfmt   : complex muffin-tin wavefunction passed in as real array
-!            (out,real(2,ld,*))
+!            (out,real(2,*))
 ! !DESCRIPTION:
 !   Calculates the first-variational wavefunction in the muffin-tin in terms of
 !   a spherical harmonic expansion. For atom $\alpha$ and a particular $k$-point
@@ -41,71 +39,93 @@ use modmain
 !   Created April 2003 (JKD)
 !   Fixed description, October 2004 (C. Brouder)
 !   Removed argument ist, November 2006 (JKD)
+!   Changed arguments and optimised, December 2014 (JKD)
 !EOP
 !BOC
 implicit none
 ! arguments
-integer, intent(in) :: lrstp
-integer, intent(in) :: lmax
-integer, intent(in) :: ias
-integer, intent(in) :: ngp
+integer, intent(in) :: lrstp,ias,ngp
 complex(8), intent(in) :: apwalm(ngkmax,apwordmax,lmmaxapw,natmtot)
 complex(8), intent(in) :: evecfv(nmatmax)
-integer, intent(in) :: ld
-real(8), intent(out) :: wfmt(2,ld,*)
+real(8), intent(out) :: wfmt(2,*)
 ! local variables
-integer is,nrc,ir,ld2
-integer l,m,lm,io,ilo
+integer is,ldi,ldo,io,ilo
+integer nrc,nrci,nrco,iro
+integer l,m,lm,npc,npci,i
 complex(8) z1
 ! external functions
 complex(8) zdotu
 external zdotu
-if (lmax.gt.lmaxapw) then
+is=idxis(ias)
+ldi=2*lmmaxi
+ldo=2*lmmaxo
+iro=nrmti(is)+lrstp
+if (lrstp.eq.1) then
+  nrc=nrmt(is)
+  nrci=nrmti(is)
+  npc=npmt(is)
+  npci=npmti(is)
+else if (lrstp.eq.lradstp) then
+  nrc=nrcmt(is)
+  nrci=nrcmti(is)
+  npc=npcmt(is)
+  npci=npcmti(is)
+else
   write(*,*)
-  write(*,'("Error(wavefmt): lmax > lmaxapw : ",I8)') lmax
+  write(*,'("Error(wavefmt): invalid lrstp : ",I8)') lrstp
   write(*,*)
   stop
 end if
-ld2=ld*2
-! species number
-is=idxis(ias)
+nrco=nrc-nrci
 ! zero the wavefunction
-nrc=0
-do ir=1,nrmt(is),lrstp
-  nrc=nrc+1
-  wfmt(:,:,nrc)=0.d0
-end do
-! APW functions
+wfmt(:,1:npc)=0.d0
+!-----------------------!
+!     APW functions     !
+!-----------------------!
 lm=0
-do l=0,lmax
+do l=0,lmaxo
   do m=-l,l
     lm=lm+1
+    i=npci+lm
     do io=1,apword(l,is)
       z1=zdotu(ngp,evecfv,1,apwalm(:,io,lm,ias),1)
       if (abs(dble(z1)).gt.1.d-14) then
-        call daxpy(nrc,dble(z1),apwfr(:,1,io,l,ias),lrstp,wfmt(1,lm,1),ld2)
+        if (l.le.lmaxi) then
+          call daxpy(nrci,dble(z1),apwfr(1,1,io,l,ias),lrstp,wfmt(1,lm),ldi)
+        end if
+        call daxpy(nrco,dble(z1),apwfr(iro,1,io,l,ias),lrstp,wfmt(1,i),ldo)
       end if
       if (abs(aimag(z1)).gt.1.d-14) then
-        call daxpy(nrc,aimag(z1),apwfr(:,1,io,l,ias),lrstp,wfmt(2,lm,1),ld2)
+        if (l.le.lmaxi) then
+          call daxpy(nrci,aimag(z1),apwfr(1,1,io,l,ias),lrstp,wfmt(2,lm),ldi)
+        end if
+        call daxpy(nrco,aimag(z1),apwfr(iro,1,io,l,ias),lrstp,wfmt(2,i),ldo)
       end if
     end do
   end do
 end do
-! local-orbital functions
+!---------------------------------!
+!     local-orbital functions     !
+!---------------------------------!
 do ilo=1,nlorb(is)
   l=lorbl(ilo,is)
-  if (l.le.lmax) then
-    do m=-l,l
-      lm=idxlm(l,m)
-      z1=evecfv(ngp+idxlo(lm,ilo,ias))
-      if (abs(dble(z1)).gt.1.d-14) then
-        call daxpy(nrc,dble(z1),lofr(:,1,ilo,ias),lrstp,wfmt(1,lm,1),ld2)
+  do m=-l,l
+    lm=idxlm(l,m)
+    i=npci+lm
+    z1=evecfv(ngp+idxlo(lm,ilo,ias))
+    if (abs(dble(z1)).gt.1.d-14) then
+      if (l.le.lmaxi) then
+        call daxpy(nrci,dble(z1),lofr(1,1,ilo,ias),lrstp,wfmt(1,lm),ldi)
       end if
-      if (abs(aimag(z1)).gt.1.d-14) then
-        call daxpy(nrc,aimag(z1),lofr(:,1,ilo,ias),lrstp,wfmt(2,lm,1),ld2)
+      call daxpy(nrco,dble(z1),lofr(iro,1,ilo,ias),lrstp,wfmt(1,i),ldo)
+    end if
+    if (abs(aimag(z1)).gt.1.d-14) then
+      if (l.le.lmaxi) then
+        call daxpy(nrci,aimag(z1),lofr(1,1,ilo,ias),lrstp,wfmt(2,lm),ldi)
       end if
-    end do
-  end if
+      call daxpy(nrco,aimag(z1),lofr(iro,1,ilo,ias),lrstp,wfmt(2,i),ldo)
+    end if
+  end do
 end do
 return
 end subroutine
