@@ -29,6 +29,8 @@ call init1
 call init4
 ! read density and potentials from file
 call readstate
+! read Fermi energy from file
+call readfermi
 ! find the new linearisation energies
 call linengy
 ! generate the APW radial functions
@@ -37,7 +39,7 @@ call genapwfr
 call genlofr
 ! get the occupancies from file
 do ik=1,nkpt
-  call getoccsv(vkl(:,ik),occsv(:,ik))
+  call getoccsv(filext,ik,vkl(:,ik),occsv(:,ik))
 end do
 ! delete existing EMD.OUT
 if (mp_mpi) then
@@ -59,8 +61,7 @@ open(85,file='EMD.OUT',action='WRITE',form='UNFORMATTED',access='DIRECT', &
 do ik=1,nkpt
 ! distribute among MPI processes
   if (mod(ik-1,np_mpi).ne.lp_mpi) cycle
-  allocate(emd(nhkmax))
-  allocate(wfpw(nhkmax,nspinor,nstsv))
+  allocate(emd(nhkmax),wfpw(nhkmax,nspinor,nstsv))
 !$OMP CRITICAL
   write(*,'("Info(writeemd): ",I6," of ",I6," k-points")') ik,nkpt
 !$OMP END CRITICAL
