@@ -41,10 +41,10 @@ do is=1,nspecies
     ias=idxas(ia,is)
     write(50,*)
     write(50,'("Species : ",I4," (",A,"), atom : ",I4)') is,trim(spsymb(is)),ia
-    do ist=1,spnst(is)
+    do ist=1,nstsp(is)
       if (spcore(ist,is)) then
         write(50,'(" n = ",I2,", l = ",I2,", k = ",I2," : ",G18.10)') &
-         spn(ist,is),spl(ist,is),spk(ist,is),evalcr(ist,ias)
+         nsp(ist,is),lsp(ist,is),ksp(ist,is),evalcr(ist,ias)
       end if
     end do
   end do
