@@ -53,7 +53,7 @@ write(fnum,*)
 write(fnum,'("All units are atomic (Hartree, Bohr, etc.)")')
 write(fnum,*)
 select case(task)
-case(0,1,28,200,201,350,351,440)
+case(0,1,28,29,200,201,350,351,440)
   if (trdstate) then
     write(fnum,'("+------------------------------------------+")')
     write(fnum,'("| Ground-state run resuming from STATE.OUT |")')
@@ -110,7 +110,7 @@ do is=1,nspecies
   write(fnum,'(" atomic mass : ",G18.10)') spmass(is)
   write(fnum,'(" muffin-tin radius : ",G18.10)') rmt(is)
   write(fnum,'(" number of radial points in muffin-tin : ",I6)') nrmt(is)
-  write(fnum,'(" number on inner part of muffin-tin    : ",I6)') nrmtinr(is)
+  write(fnum,'(" number on inner part of muffin-tin    : ",I6)') nrmti(is)
   write(fnum,'(" atomic positions (lattice), magnetic fields (Cartesian) :")')
   do ia=1,natoms(is)
     write(fnum,'(I4," : ",3F12.8,"  ",3F12.8)') ia,atposl(:,ia,is), &
@@ -166,6 +166,10 @@ if ((abs(fsmtype).eq.2).or.(abs(fsmtype).eq.3)) then
     end do
   end do
 end if
+if (trst) then
+  write(fnum,'(" reduced Stoner theory (RST) enabled")')
+  write(fnum,'("  scaling factor : ",G18.10)') rstsf
+end if
 if (ftmtype.ne.0) then
   write(fnum,*)
   write(fnum,'(" fixed tensor moment (FTM) calculation, type : ",I4)') ftmtype
@@ -234,9 +238,9 @@ write(fnum,'("Number of G-vectors : ",I8)') ngvec
 write(fnum,*)
 write(fnum,'("Maximum angular momentum used for")')
 write(fnum,'(" APW functions                      : ",I4)') lmaxapw
-write(fnum,'(" potential and density              : ",I4)') lmaxvr
-write(fnum,'(" inner part of muffin-tin           : ",I4)') lmaxinr
 write(fnum,'(" H and O matrix elements outer loop : ",I4)') lmaxmat
+write(fnum,'(" outer part of muffin-tin           : ",I4)') lmaxo
+write(fnum,'(" inner part of muffin-tin           : ",I4)') lmaxi
 write(fnum,*)
 write(fnum,'("Total nuclear charge    : ",G18.10)') chgzn
 write(fnum,'("Total core charge       : ",G18.10)') chgcrtot
