@@ -18,6 +18,8 @@ call init1
 call init4
 ! read density and potentials from file
 call readstate
+! read Fermi energy from file
+call readfermi
 ! find the new linearisation energies
 call linengy
 ! generate the APW radial functions
