@@ -9,23 +9,26 @@ implicit none
 ! arguments
 integer, intent(in) :: ngp
 real(8), intent(in) :: gpc(ngp)
-complex(8), intent(in) :: ylmgp(lmmaxvr,ngp)
+complex(8), intent(in) :: ylmgp(lmmaxo,ngp)
 integer, intent(in) :: ld
 complex(8), intent(in) :: sfacgp(ld,natmtot)
-complex(8), intent(in) :: zfmt(lmmaxvr,nrcmtmax,natmtot),zfir(ngtot)
+complex(8), intent(in) :: zfmt(npcmtmax,natmtot),zfir(ngtot)
 complex(8), intent(out) :: zfgp(ngp)
 ! local variables
 integer is,ia,ias,ig
 integer nrc,nrci,irc
-integer lmax,l,m,lm
+integer lmax,l,m,lm,i
 real(8) t0,t1,t2
-complex(8) zsum1,zsum2,z1
+complex(8) zsum1,zsum2
 ! automatic arrays
-real(8) jl(0:lmaxvr,nrcmtmax)
-real(8) fr1(nrcmtmax),fr2(nrcmtmax),gr(nrcmtmax)
-complex(8) ylm(lmmaxvr)
+real(8) jl(0:lmaxo,nrcmtmax)
+real(8) fr1(nrcmtmax),fr2(nrcmtmax)
+complex(8) ylm(lmmaxo)
 ! allocatable arrays
 complex(8), allocatable :: zfft(:)
+! external functions
+real(8) fintgt
+external fintgt
 if ((ngp.lt.1).or.(ngp.gt.ngvec)) then
   write(*,*)
   write(*,'("Error(zftzf): ngp out of range : ",I8)') ngp
@@ -42,46 +45,41 @@ do ig=1,ngp
   ylm(:)=ylmgp(:,ig)
   do is=1,nspecies
     nrc=nrcmt(is)
-    nrci=nrcmtinr(is)
+    nrci=nrcmti(is)
 ! generate spherical Bessel functions
+    lmax=lmaxi
     do irc=1,nrc
-      if (irc.le.nrci) then
-        lmax=lmaxinr
-      else
-        lmax=lmaxvr
-      end if
       t1=gpc(ig)*rcmt(irc,is)
       call sbessel(lmax,t1,jl(:,irc))
+      if (irc.eq.nrci) lmax=lmaxo
     end do
     do ia=1,natoms(is)
       ias=idxas(ia,is)
-      z1=t0*conjg(sfacgp(ig,ias))
+      lmax=lmaxi
+      i=0
       do irc=1,nrc
-        if (irc.le.nrci) then
-          lmax=lmaxinr
-        else
-          lmax=lmaxvr
-        end if
-        zsum1=jl(0,irc)*zfmt(1,irc,ias)*ylm(1)
+        i=i+1
+        zsum1=jl(0,irc)*zfmt(i,ias)*ylm(1)
         lm=1
         do l=1,lmax
           lm=lm+1
-          zsum2=zfmt(lm,irc,ias)*ylm(lm)
+          i=i+1
+          zsum2=zfmt(i,ias)*ylm(lm)
           do m=1-l,l
             lm=lm+1
-            zsum2=zsum2+zfmt(lm,irc,ias)*ylm(lm)
+            i=i+1
+            zsum2=zsum2+zfmt(i,ias)*ylm(lm)
           end do
           zsum1=zsum1+jl(l,irc)*zilc(l)*zsum2
         end do
-        zsum1=zsum1*rcmt(irc,is)**2
+        zsum1=zsum1*r2cmt(irc,is)
         fr1(irc)=dble(zsum1)
         fr2(irc)=aimag(zsum1)
+        if (irc.eq.nrci) lmax=lmaxo
       end do
-      call fderiv(-1,nrc,rcmt(:,is),fr1,gr)
-      t1=gr(nrc)
-      call fderiv(-1,nrc,rcmt(:,is),fr2,gr)
-      t2=gr(nrc)
-      zfgp(ig)=zfgp(ig)+z1*cmplx(t1,t2,8)
+      t1=fintgt(-1,nrc,rcmt(:,is),fr1)
+      t2=fintgt(-1,nrc,rcmt(:,is),fr2)
+      zfgp(ig)=zfgp(ig)+t0*conjg(sfacgp(ig,ias))*cmplx(t1,t2,8)
     end do
   end do
 end do
